@@ -1,6 +1,6 @@
 /* valaccodedeclarator.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,41 +19,39 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodedeclarator.h"
 
-struct _ValaCCodeDeclaratorPrivate {
-};
-#define VALA_CCODE_DECLARATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_DECLARATOR, ValaCCodeDeclaratorPrivate))
 enum  {
-	VALA_CCODE_DECLARATOR_DUMMY_PROPERTY,
+	VALA_CCODE_DECLARATOR_DUMMY_PROPERTY
 };
+static void vala_ccode_declarator_real_write_initialization (ValaCCodeDeclarator* self, ValaCCodeWriter* writer);
 static gpointer vala_ccode_declarator_parent_class = NULL;
 
 
-static void vala_ccode_declarator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
+/**
+ * Writes initialization statements for this declarator with the
+ * specified C code writer if necessary.
+ *
+ * @param writer a C code writer
+ */
+static void vala_ccode_declarator_real_write_initialization (ValaCCodeDeclarator* self, ValaCCodeWriter* writer)
 {
-	ValaCCodeDeclarator * self = VALA_CCODE_DECLARATOR (object);
-	switch (property_id) {
-	}
+	g_return_if_fail (VALA_IS_CCODE_DECLARATOR (self));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 }
 
 
-static void vala_ccode_declarator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
+void vala_ccode_declarator_write_initialization (ValaCCodeDeclarator* self, ValaCCodeWriter* writer)
 {
-	ValaCCodeDeclarator * self = VALA_CCODE_DECLARATOR (object);
-	switch (property_id) {
-	}
+	VALA_CCODE_DECLARATOR_GET_CLASS (self)->write_initialization (self, writer);
 }
 
 
 static void vala_ccode_declarator_class_init (ValaCCodeDeclaratorClass * klass)
 {
 	vala_ccode_declarator_parent_class = g_type_class_peek_parent (klass);
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_declarator_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_declarator_set_property;
+	VALA_CCODE_DECLARATOR_CLASS (klass)->write_initialization = vala_ccode_declarator_real_write_initialization;
 }
 
 
@@ -62,7 +60,7 @@ static void vala_ccode_declarator_init (ValaCCodeDeclarator * self)
 }
 
 
-GType vala_ccode_declarator_get_type ()
+GType vala_ccode_declarator_get_type (void)
 {
 	static GType vala_ccode_declarator_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_declarator_type_id == 0)) {
