@@ -85,10 +85,10 @@ ValaCCodeExpression* vala_ccode_element_access_get_container (ValaCCodeElementAc
 
 void vala_ccode_element_access_set_container (ValaCCodeElementAccess* self, ValaCCodeExpression* value)
 {
-	ValaCCodeExpression* __temp1;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_ELEMENT_ACCESS (self));
-	__temp1 = NULL;
-	self->priv->_container = (__temp1 = g_object_ref (value), (self->priv->_container == NULL ? NULL : (self->priv->_container = (g_object_unref (self->priv->_container), NULL))), __temp1);
+	_tmp1 = NULL;
+	self->priv->_container = (_tmp1 = g_object_ref (value), (self->priv->_container == NULL ? NULL : (self->priv->_container = (g_object_unref (self->priv->_container), NULL))), _tmp1);
 }
 
 
@@ -101,10 +101,10 @@ ValaCCodeExpression* vala_ccode_element_access_get_index (ValaCCodeElementAccess
 
 void vala_ccode_element_access_set_index (ValaCCodeElementAccess* self, ValaCCodeExpression* value)
 {
-	ValaCCodeExpression* __temp3;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_ELEMENT_ACCESS (self));
-	__temp3 = NULL;
-	self->priv->_index = (__temp3 = g_object_ref (value), (self->priv->_index == NULL ? NULL : (self->priv->_index = (g_object_unref (self->priv->_index), NULL))), __temp3);
+	_tmp1 = NULL;
+	self->priv->_index = (_tmp1 = g_object_ref (value), (self->priv->_index == NULL ? NULL : (self->priv->_index = (g_object_unref (self->priv->_index), NULL))), _tmp1);
 }
 
 
@@ -119,6 +119,9 @@ static void vala_ccode_element_access_get_property (GObject * object, guint prop
 		case VALA_CCODE_ELEMENT_ACCESS_INDEX:
 		g_value_set_object (value, vala_ccode_element_access_get_index (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -134,6 +137,9 @@ static void vala_ccode_element_access_set_property (GObject * object, guint prop
 		case VALA_CCODE_ELEMENT_ACCESS_INDEX:
 		vala_ccode_element_access_set_index (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
