@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodeformalparameter.h"
 #include <ccode/valaccodeformalparameter.h>
@@ -52,6 +50,11 @@ ValaCCodeFormalParameter* vala_ccode_formal_parameter_new (const char* n, const
 	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, n), __params_it++);
 	(__params_it->name = "type-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, type), __params_it++);
 	self = g_object_newv (VALA_TYPE_CCODE_FORMAL_PARAMETER, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -59,7 +62,7 @@ ValaCCodeFormalParameter* vala_ccode_formal_parameter_new (const char* n, const
 static void vala_ccode_formal_parameter_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeFormalParameter * self;
-	self = VALA_CCODE_FORMAL_PARAMETER (base);
+	self = ((ValaCCodeFormalParameter*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, vala_ccode_formal_parameter_get_type_name (self));
 	vala_ccode_writer_write_string (writer, " ");
@@ -76,10 +79,10 @@ char* vala_ccode_formal_parameter_get_name (ValaCCodeFormalParameter* self)
 
 void vala_ccode_formal_parameter_set_name (ValaCCodeFormalParameter* self, const char* value)
 {
-	char* __temp1;
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_FORMAL_PARAMETER (self));
-	__temp1 = NULL;
-	self->priv->_name = (__temp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp1);
+	_tmp1 = NULL;
+	self->priv->_name = (_tmp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp1);
 }
 
 
@@ -92,10 +95,10 @@ char* vala_ccode_formal_parameter_get_type_name (ValaCCodeFormalParameter* self)
 
 void vala_ccode_formal_parameter_set_type_name (ValaCCodeFormalParameter* self, const char* value)
 {
-	char* __temp3;
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_FORMAL_PARAMETER (self));
-	__temp3 = NULL;
-	self->priv->_type_name = (__temp3 = g_strdup (value), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), __temp3);
+	_tmp1 = NULL;
+	self->priv->_type_name = (_tmp1 = g_strdup (value), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), _tmp1);
 }
 
 
@@ -110,6 +113,9 @@ static void vala_ccode_formal_parameter_get_property (GObject * object, guint pr
 		case VALA_CCODE_FORMAL_PARAMETER_TYPE_NAME:
 		g_value_set_string (value, vala_ccode_formal_parameter_get_type_name (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -125,6 +131,9 @@ static void vala_ccode_formal_parameter_set_property (GObject * object, guint pr
 		case VALA_CCODE_FORMAL_PARAMETER_TYPE_NAME:
 		vala_ccode_formal_parameter_set_type_name (self, g_value_get_string (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -162,7 +171,7 @@ static void vala_ccode_formal_parameter_dispose (GObject * obj)
 }
 
 
-GType vala_ccode_formal_parameter_get_type ()
+GType vala_ccode_formal_parameter_get_type (void)
 {
 	static GType vala_ccode_formal_parameter_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_formal_parameter_type_id == 0)) {
