@@ -19,17 +19,19 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodefunction.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/collection.h>
+#include <ccode/valaccodefunction.h>
 
 struct _ValaCCodeFunctionPrivate {
 	char* _name;
 	ValaCCodeModifiers _modifiers;
 	char* _return_type;
 	ValaCCodeBlock* _block;
-	GList* parameters;
+	GeeList* parameters;
 };
 #define VALA_CCODE_FUNCTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FUNCTION, ValaCCodeFunctionPrivate))
 enum  {
@@ -44,18 +46,14 @@ static gpointer vala_ccode_function_parent_class = NULL;
 static void vala_ccode_function_dispose (GObject * obj);
 
 
-ValaCCodeFunction* vala_ccode_function_new (const char* _name, const char* _return_type)
+ValaCCodeFunction* vala_ccode_function_new (const char* name, const char* return_type)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaCCodeFunction * self;
-	g_return_val_if_fail (_name != NULL, NULL);
-	g_return_val_if_fail (_return_type != NULL, NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
-	(__params_it->name = "return-type", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _return_type), __params_it++);
-	self = g_object_newv (VALA_TYPE_CCODE_FUNCTION, __params_it - __params, __params);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (return_type != NULL, NULL);
+	self = g_object_newv (VALA_TYPE_CCODE_FUNCTION, 0, NULL);
+	vala_ccode_function_set_name (self, name);
+	vala_ccode_function_set_return_type (self, return_type);
 	return self;
 }
 
@@ -69,7 +67,7 @@ void vala_ccode_function_add_parameter (ValaCCodeFunction* self, ValaCCodeFormal
 {
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION (self));
 	g_return_if_fail (VALA_IS_CCODE_FORMAL_PARAMETER (param));
-	self->priv->parameters = g_list_append (self->priv->parameters, g_object_ref (param));
+	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
 }
 
 
@@ -83,26 +81,26 @@ ValaCCodeFunction* vala_ccode_function_copy (ValaCCodeFunction* self)
 	ValaCCodeFunction* func;
 	g_return_val_if_fail (VALA_IS_CCODE_FUNCTION (self), NULL);
 	func = vala_ccode_function_new (vala_ccode_function_get_name (self), vala_ccode_function_get_return_type (self));
-	(vala_ccode_function_set_modifiers (func, vala_ccode_function_get_modifiers (self)), vala_ccode_function_get_modifiers (func));
+	vala_ccode_function_set_modifiers (func, vala_ccode_function_get_modifiers (self));
 	{
-		GList* __temp1;
-		GList* param_it;
-		__temp1 = NULL;
-		__temp1 = self->priv->parameters;
-		for (param_it = __temp1; param_it != NULL; param_it = param_it->next) {
+		GeeList* param_collection;
+		GeeIterator* param_it;
+		param_collection = self->priv->parameters;
+		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
+		while (gee_iterator_next (param_it)) {
 			ValaCCodeFormalParameter* param;
-			param = param_it->data;
+			param = gee_iterator_get (param_it);
 			{
-				ValaCCodeFormalParameter* __temp0;
 				/* no deep copy for lists available yet
 				 * func.parameters = parameters.copy ();
 				 */
-				__temp0 = NULL;
-				func->priv->parameters = g_list_append (func->priv->parameters, (__temp0 = param, (__temp0 == NULL ? NULL : g_object_ref (__temp0))));
+				gee_collection_add (GEE_COLLECTION (func->priv->parameters), param);
+				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
+		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
-	(vala_ccode_function_set_block (func, vala_ccode_function_get_block (self)), vala_ccode_function_get_block (func));
+	vala_ccode_function_set_block (func, vala_ccode_function_get_block (self));
 	return func;
 	(func == NULL ? NULL : (func = (g_object_unref (func), NULL)));
 }
@@ -112,7 +110,7 @@ static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter
 {
 	ValaCCodeFunction * self;
 	gboolean first;
-	self = VALA_CCODE_FUNCTION (base);
+	self = ((ValaCCodeFunction*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer);
 	if ((vala_ccode_function_get_modifiers (self) & VALA_CCODE_MODIFIERS_STATIC) == VALA_CCODE_MODIFIERS_STATIC) {
@@ -124,13 +122,13 @@ static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter
 	vala_ccode_writer_write_string (writer, " (");
 	first = TRUE;
 	{
-		GList* __temp3;
-		GList* param_it;
-		__temp3 = NULL;
-		__temp3 = self->priv->parameters;
-		for (param_it = __temp3; param_it != NULL; param_it = param_it->next) {
+		GeeList* param_collection;
+		GeeIterator* param_it;
+		param_collection = self->priv->parameters;
+		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
+		while (gee_iterator_next (param_it)) {
 			ValaCCodeFormalParameter* param;
-			param = param_it->data;
+			param = gee_iterator_get (param_it);
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -138,8 +136,13 @@ static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter
 					first = FALSE;
 				}
 				vala_ccode_node_write (VALA_CCODE_NODE (param), writer);
+				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
+		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
+	}
+	if (first) {
+		vala_ccode_writer_write_string (writer, "void");
 	}
 	vala_ccode_writer_write_string (writer, ")");
 	if (vala_ccode_function_get_block (self) == NULL) {
@@ -162,10 +165,10 @@ char* vala_ccode_function_get_name (ValaCCodeFunction* self)
 
 void vala_ccode_function_set_name (ValaCCodeFunction* self, const char* value)
 {
-	char* __temp5;
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION (self));
-	__temp5 = NULL;
-	self->priv->_name = (__temp5 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp5);
+	_tmp1 = NULL;
+	self->priv->_name = (_tmp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp1);
 }
 
 
@@ -192,10 +195,10 @@ char* vala_ccode_function_get_return_type (ValaCCodeFunction* self)
 
 void vala_ccode_function_set_return_type (ValaCCodeFunction* self, const char* value)
 {
-	char* __temp8;
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION (self));
-	__temp8 = NULL;
-	self->priv->_return_type = (__temp8 = g_strdup (value), (self->priv->_return_type = (g_free (self->priv->_return_type), NULL)), __temp8);
+	_tmp1 = NULL;
+	self->priv->_return_type = (_tmp1 = g_strdup (value), (self->priv->_return_type = (g_free (self->priv->_return_type), NULL)), _tmp1);
 }
 
 
@@ -208,12 +211,12 @@ ValaCCodeBlock* vala_ccode_function_get_block (ValaCCodeFunction* self)
 
 void vala_ccode_function_set_block (ValaCCodeFunction* self, ValaCCodeBlock* value)
 {
-	ValaCCodeBlock* __temp11;
-	ValaCCodeBlock* __temp10;
+	ValaCCodeBlock* _tmp2;
+	ValaCCodeBlock* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION (self));
-	__temp11 = NULL;
-	__temp10 = NULL;
-	self->priv->_block = (__temp11 = (__temp10 = value, (__temp10 == NULL ? NULL : g_object_ref (__temp10))), (self->priv->_block == NULL ? NULL : (self->priv->_block = (g_object_unref (self->priv->_block), NULL))), __temp11);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_block == NULL ? NULL : (self->priv->_block = (g_object_unref (self->priv->_block), NULL))), _tmp2);
 }
 
 
@@ -234,6 +237,9 @@ static void vala_ccode_function_get_property (GObject * object, guint property_i
 		case VALA_CCODE_FUNCTION_BLOCK:
 		g_value_set_object (value, vala_ccode_function_get_block (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -255,6 +261,9 @@ static void vala_ccode_function_set_property (GObject * object, guint property_i
 		case VALA_CCODE_FUNCTION_BLOCK:
 		vala_ccode_function_set_block (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -267,9 +276,9 @@ static void vala_ccode_function_class_init (ValaCCodeFunctionClass * klass)
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_function_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_function_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_function_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_MODIFIERS, g_param_spec_int ("modifiers", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_RETURN_TYPE, g_param_spec_string ("return-type", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_RETURN_TYPE, g_param_spec_string ("return-type", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_BLOCK, g_param_spec_object ("block", "foo", "bar", VALA_TYPE_CCODE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -277,6 +286,7 @@ static void vala_ccode_function_class_init (ValaCCodeFunctionClass * klass)
 static void vala_ccode_function_init (ValaCCodeFunction * self)
 {
 	self->priv = VALA_CCODE_FUNCTION_GET_PRIVATE (self);
+	self->priv->parameters = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
@@ -289,14 +299,14 @@ static void vala_ccode_function_dispose (GObject * obj)
 	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	(self->priv->_return_type = (g_free (self->priv->_return_type), NULL));
 	(self->priv->_block == NULL ? NULL : (self->priv->_block = (g_object_unref (self->priv->_block), NULL)));
-	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_list_foreach (self->priv->parameters, (GFunc) g_object_unref, NULL), g_list_free (self->priv->parameters), NULL)));
+	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
 	klass = VALA_CCODE_FUNCTION_CLASS (g_type_class_peek (VALA_TYPE_CCODE_FUNCTION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_ccode_function_get_type ()
+GType vala_ccode_function_get_type (void)
 {
 	static GType vala_ccode_function_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_function_type_id == 0)) {
