@@ -86,10 +86,10 @@ static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWr
 	vala_ccode_writer_write_string (writer, ")");
 	/* else shouldn't be on a separate line */
 	if (vala_ccode_if_statement_get_false_statement (self) != NULL && VALA_IS_CCODE_BLOCK (vala_ccode_if_statement_get_true_statement (self))) {
-		ValaCCodeBlock* __temp0;
+		ValaCCodeBlock* _tmp0;
 		ValaCCodeBlock* cblock;
-		__temp0 = NULL;
-		cblock = (__temp0 = VALA_CCODE_BLOCK (vala_ccode_if_statement_get_true_statement (self)), (__temp0 == NULL ? NULL : g_object_ref (__temp0)));
+		_tmp0 = NULL;
+		cblock = (_tmp0 = VALA_CCODE_BLOCK (vala_ccode_if_statement_get_true_statement (self)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 		vala_ccode_block_set_suppress_newline (cblock, TRUE);
 		(cblock == NULL ? NULL : (cblock = (g_object_unref (cblock), NULL)));
 	}
@@ -103,10 +103,10 @@ static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWr
 		}
 		/* else if should be on one line */
 		if (VALA_IS_CCODE_IF_STATEMENT (vala_ccode_if_statement_get_false_statement (self))) {
-			ValaCCodeIfStatement* __temp1;
+			ValaCCodeIfStatement* _tmp1;
 			ValaCCodeIfStatement* cif;
-			__temp1 = NULL;
-			cif = (__temp1 = VALA_CCODE_IF_STATEMENT (vala_ccode_if_statement_get_false_statement (self)), (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
+			_tmp1 = NULL;
+			cif = (_tmp1 = VALA_CCODE_IF_STATEMENT (vala_ccode_if_statement_get_false_statement (self)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 			vala_ccode_if_statement_set_else_if (cif, TRUE);
 			(cif == NULL ? NULL : (cif = (g_object_unref (cif), NULL)));
 		}
@@ -124,10 +124,10 @@ ValaCCodeExpression* vala_ccode_if_statement_get_condition (ValaCCodeIfStatement
 
 void vala_ccode_if_statement_set_condition (ValaCCodeIfStatement* self, ValaCCodeExpression* value)
 {
-	ValaCCodeExpression* __temp3;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_IF_STATEMENT (self));
-	__temp3 = NULL;
-	self->priv->_condition = (__temp3 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), __temp3);
+	_tmp1 = NULL;
+	self->priv->_condition = (_tmp1 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp1);
 }
 
 
@@ -140,10 +140,10 @@ ValaCCodeStatement* vala_ccode_if_statement_get_true_statement (ValaCCodeIfState
 
 void vala_ccode_if_statement_set_true_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value)
 {
-	ValaCCodeStatement* __temp5;
+	ValaCCodeStatement* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_IF_STATEMENT (self));
-	__temp5 = NULL;
-	self->priv->_true_statement = (__temp5 = g_object_ref (value), (self->priv->_true_statement == NULL ? NULL : (self->priv->_true_statement = (g_object_unref (self->priv->_true_statement), NULL))), __temp5);
+	_tmp1 = NULL;
+	self->priv->_true_statement = (_tmp1 = g_object_ref (value), (self->priv->_true_statement == NULL ? NULL : (self->priv->_true_statement = (g_object_unref (self->priv->_true_statement), NULL))), _tmp1);
 }
 
 
@@ -156,12 +156,12 @@ ValaCCodeStatement* vala_ccode_if_statement_get_false_statement (ValaCCodeIfStat
 
 void vala_ccode_if_statement_set_false_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value)
 {
-	ValaCCodeStatement* __temp8;
-	ValaCCodeStatement* __temp7;
+	ValaCCodeStatement* _tmp2;
+	ValaCCodeStatement* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_IF_STATEMENT (self));
-	__temp8 = NULL;
-	__temp7 = NULL;
-	self->priv->_false_statement = (__temp8 = (__temp7 = value, (__temp7 == NULL ? NULL : g_object_ref (__temp7))), (self->priv->_false_statement == NULL ? NULL : (self->priv->_false_statement = (g_object_unref (self->priv->_false_statement), NULL))), __temp8);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_false_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_false_statement == NULL ? NULL : (self->priv->_false_statement = (g_object_unref (self->priv->_false_statement), NULL))), _tmp2);
 }
 
 
@@ -196,6 +196,9 @@ static void vala_ccode_if_statement_get_property (GObject * object, guint proper
 		case VALA_CCODE_IF_STATEMENT_ELSE_IF:
 		g_value_set_boolean (value, vala_ccode_if_statement_get_else_if (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -217,6 +220,9 @@ static void vala_ccode_if_statement_set_property (GObject * object, guint proper
 		case VALA_CCODE_IF_STATEMENT_ELSE_IF:
 		vala_ccode_if_statement_set_else_if (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
