@@ -109,10 +109,10 @@ ValaCCodeExpression* vala_ccode_member_access_get_inner (ValaCCodeMemberAccess*
 
 void vala_ccode_member_access_set_inner (ValaCCodeMemberAccess* self, ValaCCodeExpression* value)
 {
-	ValaCCodeExpression* __temp1;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_MEMBER_ACCESS (self));
-	__temp1 = NULL;
-	self->priv->_inner = (__temp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp1);
+	_tmp1 = NULL;
+	self->priv->_inner = (_tmp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp1);
 }
 
 
@@ -125,10 +125,10 @@ char* vala_ccode_member_access_get_member_name (ValaCCodeMemberAccess* self)
 
 void vala_ccode_member_access_set_member_name (ValaCCodeMemberAccess* self, const char* value)
 {
-	char* __temp3;
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_MEMBER_ACCESS (self));
-	__temp3 = NULL;
-	self->priv->_member_name = (__temp3 = g_strdup (value), (self->priv->_member_name = (g_free (self->priv->_member_name), NULL)), __temp3);
+	_tmp1 = NULL;
+	self->priv->_member_name = (_tmp1 = g_strdup (value), (self->priv->_member_name = (g_free (self->priv->_member_name), NULL)), _tmp1);
 }
 
 
@@ -160,6 +160,9 @@ static void vala_ccode_member_access_get_property (GObject * object, guint prope
 		case VALA_CCODE_MEMBER_ACCESS_IS_POINTER:
 		g_value_set_boolean (value, vala_ccode_member_access_get_is_pointer (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -178,6 +181,9 @@ static void vala_ccode_member_access_set_property (GObject * object, guint prope
 		case VALA_CCODE_MEMBER_ACCESS_IS_POINTER:
 		vala_ccode_member_access_set_is_pointer (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
