@@ -1,6 +1,6 @@
 /* valaccodemodifiers.vala
  *
- * Copyright (C) 2006  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -33,7 +33,8 @@ G_BEGIN_DECLS
 typedef enum  {
 	VALA_CCODE_MODIFIERS_NONE,
 	VALA_CCODE_MODIFIERS_STATIC,
-	VALA_CCODE_MODIFIERS_REGISTER
+	VALA_CCODE_MODIFIERS_REGISTER,
+	VALA_CCODE_MODIFIERS_EXTERN
 } ValaCCodeModifiers;
 
 
