@@ -74,12 +74,12 @@ ValaCCodeExpression* vala_ccode_return_statement_get_return_expression (ValaCCod
 
 void vala_ccode_return_statement_set_return_expression (ValaCCodeReturnStatement* self, ValaCCodeExpression* value)
 {
-	ValaCCodeExpression* __temp2;
-	ValaCCodeExpression* __temp1;
+	ValaCCodeExpression* _tmp2;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_RETURN_STATEMENT (self));
-	__temp2 = NULL;
-	__temp1 = NULL;
-	self->priv->_return_expression = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (g_object_unref (self->priv->_return_expression), NULL))), __temp2);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_return_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (g_object_unref (self->priv->_return_expression), NULL))), _tmp2);
 }
 
 
@@ -91,6 +91,9 @@ static void vala_ccode_return_statement_get_property (GObject * object, guint pr
 		case VALA_CCODE_RETURN_STATEMENT_RETURN_EXPRESSION:
 		g_value_set_object (value, vala_ccode_return_statement_get_return_expression (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -103,6 +106,9 @@ static void vala_ccode_return_statement_set_property (GObject * object, guint pr
 		case VALA_CCODE_RETURN_STATEMENT_RETURN_EXPRESSION:
 		vala_ccode_return_statement_set_return_expression (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
