@@ -82,12 +82,12 @@ char* vala_ccode_type_definition_get_type_name (ValaCCodeTypeDefinition* self)
 
 void vala_ccode_type_definition_set_type_name (ValaCCodeTypeDefinition* self, const char* value)
 {
-	char* __temp2;
-	const char* __temp1;
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_TYPE_DEFINITION (self));
-	__temp2 = NULL;
-	__temp1 = NULL;
-	self->priv->_type_name = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_strdup (__temp1))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), __temp2);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), _tmp2);
 }
 
 
@@ -100,12 +100,12 @@ ValaCCodeDeclarator* vala_ccode_type_definition_get_declarator (ValaCCodeTypeDef
 
 void vala_ccode_type_definition_set_declarator (ValaCCodeTypeDefinition* self, ValaCCodeDeclarator* value)
 {
-	ValaCCodeDeclarator* __temp5;
-	ValaCCodeDeclarator* __temp4;
+	ValaCCodeDeclarator* _tmp2;
+	ValaCCodeDeclarator* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_TYPE_DEFINITION (self));
-	__temp5 = NULL;
-	__temp4 = NULL;
-	self->priv->_declarator = (__temp5 = (__temp4 = value, (__temp4 == NULL ? NULL : g_object_ref (__temp4))), (self->priv->_declarator == NULL ? NULL : (self->priv->_declarator = (g_object_unref (self->priv->_declarator), NULL))), __temp5);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_declarator = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_declarator == NULL ? NULL : (self->priv->_declarator = (g_object_unref (self->priv->_declarator), NULL))), _tmp2);
 }
 
 
@@ -120,6 +120,9 @@ static void vala_ccode_type_definition_get_property (GObject * object, guint pro
 		case VALA_CCODE_TYPE_DEFINITION_DECLARATOR:
 		g_value_set_object (value, vala_ccode_type_definition_get_declarator (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -135,6 +138,9 @@ static void vala_ccode_type_definition_set_property (GObject * object, guint pro
 		case VALA_CCODE_TYPE_DEFINITION_DECLARATOR:
 		vala_ccode_type_definition_set_declarator (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
