@@ -84,10 +84,10 @@ ValaCCodeExpression* vala_ccode_while_statement_get_condition (ValaCCodeWhileSta
 
 void vala_ccode_while_statement_set_condition (ValaCCodeWhileStatement* self, ValaCCodeExpression* value)
 {
-	ValaCCodeExpression* __temp1;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_WHILE_STATEMENT (self));
-	__temp1 = NULL;
-	self->priv->_condition = (__temp1 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), __temp1);
+	_tmp1 = NULL;
+	self->priv->_condition = (_tmp1 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp1);
 }
 
 
@@ -100,12 +100,12 @@ ValaCCodeStatement* vala_ccode_while_statement_get_body (ValaCCodeWhileStatement
 
 void vala_ccode_while_statement_set_body (ValaCCodeWhileStatement* self, ValaCCodeStatement* value)
 {
-	ValaCCodeStatement* __temp4;
-	ValaCCodeStatement* __temp3;
+	ValaCCodeStatement* _tmp2;
+	ValaCCodeStatement* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_WHILE_STATEMENT (self));
-	__temp4 = NULL;
-	__temp3 = NULL;
-	self->priv->_body = (__temp4 = (__temp3 = value, (__temp3 == NULL ? NULL : g_object_ref (__temp3))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp4);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
 }
 
 
@@ -120,6 +120,9 @@ static void vala_ccode_while_statement_get_property (GObject * object, guint pro
 		case VALA_CCODE_WHILE_STATEMENT_BODY:
 		g_value_set_object (value, vala_ccode_while_statement_get_body (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -135,6 +138,9 @@ static void vala_ccode_while_statement_set_property (GObject * object, guint pro
 		case VALA_CCODE_WHILE_STATEMENT_BODY:
 		vala_ccode_while_statement_set_body (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
