@@ -41,6 +41,7 @@ enum  {
 };
 static gpointer vala_ccode_writer_parent_class = NULL;
 static void vala_ccode_writer_dispose (GObject * obj);
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
 ValaCCodeWriter* vala_ccode_writer_new (const char* _filename)
@@ -68,11 +69,11 @@ ValaCCodeWriter* vala_ccode_writer_new (const char* _filename)
 void vala_ccode_writer_close (ValaCCodeWriter* self)
 {
 	GError * inner_error;
-	FILE* __temp0;
+	FILE* _tmp0;
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
 	inner_error = NULL;
-	__temp0 = NULL;
-	self->priv->stream = (__temp0 = NULL, (self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL))), __temp0);
+	_tmp0 = NULL;
+	self->priv->stream = (_tmp0 = NULL, (self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL))), _tmp0);
 	if (self->priv->file_exists) {
 		gboolean changed;
 		changed = TRUE;
@@ -80,8 +81,8 @@ void vala_ccode_writer_close (ValaCCodeWriter* self)
 			GMappedFile* old_file;
 			GMappedFile* new_file;
 			glong len;
-			GMappedFile* __temp1;
-			GMappedFile* __temp2;
+			GMappedFile* _tmp1;
+			GMappedFile* _tmp2;
 			old_file = g_mapped_file_new (self->priv->_filename, FALSE, &inner_error);
 			if (inner_error != NULL) {
 				if (inner_error->domain == G_FILE_ERROR) {
@@ -104,10 +105,10 @@ void vala_ccode_writer_close (ValaCCodeWriter* self)
 					changed = FALSE;
 				}
 			}
-			__temp1 = NULL;
-			old_file = (__temp1 = NULL, (old_file == NULL ? NULL : (old_file = (g_mapped_file_free (old_file), NULL))), __temp1);
-			__temp2 = NULL;
-			new_file = (__temp2 = NULL, (new_file == NULL ? NULL : (new_file = (g_mapped_file_free (new_file), NULL))), __temp2);
+			_tmp1 = NULL;
+			old_file = (_tmp1 = NULL, (old_file == NULL ? NULL : (old_file = (g_mapped_file_free (old_file), NULL))), _tmp1);
+			_tmp2 = NULL;
+			new_file = (_tmp2 = NULL, (new_file == NULL ? NULL : (new_file = (g_mapped_file_free (new_file), NULL))), _tmp2);
 			(old_file == NULL ? NULL : (old_file = (g_mapped_file_free (old_file), NULL)));
 			(new_file == NULL ? NULL : (new_file = (g_mapped_file_free (new_file), NULL)));
 		}
@@ -213,7 +214,7 @@ void vala_ccode_writer_write_end_block (ValaCCodeWriter* self)
 void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text)
 {
 	gboolean first;
-	char** __temp3;
+	char** _tmp0;
 	gint lines_length1;
 	char** lines;
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
@@ -222,17 +223,17 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text)
 	fprintf (self->priv->stream, "/*");
 	first = TRUE;
 	/* separate declaration due to missing memory management in foreach statements */
-	__temp3 = NULL;
-	lines = (__temp3 = g_strsplit (text, "\n", 0), lines_length1 = -1, __temp3);
+	_tmp0 = NULL;
+	lines = (_tmp0 = g_strsplit (text, "\n", 0), lines_length1 = -1, _tmp0);
 	{
 		char** line_collection;
 		int line_it;
 		line_collection = lines;
 		for (line_it = 0; (lines_length1 != -1 && line_it < lines_length1) || (lines_length1 == -1 && line_collection[line_it] != NULL); line_it = line_it + 1) {
-			const char* __temp4;
+			const char* _tmp1;
 			char* line;
-			__temp4 = NULL;
-			line = (__temp4 = line_collection[line_it], (__temp4 == NULL ? NULL : g_strdup (__temp4)));
+			_tmp1 = NULL;
+			line = (_tmp1 = line_collection[line_it], (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 			{
 				if (!first) {
 					vala_ccode_writer_write_indent (self);
@@ -246,7 +247,7 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text)
 	}
 	fprintf (self->priv->stream, "*/");
 	vala_ccode_writer_write_newline (self);
-	(lines = (g_strfreev (lines), NULL));
+	(lines = (_vala_array_free (lines, lines_length1, ((GDestroyNotify) g_free)), NULL));
 }
 
 
@@ -259,24 +260,24 @@ char* vala_ccode_writer_get_filename (ValaCCodeWriter* self)
 
 void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value)
 {
-	char* __temp7;
-	const char* __temp6;
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
-	__temp7 = NULL;
-	__temp6 = NULL;
-	self->priv->_filename = (__temp7 = (__temp6 = value, (__temp6 == NULL ? NULL : g_strdup (__temp6))), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), __temp7);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_filename = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), _tmp2);
 	self->priv->file_exists = g_file_test (self->priv->_filename, G_FILE_TEST_EXISTS);
 	if (self->priv->file_exists) {
-		char* __temp8;
-		FILE* __temp9;
-		__temp8 = NULL;
-		self->priv->temp_filename = (__temp8 = g_strdup_printf ("%s.valatmp", self->priv->_filename), (self->priv->temp_filename = (g_free (self->priv->temp_filename), NULL)), __temp8);
-		__temp9 = NULL;
-		self->priv->stream = (__temp9 = fopen (self->priv->temp_filename, "w"), (self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL))), __temp9);
+		char* _tmp3;
+		FILE* _tmp4;
+		_tmp3 = NULL;
+		self->priv->temp_filename = (_tmp3 = g_strdup_printf ("%s.valatmp", self->priv->_filename), (self->priv->temp_filename = (g_free (self->priv->temp_filename), NULL)), _tmp3);
+		_tmp4 = NULL;
+		self->priv->stream = (_tmp4 = fopen (self->priv->temp_filename, "w"), (self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL))), _tmp4);
 	} else {
-		FILE* __temp10;
-		__temp10 = NULL;
-		self->priv->stream = (__temp10 = fopen (self->priv->_filename, "w"), (self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL))), __temp10);
+		FILE* _tmp5;
+		_tmp5 = NULL;
+		self->priv->stream = (_tmp5 = fopen (self->priv->_filename, "w"), (self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL))), _tmp5);
 	}
 }
 
@@ -299,6 +300,9 @@ static void vala_ccode_writer_get_property (GObject * object, guint property_id,
 		case VALA_CCODE_WRITER_BOL:
 		g_value_set_boolean (value, vala_ccode_writer_get_bol (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -311,6 +315,9 @@ static void vala_ccode_writer_set_property (GObject * object, guint property_id,
 		case VALA_CCODE_WRITER_FILENAME:
 		vala_ccode_writer_set_filename (self, g_value_get_string (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -360,5 +367,23 @@ GType vala_ccode_writer_get_type (void)
 }
 
 
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func)
+{
+	if (array != NULL && destroy_func != NULL) {
+		int i;
+		if (array_length >= 0)
+		for (i = 0; i < array_length; i = i + 1) {
+			if (((gpointer*) array)[i] != NULL)
+			destroy_func (((gpointer*) array)[i]);
+		}
+		else
+		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) array)[i]);
+		}
+	}
+	g_free (array);
+}
+
+
 
 
