@@ -25,9 +25,6 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <stdlib.h>
-#include <string.h>
-#include <vala/valacodecontext.h>
 
 G_BEGIN_DECLS
 
