@@ -23,7 +23,9 @@
  */
 
 #include "hashmap.h"
+#include <gee/hashmap.h>
 
+typedef struct _GeeHashMapNode GeeHashMapNode;
 typedef struct _GeeHashMapKeySet GeeHashMapKeySet;
 typedef struct _GeeHashMapKeySetClass GeeHashMapKeySetClass;
 typedef struct _GeeHashMapKeySetPrivate GeeHashMapKeySetPrivate;
@@ -36,7 +38,6 @@ typedef struct _GeeHashMapValueCollectionPrivate GeeHashMapValueCollectionPrivat
 typedef struct _GeeHashMapValueIterator GeeHashMapValueIterator;
 typedef struct _GeeHashMapValueIteratorClass GeeHashMapValueIteratorClass;
 typedef struct _GeeHashMapValueIteratorPrivate GeeHashMapValueIteratorPrivate;
-typedef struct _GeeHashMapNode GeeHashMapNode;
 struct _GeeHashMapPrivate {
 	gint _array_size;
 	gint _nnodes;
@@ -75,6 +76,23 @@ static gboolean gee_hash_map_real_remove (GeeMap* base, gpointer key);
 static void gee_hash_map_real_clear (GeeMap* base);
 static void gee_hash_map_resize (GeeHashMap* self);
 static GObject * gee_hash_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
+struct _GeeHashMapNode {
+	gpointer key;
+	gpointer value;
+	GeeHashMapNode* next;
+	guint key_hash;
+};
+static GeeHashMapNode* gee_hash_map_node_new (gpointer k, gpointer v, guint hash);
+static void gee_hash_map_node_free (GeeHashMapNode* self);
+static void gee_hash_map_node_free (GeeHashMapNode* self)
+{
+	NULL;
+	NULL;
+	(self->next == NULL ? NULL : (self->next = (gee_hash_map_node_free (self->next), NULL)));
+	g_slice_free (GeeHashMapNode, self);
+}
+
+
 
 #define GEE_HASH_MAP_TYPE_KEY_SET (gee_hash_map_key_set_get_type ())
 #define GEE_HASH_MAP_KEY_SET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_HASH_MAP_TYPE_KEY_SET, GeeHashMapKeySet))
@@ -119,7 +137,7 @@ static GeeIterableIface* gee_hash_map_key_set_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_hash_map_key_set_gee_collection_parent_iface = NULL;
 static GeeSetIface* gee_hash_map_key_set_gee_set_parent_iface = NULL;
 static void gee_hash_map_key_set_dispose (GObject * obj);
-GType gee_hash_map_key_set_get_type (void);
+static GType gee_hash_map_key_set_get_type (void);
 
 #define GEE_HASH_MAP_TYPE_KEY_ITERATOR (gee_hash_map_key_iterator_get_type ())
 #define GEE_HASH_MAP_KEY_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_HASH_MAP_TYPE_KEY_ITERATOR, GeeHashMapKeyIterator))
@@ -161,7 +179,7 @@ static void gee_hash_map_key_iterator_set_map (GeeHashMapKeyIterator* self, GeeH
 static gpointer gee_hash_map_key_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_hash_map_key_iterator_gee_iterator_parent_iface = NULL;
 static void gee_hash_map_key_iterator_dispose (GObject * obj);
-GType gee_hash_map_key_iterator_get_type (void);
+static GType gee_hash_map_key_iterator_get_type (void);
 
 #define GEE_HASH_MAP_TYPE_VALUE_COLLECTION (gee_hash_map_value_collection_get_type ())
 #define GEE_HASH_MAP_VALUE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_HASH_MAP_TYPE_VALUE_COLLECTION, GeeHashMapValueCollection))
@@ -205,7 +223,7 @@ static gpointer gee_hash_map_value_collection_parent_class = NULL;
 static GeeIterableIface* gee_hash_map_value_collection_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_hash_map_value_collection_gee_collection_parent_iface = NULL;
 static void gee_hash_map_value_collection_dispose (GObject * obj);
-GType gee_hash_map_value_collection_get_type (void);
+static GType gee_hash_map_value_collection_get_type (void);
 
 #define GEE_HASH_MAP_TYPE_VALUE_ITERATOR (gee_hash_map_value_iterator_get_type ())
 #define GEE_HASH_MAP_VALUE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_HASH_MAP_TYPE_VALUE_ITERATOR, GeeHashMapValueIterator))
@@ -247,24 +265,7 @@ static void gee_hash_map_value_iterator_set_map (GeeHashMapValueIterator* self,
 static gpointer gee_hash_map_value_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_hash_map_value_iterator_gee_iterator_parent_iface = NULL;
 static void gee_hash_map_value_iterator_dispose (GObject * obj);
-GType gee_hash_map_value_iterator_get_type (void);
-struct _GeeHashMapNode {
-	gpointer key;
-	gpointer value;
-	GeeHashMapNode* next;
-	guint key_hash;
-};
-static GeeHashMapNode* gee_hash_map_node_new (gpointer k, gpointer v, guint hash);
-static void gee_hash_map_node_free (GeeHashMapNode* self);
-static void gee_hash_map_node_free (GeeHashMapNode* self)
-{
-	NULL;
-	NULL;
-	(self->next == NULL ? NULL : (self->next = (gee_hash_map_node_free (self->next), NULL)));
-	g_slice_free (GeeHashMapNode, self);
-}
-
-
+static GType gee_hash_map_value_iterator_get_type (void);
 static gpointer gee_hash_map_parent_class = NULL;
 static GeeMapIface* gee_hash_map_gee_map_parent_iface = NULL;
 static void gee_hash_map_dispose (GObject * obj);
@@ -333,8 +334,8 @@ static gpointer gee_hash_map_real_get (GeeMap* base, gpointer key)
 	self = ((GeeHashMap*) base);
 	node = *gee_hash_map_lookup_node (self, key);
 	if (node != NULL) {
-		gpointer __temp4;
-		return (__temp4 = node->value, (__temp4 == NULL || self->priv->v_dup_func == NULL ? __temp4 : self->priv->v_dup_func (__temp4)));
+		gpointer _tmp0;
+		return (_tmp0 = node->value, (_tmp0 == NULL || self->priv->v_dup_func == NULL ? _tmp0 : self->priv->v_dup_func (_tmp0)));
 	} else {
 		return NULL;
 	}
@@ -348,15 +349,15 @@ static void gee_hash_map_real_set (GeeMap* base, gpointer key, gpointer value)
 	self = ((GeeHashMap*) base);
 	node = gee_hash_map_lookup_node (self, key);
 	if (*node != NULL) {
-		gpointer __temp8;
-		gpointer __temp7;
-		(*node)->value = (__temp8 = (__temp7 = value, (__temp7 == NULL || self->priv->v_dup_func == NULL ? __temp7 : self->priv->v_dup_func (__temp7))), ((*node)->value == NULL || self->priv->v_destroy_func == NULL ? NULL : ((*node)->value = (self->priv->v_destroy_func ((*node)->value), NULL))), __temp8);
+		gpointer _tmp1;
+		gpointer _tmp0;
+		(*node)->value = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL || self->priv->v_dup_func == NULL ? _tmp0 : self->priv->v_dup_func (_tmp0))), ((*node)->value == NULL || self->priv->v_destroy_func == NULL ? NULL : ((*node)->value = (self->priv->v_destroy_func ((*node)->value), NULL))), _tmp1);
 	} else {
 		guint hash_value;
-		gpointer __temp10;
-		gpointer __temp9;
+		gpointer _tmp3;
+		gpointer _tmp2;
 		hash_value = self->priv->_key_hash_func (key);
-		*node = gee_hash_map_node_new ((__temp9 = key, (__temp9 == NULL || self->priv->k_dup_func == NULL ? __temp9 : self->priv->k_dup_func (__temp9))), (__temp10 = value, (__temp10 == NULL || self->priv->v_dup_func == NULL ? __temp10 : self->priv->v_dup_func (__temp10))), hash_value);
+		*node = gee_hash_map_node_new ((_tmp2 = key, (_tmp2 == NULL || self->priv->k_dup_func == NULL ? _tmp2 : self->priv->k_dup_func (_tmp2))), (_tmp3 = value, (_tmp3 == NULL || self->priv->v_dup_func == NULL ? _tmp3 : self->priv->v_dup_func (_tmp3))), hash_value);
 		self->priv->_nnodes++;
 		gee_hash_map_resize (self);
 	}
@@ -371,10 +372,10 @@ static gboolean gee_hash_map_real_remove (GeeMap* base, gpointer key)
 	self = ((GeeHashMap*) base);
 	node = gee_hash_map_lookup_node (self, key);
 	if (*node != NULL) {
-		gpointer __temp11;
-		gpointer __temp12;
-		(*node)->key = (__temp11 = NULL, ((*node)->key == NULL || self->priv->k_destroy_func == NULL ? NULL : ((*node)->key = (self->priv->k_destroy_func ((*node)->key), NULL))), __temp11);
-		(*node)->value = (__temp12 = NULL, ((*node)->value == NULL || self->priv->v_destroy_func == NULL ? NULL : ((*node)->value = (self->priv->v_destroy_func ((*node)->value), NULL))), __temp12);
+		gpointer _tmp0;
+		gpointer _tmp1;
+		(*node)->key = (_tmp0 = NULL, ((*node)->key == NULL || self->priv->k_destroy_func == NULL ? NULL : ((*node)->key = (self->priv->k_destroy_func ((*node)->key), NULL))), _tmp0);
+		(*node)->value = (_tmp1 = NULL, ((*node)->value == NULL || self->priv->v_destroy_func == NULL ? NULL : ((*node)->value = (self->priv->v_destroy_func ((*node)->value), NULL))), _tmp1);
 		*node = (*node)->next;
 		self->priv->_nnodes--;
 		gee_hash_map_resize (self);
@@ -393,24 +394,24 @@ static void gee_hash_map_real_clear (GeeMap* base)
 		gint i;
 		i = 0;
 		for (i = 0; i < self->priv->_array_size; i++) {
-			GeeHashMapNode* __temp15;
+			GeeHashMapNode* _tmp0;
 			GeeHashMapNode* node;
-			__temp15 = NULL;
-			node = (__temp15 = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, __temp15);
+			_tmp0 = NULL;
+			node = (_tmp0 = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp0);
 			while (node != NULL) {
-				GeeHashMapNode* __temp16;
+				GeeHashMapNode* _tmp1;
 				GeeHashMapNode* next;
-				gpointer __temp17;
-				gpointer __temp18;
-				GeeHashMapNode* __temp20;
-				GeeHashMapNode* __temp19;
-				__temp16 = NULL;
-				next = (__temp16 = node->next, node->next = NULL, __temp16);
-				node->key = (__temp17 = NULL, (node->key == NULL || self->priv->k_destroy_func == NULL ? NULL : (node->key = (self->priv->k_destroy_func (node->key), NULL))), __temp17);
-				node->value = (__temp18 = NULL, (node->value == NULL || self->priv->v_destroy_func == NULL ? NULL : (node->value = (self->priv->v_destroy_func (node->value), NULL))), __temp18);
-				__temp20 = NULL;
-				__temp19 = NULL;
-				node = (__temp20 = (__temp19 = next, next = NULL, __temp19), (node == NULL ? NULL : (node = (gee_hash_map_node_free (node), NULL))), __temp20);
+				gpointer _tmp2;
+				gpointer _tmp3;
+				GeeHashMapNode* _tmp5;
+				GeeHashMapNode* _tmp4;
+				_tmp1 = NULL;
+				next = (_tmp1 = node->next, node->next = NULL, _tmp1);
+				node->key = (_tmp2 = NULL, (node->key == NULL || self->priv->k_destroy_func == NULL ? NULL : (node->key = (self->priv->k_destroy_func (node->key), NULL))), _tmp2);
+				node->value = (_tmp3 = NULL, (node->value == NULL || self->priv->v_destroy_func == NULL ? NULL : (node->value = (self->priv->v_destroy_func (node->value), NULL))), _tmp3);
+				_tmp5 = NULL;
+				_tmp4 = NULL;
+				node = (_tmp5 = (_tmp4 = next, next = NULL, _tmp4), (node == NULL ? NULL : (node = (gee_hash_map_node_free (node), NULL))), _tmp5);
 				(next == NULL ? NULL : (next = (gee_hash_map_node_free (next), NULL)));
 			}
 			(node == NULL ? NULL : (node = (gee_hash_map_node_free (node), NULL)));
@@ -426,57 +427,57 @@ static void gee_hash_map_resize (GeeHashMap* self)
 	g_return_if_fail (GEE_IS_HASH_MAP (self));
 	if ((self->priv->_array_size >= 3 * self->priv->_nnodes && self->priv->_array_size >= GEE_HASH_MAP_MIN_SIZE) || (3 * self->priv->_array_size <= self->priv->_nnodes && self->priv->_array_size < GEE_HASH_MAP_MAX_SIZE)) {
 		gint new_array_size;
-		GeeHashMapNode** __temp21;
+		GeeHashMapNode** _tmp0;
 		gint new_nodes_length1;
 		GeeHashMapNode** new_nodes;
-		GeeHashMapNode** __temp33;
-		GeeHashMapNode** __temp32;
+		GeeHashMapNode** _tmp12;
+		GeeHashMapNode** _tmp11;
 		new_array_size = g_spaced_primes_closest (self->priv->_nnodes);
 		new_array_size = CLAMP (new_array_size, GEE_HASH_MAP_MIN_SIZE, GEE_HASH_MAP_MAX_SIZE);
-		__temp21 = NULL;
-		new_nodes = (__temp21 = g_new0 (GeeHashMapNode*, new_array_size), new_nodes_length1 = new_array_size, __temp21);
+		_tmp0 = NULL;
+		new_nodes = (_tmp0 = g_new0 (GeeHashMapNode*, new_array_size + 1), new_nodes_length1 = new_array_size, _tmp0);
 		{
 			gint i;
 			i = 0;
 			for (i = 0; i < self->priv->_array_size; i++) {
 				GeeHashMapNode* node;
 				GeeHashMapNode* next;
-				GeeHashMapNode* __temp25;
-				GeeHashMapNode* __temp24;
-				GeeHashMapNode* __temp23;
-				GeeHashMapNode* __temp22;
+				GeeHashMapNode* _tmp4;
+				GeeHashMapNode* _tmp3;
+				GeeHashMapNode* _tmp2;
+				GeeHashMapNode* _tmp1;
 				node = NULL;
 				next = NULL;
-				__temp25 = NULL;
-				__temp24 = NULL;
-				__temp23 = NULL;
-				__temp22 = NULL;
-				for (node = (__temp23 = (__temp22 = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, __temp22), (node == NULL ? NULL : (node = (gee_hash_map_node_free (node), NULL))), __temp23); node != NULL; node = (__temp25 = (__temp24 = next, next = NULL, __temp24), (node == NULL ? NULL : (node = (gee_hash_map_node_free (node), NULL))), __temp25)) {
-					GeeHashMapNode* __temp27;
-					GeeHashMapNode* __temp26;
+				_tmp4 = NULL;
+				_tmp3 = NULL;
+				_tmp2 = NULL;
+				_tmp1 = NULL;
+				for (node = (_tmp2 = (_tmp1 = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp1), (node == NULL ? NULL : (node = (gee_hash_map_node_free (node), NULL))), _tmp2); node != NULL; node = (_tmp4 = (_tmp3 = next, next = NULL, _tmp3), (node == NULL ? NULL : (node = (gee_hash_map_node_free (node), NULL))), _tmp4)) {
+					GeeHashMapNode* _tmp6;
+					GeeHashMapNode* _tmp5;
 					guint hash_val;
-					GeeHashMapNode* __temp29;
-					GeeHashMapNode* __temp28;
-					GeeHashMapNode* __temp31;
-					GeeHashMapNode* __temp30;
-					__temp27 = NULL;
-					__temp26 = NULL;
-					next = (__temp27 = (__temp26 = node->next, node->next = NULL, __temp26), (next == NULL ? NULL : (next = (gee_hash_map_node_free (next), NULL))), __temp27);
+					GeeHashMapNode* _tmp8;
+					GeeHashMapNode* _tmp7;
+					GeeHashMapNode* _tmp10;
+					GeeHashMapNode* _tmp9;
+					_tmp6 = NULL;
+					_tmp5 = NULL;
+					next = (_tmp6 = (_tmp5 = node->next, node->next = NULL, _tmp5), (next == NULL ? NULL : (next = (gee_hash_map_node_free (next), NULL))), _tmp6);
 					hash_val = node->key_hash % new_array_size;
-					__temp29 = NULL;
-					__temp28 = NULL;
-					node->next = (__temp29 = (__temp28 = new_nodes[hash_val], new_nodes[hash_val] = NULL, __temp28), (node->next == NULL ? NULL : (node->next = (gee_hash_map_node_free (node->next), NULL))), __temp29);
-					__temp31 = NULL;
-					__temp30 = NULL;
-					new_nodes[hash_val] = (__temp31 = (__temp30 = node, node = NULL, __temp30), (new_nodes[hash_val] == NULL ? NULL : (new_nodes[hash_val] = (gee_hash_map_node_free (new_nodes[hash_val]), NULL))), __temp31);
+					_tmp8 = NULL;
+					_tmp7 = NULL;
+					node->next = (_tmp8 = (_tmp7 = new_nodes[hash_val], new_nodes[hash_val] = NULL, _tmp7), (node->next == NULL ? NULL : (node->next = (gee_hash_map_node_free (node->next), NULL))), _tmp8);
+					_tmp10 = NULL;
+					_tmp9 = NULL;
+					new_nodes[hash_val] = (_tmp10 = (_tmp9 = node, node = NULL, _tmp9), (new_nodes[hash_val] == NULL ? NULL : (new_nodes[hash_val] = (gee_hash_map_node_free (new_nodes[hash_val]), NULL))), _tmp10);
 				}
 				(node == NULL ? NULL : (node = (gee_hash_map_node_free (node), NULL)));
 				(next == NULL ? NULL : (next = (gee_hash_map_node_free (next), NULL)));
 			}
 		}
-		__temp33 = NULL;
-		__temp32 = NULL;
-		self->priv->_nodes = (__temp33 = (__temp32 = new_nodes, new_nodes = NULL, __temp32), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_map_node_free)), NULL)), self->priv->_nodes_length1 = new_nodes_length1, __temp33);
+		_tmp12 = NULL;
+		_tmp11 = NULL;
+		self->priv->_nodes = (_tmp12 = (_tmp11 = new_nodes, new_nodes = NULL, _tmp11), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_map_node_free)), NULL)), self->priv->_nodes_length1 = new_nodes_length1, _tmp12);
 		self->priv->_array_size = new_array_size;
 		(new_nodes = (_vala_array_free (new_nodes, new_nodes_length1, ((GDestroyNotify) gee_hash_map_node_free)), NULL));
 	}
@@ -522,15 +523,30 @@ static GObject * gee_hash_map_constructor (GType type, guint n_construct_propert
 	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
 	self = GEE_HASH_MAP (obj);
 	{
-		GeeHashMapNode** __temp35;
+		GeeHashMapNode** _tmp0;
 		self->priv->_array_size = GEE_HASH_MAP_MIN_SIZE;
-		__temp35 = NULL;
-		self->priv->_nodes = (__temp35 = g_new0 (GeeHashMapNode*, self->priv->_array_size), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_map_node_free)), NULL)), self->priv->_nodes_length1 = self->priv->_array_size, __temp35);
+		_tmp0 = NULL;
+		self->priv->_nodes = (_tmp0 = g_new0 (GeeHashMapNode*, self->priv->_array_size + 1), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_map_node_free)), NULL)), self->priv->_nodes_length1 = self->priv->_array_size, _tmp0);
 	}
 	return obj;
 }
 
 
+static GeeHashMapNode* gee_hash_map_node_new (gpointer k, gpointer v, guint hash)
+{
+	GeeHashMapNode* self;
+	gpointer _tmp1;
+	gpointer _tmp0;
+	gpointer _tmp3;
+	gpointer _tmp2;
+	self = g_slice_new0 (GeeHashMapNode);
+	self->key = (_tmp1 = (_tmp0 = k, k = NULL, _tmp0), NULL, _tmp1);
+	self->value = (_tmp3 = (_tmp2 = v, v = NULL, _tmp2), NULL, _tmp3);
+	self->key_hash = hash;
+	return self;
+}
+
+
 static GeeHashMapKeySet* gee_hash_map_key_set_new (GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map)
 {
 	GeeHashMapKeySet * self;
@@ -589,12 +605,12 @@ static gboolean gee_hash_map_key_set_real_contains (GeeCollection* base, gpointe
 
 static void gee_hash_map_key_set_set_map (GeeHashMapKeySet* self, GeeHashMap* value)
 {
-	GeeHashMap* __temp41;
-	GeeHashMap* __temp40;
+	GeeHashMap* _tmp1;
+	GeeHashMap* _tmp0;
 	g_return_if_fail (GEE_HASH_MAP_IS_KEY_SET (self));
-	__temp41 = NULL;
-	__temp40 = NULL;
-	self->priv->_map = (__temp41 = (__temp40 = value, (__temp40 == NULL ? NULL : g_object_ref (__temp40))), (self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL))), __temp41);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->_map = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL))), _tmp1);
 }
 
 
@@ -613,6 +629,9 @@ static void gee_hash_map_key_set_get_property (GObject * object, guint property_
 		case GEE_HASH_MAP_KEY_SET_SIZE:
 		g_value_set_int (value, gee_hash_map_key_set_real_get_size (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -631,6 +650,9 @@ static void gee_hash_map_key_set_set_property (GObject * object, guint property_
 		case GEE_HASH_MAP_KEY_SET_V_DESTROY_FUNC:
 		self->priv->v_destroy_func = g_value_get_pointer (value);
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -693,7 +715,7 @@ static void gee_hash_map_key_set_dispose (GObject * obj)
 }
 
 
-GType gee_hash_map_key_set_get_type (void)
+static GType gee_hash_map_key_set_get_type (void)
 {
 	static GType gee_hash_map_key_set_type_id = 0;
 	if (G_UNLIKELY (gee_hash_map_key_set_type_id == 0)) {
@@ -742,26 +764,38 @@ static gboolean gee_hash_map_key_iterator_real_next (GeeIterator* base)
 static gpointer gee_hash_map_key_iterator_real_get (GeeIterator* base)
 {
 	GeeHashMapKeyIterator * self;
-	gpointer __temp44;
+	gpointer _tmp0;
 	self = ((GeeHashMapKeyIterator*) base);
 	g_assert (self->priv->_stamp == self->priv->_map->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
-	return (__temp44 = self->priv->_node->key, (__temp44 == NULL || self->priv->k_dup_func == NULL ? __temp44 : self->priv->k_dup_func (__temp44)));
+	return (_tmp0 = self->priv->_node->key, (_tmp0 == NULL || self->priv->k_dup_func == NULL ? _tmp0 : self->priv->k_dup_func (_tmp0)));
 }
 
 
 static void gee_hash_map_key_iterator_set_map (GeeHashMapKeyIterator* self, GeeHashMap* value)
 {
-	GeeHashMap* __temp47;
-	GeeHashMap* __temp46;
+	GeeHashMap* _tmp1;
+	GeeHashMap* _tmp0;
 	g_return_if_fail (GEE_HASH_MAP_IS_KEY_ITERATOR (self));
-	__temp47 = NULL;
-	__temp46 = NULL;
-	self->priv->_map = (__temp47 = (__temp46 = value, (__temp46 == NULL ? NULL : g_object_ref (__temp46))), (self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL))), __temp47);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->_map = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL))), _tmp1);
 	self->priv->_stamp = self->priv->_map->priv->_stamp;
 }
 
 
+static void gee_hash_map_key_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
+{
+	GeeHashMapKeyIterator * self;
+	self = GEE_HASH_MAP_KEY_ITERATOR (object);
+	switch (property_id) {
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+
 static void gee_hash_map_key_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
 	GeeHashMapKeyIterator * self;
@@ -776,6 +810,9 @@ static void gee_hash_map_key_iterator_set_property (GObject * object, guint prop
 		case GEE_HASH_MAP_KEY_ITERATOR_V_DESTROY_FUNC:
 		self->priv->v_destroy_func = g_value_get_pointer (value);
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -784,6 +821,7 @@ static void gee_hash_map_key_iterator_class_init (GeeHashMapKeyIteratorClass * k
 {
 	gee_hash_map_key_iterator_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GeeHashMapKeyIteratorPrivate));
+	G_OBJECT_CLASS (klass)->get_property = gee_hash_map_key_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_map_key_iterator_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_hash_map_key_iterator_dispose;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_ITERATOR_K_DUP_FUNC, g_param_spec_pointer ("k-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
@@ -822,7 +860,7 @@ static void gee_hash_map_key_iterator_dispose (GObject * obj)
 }
 
 
-GType gee_hash_map_key_iterator_get_type (void)
+static GType gee_hash_map_key_iterator_get_type (void)
 {
 	static GType gee_hash_map_key_iterator_type_id = 0;
 	if (G_UNLIKELY (gee_hash_map_key_iterator_type_id == 0)) {
@@ -885,30 +923,30 @@ static gboolean gee_hash_map_value_collection_real_contains (GeeCollection* base
 {
 	GeeHashMapValueCollection * self;
 	GeeIterator* it;
-	gboolean __temp52;
+	gboolean _tmp3;
 	self = ((GeeHashMapValueCollection*) base);
 	it = gee_iterable_iterator (GEE_ITERABLE (self));
 	while (gee_iterator_next (it)) {
-		gpointer __temp49;
-		gboolean __temp50;
-		if ((__temp50 = self->priv->_map->priv->_value_equal_func ((__temp49 = gee_iterator_get (it)), value), (__temp49 == NULL || self->priv->v_destroy_func == NULL ? NULL : (__temp49 = (self->priv->v_destroy_func (__temp49), NULL))), __temp50)) {
-			gboolean __temp51;
-			return (__temp51 = TRUE, (it == NULL ? NULL : (it = (g_object_unref (it), NULL))), __temp51);
+		gpointer _tmp0;
+		gboolean _tmp1;
+		if ((_tmp1 = self->priv->_map->priv->_value_equal_func ((_tmp0 = gee_iterator_get (it)), value), (_tmp0 == NULL || self->priv->v_destroy_func == NULL ? NULL : (_tmp0 = (self->priv->v_destroy_func (_tmp0), NULL))), _tmp1)) {
+			gboolean _tmp2;
+			return (_tmp2 = TRUE, (it == NULL ? NULL : (it = (g_object_unref (it), NULL))), _tmp2);
 		}
 	}
-	return (__temp52 = FALSE, (it == NULL ? NULL : (it = (g_object_unref (it), NULL))), __temp52);
+	return (_tmp3 = FALSE, (it == NULL ? NULL : (it = (g_object_unref (it), NULL))), _tmp3);
 	(it == NULL ? NULL : (it = (g_object_unref (it), NULL)));
 }
 
 
 static void gee_hash_map_value_collection_set_map (GeeHashMapValueCollection* self, GeeHashMap* value)
 {
-	GeeHashMap* __temp54;
-	GeeHashMap* __temp53;
+	GeeHashMap* _tmp1;
+	GeeHashMap* _tmp0;
 	g_return_if_fail (GEE_HASH_MAP_IS_VALUE_COLLECTION (self));
-	__temp54 = NULL;
-	__temp53 = NULL;
-	self->priv->_map = (__temp54 = (__temp53 = value, (__temp53 == NULL ? NULL : g_object_ref (__temp53))), (self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL))), __temp54);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->_map = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL))), _tmp1);
 }
 
 
@@ -927,6 +965,9 @@ static void gee_hash_map_value_collection_get_property (GObject * object, guint
 		case GEE_HASH_MAP_VALUE_COLLECTION_SIZE:
 		g_value_set_int (value, gee_hash_map_value_collection_real_get_size (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -945,6 +986,9 @@ static void gee_hash_map_value_collection_set_property (GObject * object, guint
 		case GEE_HASH_MAP_VALUE_COLLECTION_V_DESTROY_FUNC:
 		self->priv->v_destroy_func = g_value_get_pointer (value);
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -1001,7 +1045,7 @@ static void gee_hash_map_value_collection_dispose (GObject * obj)
 }
 
 
-GType gee_hash_map_value_collection_get_type (void)
+static GType gee_hash_map_value_collection_get_type (void)
 {
 	static GType gee_hash_map_value_collection_type_id = 0;
 	if (G_UNLIKELY (gee_hash_map_value_collection_type_id == 0)) {
@@ -1048,26 +1092,38 @@ static gboolean gee_hash_map_value_iterator_real_next (GeeIterator* base)
 static gpointer gee_hash_map_value_iterator_real_get (GeeIterator* base)
 {
 	GeeHashMapValueIterator * self;
-	gpointer __temp57;
+	gpointer _tmp0;
 	self = ((GeeHashMapValueIterator*) base);
 	g_assert (self->priv->_stamp == self->priv->_map->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
-	return (__temp57 = self->priv->_node->value, (__temp57 == NULL || self->priv->v_dup_func == NULL ? __temp57 : self->priv->v_dup_func (__temp57)));
+	return (_tmp0 = self->priv->_node->value, (_tmp0 == NULL || self->priv->v_dup_func == NULL ? _tmp0 : self->priv->v_dup_func (_tmp0)));
 }
 
 
 static void gee_hash_map_value_iterator_set_map (GeeHashMapValueIterator* self, GeeHashMap* value)
 {
-	GeeHashMap* __temp60;
-	GeeHashMap* __temp59;
+	GeeHashMap* _tmp1;
+	GeeHashMap* _tmp0;
 	g_return_if_fail (GEE_HASH_MAP_IS_VALUE_ITERATOR (self));
-	__temp60 = NULL;
-	__temp59 = NULL;
-	self->priv->_map = (__temp60 = (__temp59 = value, (__temp59 == NULL ? NULL : g_object_ref (__temp59))), (self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL))), __temp60);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->_map = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL))), _tmp1);
 	self->priv->_stamp = self->priv->_map->priv->_stamp;
 }
 
 
+static void gee_hash_map_value_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
+{
+	GeeHashMapValueIterator * self;
+	self = GEE_HASH_MAP_VALUE_ITERATOR (object);
+	switch (property_id) {
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+
 static void gee_hash_map_value_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
 	GeeHashMapValueIterator * self;
@@ -1082,6 +1138,9 @@ static void gee_hash_map_value_iterator_set_property (GObject * object, guint pr
 		case GEE_HASH_MAP_VALUE_ITERATOR_V_DESTROY_FUNC:
 		self->priv->v_destroy_func = g_value_get_pointer (value);
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -1090,6 +1149,7 @@ static void gee_hash_map_value_iterator_class_init (GeeHashMapValueIteratorClass
 {
 	gee_hash_map_value_iterator_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GeeHashMapValueIteratorPrivate));
+	G_OBJECT_CLASS (klass)->get_property = gee_hash_map_value_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_map_value_iterator_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_hash_map_value_iterator_dispose;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_ITERATOR_K_DUP_FUNC, g_param_spec_pointer ("k-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
@@ -1128,7 +1188,7 @@ static void gee_hash_map_value_iterator_dispose (GObject * obj)
 }
 
 
-GType gee_hash_map_value_iterator_get_type (void)
+static GType gee_hash_map_value_iterator_get_type (void)
 {
 	static GType gee_hash_map_value_iterator_type_id = 0;
 	if (G_UNLIKELY (gee_hash_map_value_iterator_type_id == 0)) {
@@ -1141,21 +1201,6 @@ GType gee_hash_map_value_iterator_get_type (void)
 }
 
 
-static GeeHashMapNode* gee_hash_map_node_new (gpointer k, gpointer v, guint hash)
-{
-	GeeHashMapNode* self;
-	gpointer __temp62;
-	gpointer __temp61;
-	gpointer __temp64;
-	gpointer __temp63;
-	self = g_slice_new0 (GeeHashMapNode);
-	self->key = (__temp62 = (__temp61 = k, k = NULL, __temp61), NULL, __temp62);
-	self->value = (__temp64 = (__temp63 = v, v = NULL, __temp63), NULL, __temp64);
-	self->key_hash = hash;
-	return self;
-}
-
-
 static void gee_hash_map_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
 	GeeHashMap * self;
@@ -1164,6 +1209,9 @@ static void gee_hash_map_get_property (GObject * object, guint property_id, GVal
 		case GEE_HASH_MAP_SIZE:
 		g_value_set_int (value, gee_hash_map_real_get_size (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -1188,6 +1236,9 @@ static void gee_hash_map_set_property (GObject * object, guint property_id, cons
 		case GEE_HASH_MAP_V_DESTROY_FUNC:
 		self->priv->v_destroy_func = g_value_get_pointer (value);
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -1264,10 +1315,15 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 {
 	if (array != NULL && destroy_func != NULL) {
 		int i;
+		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
 			if (((gpointer*) array)[i] != NULL)
 			destroy_func (((gpointer*) array)[i]);
 		}
+		else
+		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) array)[i]);
+		}
 	}
 	g_free (array);
 }
