@@ -23,11 +23,12 @@
  */
 
 #include "hashset.h"
+#include <gee/hashset.h>
 
+typedef struct _GeeHashSetNode GeeHashSetNode;
 typedef struct _GeeHashSetIterator GeeHashSetIterator;
 typedef struct _GeeHashSetIteratorClass GeeHashSetIteratorClass;
 typedef struct _GeeHashSetIteratorPrivate GeeHashSetIteratorPrivate;
-typedef struct _GeeHashSetNode GeeHashSetNode;
 struct _GeeHashSetPrivate {
 	gint _array_size;
 	gint _nnodes;
@@ -58,6 +59,21 @@ static gboolean gee_hash_set_real_remove (GeeCollection* base, gpointer key);
 static void gee_hash_set_real_clear (GeeCollection* base);
 static void gee_hash_set_resize (GeeHashSet* self);
 static GObject * gee_hash_set_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
+struct _GeeHashSetNode {
+	gpointer key;
+	GeeHashSetNode* next;
+	guint key_hash;
+};
+static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash);
+static void gee_hash_set_node_free (GeeHashSetNode* self);
+static void gee_hash_set_node_free (GeeHashSetNode* self)
+{
+	NULL;
+	(self->next == NULL ? NULL : (self->next = (gee_hash_set_node_free (self->next), NULL)));
+	g_slice_free (GeeHashSetNode, self);
+}
+
+
 
 #define GEE_HASH_SET_TYPE_ITERATOR (gee_hash_set_iterator_get_type ())
 #define GEE_HASH_SET_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_HASH_SET_TYPE_ITERATOR, GeeHashSetIterator))
@@ -95,22 +111,7 @@ static void gee_hash_set_iterator_set_set (GeeHashSetIterator* self, GeeHashSet*
 static gpointer gee_hash_set_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_hash_set_iterator_gee_iterator_parent_iface = NULL;
 static void gee_hash_set_iterator_dispose (GObject * obj);
-GType gee_hash_set_iterator_get_type (void);
-struct _GeeHashSetNode {
-	gpointer key;
-	GeeHashSetNode* next;
-	guint key_hash;
-};
-static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash);
-static void gee_hash_set_node_free (GeeHashSetNode* self);
-static void gee_hash_set_node_free (GeeHashSetNode* self)
-{
-	NULL;
-	(self->next == NULL ? NULL : (self->next = (gee_hash_set_node_free (self->next), NULL)));
-	g_slice_free (GeeHashSetNode, self);
-}
-
-
+static GType gee_hash_set_iterator_get_type (void);
 static gpointer gee_hash_set_parent_class = NULL;
 static GeeIterableIface* gee_hash_set_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_hash_set_gee_collection_parent_iface = NULL;
@@ -173,9 +174,9 @@ static gboolean gee_hash_set_real_add (GeeCollection* base, gpointer key)
 		return FALSE;
 	} else {
 		guint hash_value;
-		gpointer __temp4;
+		gpointer _tmp1;
 		hash_value = self->priv->_hash_func (key);
-		*node = gee_hash_set_node_new ((__temp4 = key, (__temp4 == NULL || self->priv->g_dup_func == NULL ? __temp4 : self->priv->g_dup_func (__temp4))), hash_value);
+		*node = gee_hash_set_node_new ((_tmp1 = key, (_tmp1 == NULL || self->priv->g_dup_func == NULL ? _tmp1 : self->priv->g_dup_func (_tmp1))), hash_value);
 		self->priv->_nnodes++;
 		gee_hash_set_resize (self);
 		self->priv->_stamp++;
@@ -191,8 +192,8 @@ static gboolean gee_hash_set_real_remove (GeeCollection* base, gpointer key)
 	self = ((GeeHashSet*) base);
 	node = gee_hash_set_lookup_node (self, key);
 	if (*node != NULL) {
-		gpointer __temp6;
-		(*node)->key = (__temp6 = NULL, ((*node)->key == NULL || self->priv->g_destroy_func == NULL ? NULL : ((*node)->key = (self->priv->g_destroy_func ((*node)->key), NULL))), __temp6);
+		gpointer _tmp0;
+		(*node)->key = (_tmp0 = NULL, ((*node)->key == NULL || self->priv->g_destroy_func == NULL ? NULL : ((*node)->key = (self->priv->g_destroy_func ((*node)->key), NULL))), _tmp0);
 		*node = (*node)->next;
 		self->priv->_nnodes--;
 		gee_hash_set_resize (self);
@@ -211,22 +212,22 @@ static void gee_hash_set_real_clear (GeeCollection* base)
 		gint i;
 		i = 0;
 		for (i = 0; i < self->priv->_array_size; i++) {
-			GeeHashSetNode* __temp9;
+			GeeHashSetNode* _tmp0;
 			GeeHashSetNode* node;
-			__temp9 = NULL;
-			node = (__temp9 = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, __temp9);
+			_tmp0 = NULL;
+			node = (_tmp0 = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp0);
 			while (node != NULL) {
-				GeeHashSetNode* __temp10;
+				GeeHashSetNode* _tmp1;
 				GeeHashSetNode* next;
-				gpointer __temp11;
-				GeeHashSetNode* __temp13;
-				GeeHashSetNode* __temp12;
-				__temp10 = NULL;
-				next = (__temp10 = node->next, node->next = NULL, __temp10);
-				node->key = (__temp11 = NULL, (node->key == NULL || self->priv->g_destroy_func == NULL ? NULL : (node->key = (self->priv->g_destroy_func (node->key), NULL))), __temp11);
-				__temp13 = NULL;
-				__temp12 = NULL;
-				node = (__temp13 = (__temp12 = next, next = NULL, __temp12), (node == NULL ? NULL : (node = (gee_hash_set_node_free (node), NULL))), __temp13);
+				gpointer _tmp2;
+				GeeHashSetNode* _tmp4;
+				GeeHashSetNode* _tmp3;
+				_tmp1 = NULL;
+				next = (_tmp1 = node->next, node->next = NULL, _tmp1);
+				node->key = (_tmp2 = NULL, (node->key == NULL || self->priv->g_destroy_func == NULL ? NULL : (node->key = (self->priv->g_destroy_func (node->key), NULL))), _tmp2);
+				_tmp4 = NULL;
+				_tmp3 = NULL;
+				node = (_tmp4 = (_tmp3 = next, next = NULL, _tmp3), (node == NULL ? NULL : (node = (gee_hash_set_node_free (node), NULL))), _tmp4);
 				(next == NULL ? NULL : (next = (gee_hash_set_node_free (next), NULL)));
 			}
 			(node == NULL ? NULL : (node = (gee_hash_set_node_free (node), NULL)));
@@ -242,57 +243,57 @@ static void gee_hash_set_resize (GeeHashSet* self)
 	g_return_if_fail (GEE_IS_HASH_SET (self));
 	if ((self->priv->_array_size >= 3 * self->priv->_nnodes && self->priv->_array_size >= GEE_HASH_SET_MIN_SIZE) || (3 * self->priv->_array_size <= self->priv->_nnodes && self->priv->_array_size < GEE_HASH_SET_MAX_SIZE)) {
 		gint new_array_size;
-		GeeHashSetNode** __temp14;
+		GeeHashSetNode** _tmp0;
 		gint new_nodes_length1;
 		GeeHashSetNode** new_nodes;
-		GeeHashSetNode** __temp26;
-		GeeHashSetNode** __temp25;
+		GeeHashSetNode** _tmp12;
+		GeeHashSetNode** _tmp11;
 		new_array_size = g_spaced_primes_closest (self->priv->_nnodes);
 		new_array_size = CLAMP (new_array_size, GEE_HASH_SET_MIN_SIZE, GEE_HASH_SET_MAX_SIZE);
-		__temp14 = NULL;
-		new_nodes = (__temp14 = g_new0 (GeeHashSetNode*, new_array_size), new_nodes_length1 = new_array_size, __temp14);
+		_tmp0 = NULL;
+		new_nodes = (_tmp0 = g_new0 (GeeHashSetNode*, new_array_size + 1), new_nodes_length1 = new_array_size, _tmp0);
 		{
 			gint i;
 			i = 0;
 			for (i = 0; i < self->priv->_array_size; i++) {
 				GeeHashSetNode* node;
 				GeeHashSetNode* next;
-				GeeHashSetNode* __temp18;
-				GeeHashSetNode* __temp17;
-				GeeHashSetNode* __temp16;
-				GeeHashSetNode* __temp15;
+				GeeHashSetNode* _tmp4;
+				GeeHashSetNode* _tmp3;
+				GeeHashSetNode* _tmp2;
+				GeeHashSetNode* _tmp1;
 				node = NULL;
 				next = NULL;
-				__temp18 = NULL;
-				__temp17 = NULL;
-				__temp16 = NULL;
-				__temp15 = NULL;
-				for (node = (__temp16 = (__temp15 = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, __temp15), (node == NULL ? NULL : (node = (gee_hash_set_node_free (node), NULL))), __temp16); node != NULL; node = (__temp18 = (__temp17 = next, next = NULL, __temp17), (node == NULL ? NULL : (node = (gee_hash_set_node_free (node), NULL))), __temp18)) {
-					GeeHashSetNode* __temp20;
-					GeeHashSetNode* __temp19;
+				_tmp4 = NULL;
+				_tmp3 = NULL;
+				_tmp2 = NULL;
+				_tmp1 = NULL;
+				for (node = (_tmp2 = (_tmp1 = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp1), (node == NULL ? NULL : (node = (gee_hash_set_node_free (node), NULL))), _tmp2); node != NULL; node = (_tmp4 = (_tmp3 = next, next = NULL, _tmp3), (node == NULL ? NULL : (node = (gee_hash_set_node_free (node), NULL))), _tmp4)) {
+					GeeHashSetNode* _tmp6;
+					GeeHashSetNode* _tmp5;
 					guint hash_val;
-					GeeHashSetNode* __temp22;
-					GeeHashSetNode* __temp21;
-					GeeHashSetNode* __temp24;
-					GeeHashSetNode* __temp23;
-					__temp20 = NULL;
-					__temp19 = NULL;
-					next = (__temp20 = (__temp19 = node->next, node->next = NULL, __temp19), (next == NULL ? NULL : (next = (gee_hash_set_node_free (next), NULL))), __temp20);
+					GeeHashSetNode* _tmp8;
+					GeeHashSetNode* _tmp7;
+					GeeHashSetNode* _tmp10;
+					GeeHashSetNode* _tmp9;
+					_tmp6 = NULL;
+					_tmp5 = NULL;
+					next = (_tmp6 = (_tmp5 = node->next, node->next = NULL, _tmp5), (next == NULL ? NULL : (next = (gee_hash_set_node_free (next), NULL))), _tmp6);
 					hash_val = node->key_hash % new_array_size;
-					__temp22 = NULL;
-					__temp21 = NULL;
-					node->next = (__temp22 = (__temp21 = new_nodes[hash_val], new_nodes[hash_val] = NULL, __temp21), (node->next == NULL ? NULL : (node->next = (gee_hash_set_node_free (node->next), NULL))), __temp22);
-					__temp24 = NULL;
-					__temp23 = NULL;
-					new_nodes[hash_val] = (__temp24 = (__temp23 = node, node = NULL, __temp23), (new_nodes[hash_val] == NULL ? NULL : (new_nodes[hash_val] = (gee_hash_set_node_free (new_nodes[hash_val]), NULL))), __temp24);
+					_tmp8 = NULL;
+					_tmp7 = NULL;
+					node->next = (_tmp8 = (_tmp7 = new_nodes[hash_val], new_nodes[hash_val] = NULL, _tmp7), (node->next == NULL ? NULL : (node->next = (gee_hash_set_node_free (node->next), NULL))), _tmp8);
+					_tmp10 = NULL;
+					_tmp9 = NULL;
+					new_nodes[hash_val] = (_tmp10 = (_tmp9 = node, node = NULL, _tmp9), (new_nodes[hash_val] == NULL ? NULL : (new_nodes[hash_val] = (gee_hash_set_node_free (new_nodes[hash_val]), NULL))), _tmp10);
 				}
 				(node == NULL ? NULL : (node = (gee_hash_set_node_free (node), NULL)));
 				(next == NULL ? NULL : (next = (gee_hash_set_node_free (next), NULL)));
 			}
 		}
-		__temp26 = NULL;
-		__temp25 = NULL;
-		self->priv->_nodes = (__temp26 = (__temp25 = new_nodes, new_nodes = NULL, __temp25), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_set_node_free)), NULL)), self->priv->_nodes_length1 = new_nodes_length1, __temp26);
+		_tmp12 = NULL;
+		_tmp11 = NULL;
+		self->priv->_nodes = (_tmp12 = (_tmp11 = new_nodes, new_nodes = NULL, _tmp11), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_set_node_free)), NULL)), self->priv->_nodes_length1 = new_nodes_length1, _tmp12);
 		self->priv->_array_size = new_array_size;
 		(new_nodes = (_vala_array_free (new_nodes, new_nodes_length1, ((GDestroyNotify) gee_hash_set_node_free)), NULL));
 	}
@@ -331,15 +332,27 @@ static GObject * gee_hash_set_constructor (GType type, guint n_construct_propert
 	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
 	self = GEE_HASH_SET (obj);
 	{
-		GeeHashSetNode** __temp28;
+		GeeHashSetNode** _tmp0;
 		self->priv->_array_size = GEE_HASH_SET_MIN_SIZE;
-		__temp28 = NULL;
-		self->priv->_nodes = (__temp28 = g_new0 (GeeHashSetNode*, self->priv->_array_size), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_set_node_free)), NULL)), self->priv->_nodes_length1 = self->priv->_array_size, __temp28);
+		_tmp0 = NULL;
+		self->priv->_nodes = (_tmp0 = g_new0 (GeeHashSetNode*, self->priv->_array_size + 1), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_set_node_free)), NULL)), self->priv->_nodes_length1 = self->priv->_array_size, _tmp0);
 	}
 	return obj;
 }
 
 
+static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash)
+{
+	GeeHashSetNode* self;
+	gpointer _tmp1;
+	gpointer _tmp0;
+	self = g_slice_new0 (GeeHashSetNode);
+	self->key = (_tmp1 = (_tmp0 = k, k = NULL, _tmp0), NULL, _tmp1);
+	self->key_hash = hash;
+	return self;
+}
+
+
 static GeeHashSetIterator* gee_hash_set_iterator_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeHashSet* set)
 {
 	GeeHashSetIterator * self;
@@ -370,22 +383,22 @@ static gboolean gee_hash_set_iterator_real_next (GeeIterator* base)
 static gpointer gee_hash_set_iterator_real_get (GeeIterator* base)
 {
 	GeeHashSetIterator * self;
-	gpointer __temp30;
+	gpointer _tmp0;
 	self = ((GeeHashSetIterator*) base);
 	g_assert (self->priv->_stamp == self->priv->_set->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
-	return (__temp30 = self->priv->_node->key, (__temp30 == NULL || self->priv->g_dup_func == NULL ? __temp30 : self->priv->g_dup_func (__temp30)));
+	return (_tmp0 = self->priv->_node->key, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? _tmp0 : self->priv->g_dup_func (_tmp0)));
 }
 
 
 static void gee_hash_set_iterator_set_set (GeeHashSetIterator* self, GeeHashSet* value)
 {
-	GeeHashSet* __temp33;
-	GeeHashSet* __temp32;
+	GeeHashSet* _tmp1;
+	GeeHashSet* _tmp0;
 	g_return_if_fail (GEE_HASH_SET_IS_ITERATOR (self));
-	__temp33 = NULL;
-	__temp32 = NULL;
-	self->priv->_set = (__temp33 = (__temp32 = value, (__temp32 == NULL ? NULL : g_object_ref (__temp32))), (self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL))), __temp33);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->_set = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL))), _tmp1);
 	self->priv->_stamp = self->priv->_set->priv->_stamp;
 	while (self->priv->_node == NULL && self->priv->_index + 1 < self->priv->_set->priv->_array_size) {
 		/* find first node*/
@@ -395,6 +408,18 @@ static void gee_hash_set_iterator_set_set (GeeHashSetIterator* self, GeeHashSet*
 }
 
 
+static void gee_hash_set_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
+{
+	GeeHashSetIterator * self;
+	self = GEE_HASH_SET_ITERATOR (object);
+	switch (property_id) {
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+
 static void gee_hash_set_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
 	GeeHashSetIterator * self;
@@ -406,6 +431,9 @@ static void gee_hash_set_iterator_set_property (GObject * object, guint property
 		case GEE_HASH_SET_ITERATOR_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -414,6 +442,7 @@ static void gee_hash_set_iterator_class_init (GeeHashSetIteratorClass * klass)
 {
 	gee_hash_set_iterator_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GeeHashSetIteratorPrivate));
+	G_OBJECT_CLASS (klass)->get_property = gee_hash_set_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_set_iterator_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_hash_set_iterator_dispose;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
@@ -451,7 +480,7 @@ static void gee_hash_set_iterator_dispose (GObject * obj)
 }
 
 
-GType gee_hash_set_iterator_get_type (void)
+static GType gee_hash_set_iterator_get_type (void)
 {
 	static GType gee_hash_set_iterator_type_id = 0;
 	if (G_UNLIKELY (gee_hash_set_iterator_type_id == 0)) {
@@ -464,18 +493,6 @@ GType gee_hash_set_iterator_get_type (void)
 }
 
 
-static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash)
-{
-	GeeHashSetNode* self;
-	gpointer __temp35;
-	gpointer __temp34;
-	self = g_slice_new0 (GeeHashSetNode);
-	self->key = (__temp35 = (__temp34 = k, k = NULL, __temp34), NULL, __temp35);
-	self->key_hash = hash;
-	return self;
-}
-
-
 static void gee_hash_set_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
 	GeeHashSet * self;
@@ -484,6 +501,9 @@ static void gee_hash_set_get_property (GObject * object, guint property_id, GVal
 		case GEE_HASH_SET_SIZE:
 		g_value_set_int (value, gee_hash_set_real_get_size (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -502,6 +522,9 @@ static void gee_hash_set_set_property (GObject * object, guint property_id, cons
 		case GEE_HASH_SET_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -589,10 +612,15 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 {
 	if (array != NULL && destroy_func != NULL) {
 		int i;
+		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
 			if (((gpointer*) array)[i] != NULL)
 			destroy_func (((gpointer*) array)[i]);
 		}
+		else
+		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) array)[i]);
+		}
 	}
 	g_free (array);
 }
