@@ -21,7 +21,6 @@
  */
 
 #include "valaclassregisterfunction.h"
-#include <vala/valasymbol.h>
 #include <vala/valatypereference.h>
 #include <vala/valainterface.h>
 #include <ccode/valaccodedeclaration.h>
@@ -52,6 +51,7 @@ static char* vala_class_register_function_real_get_instance_struct_size (ValaTyp
 static char* vala_class_register_function_real_get_instance_init_func_name (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_parent_type_name (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_type_flags (ValaTypeRegisterFunction* base);
+static ValaSymbolAccessibility vala_class_register_function_real_get_accessibility (ValaTypeRegisterFunction* base);
 static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_init_declaration (ValaTypeRegisterFunction* base);
 static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_init_statements (ValaTypeRegisterFunction* base);
 static gpointer vala_class_register_function_parent_class = NULL;
@@ -85,12 +85,12 @@ static ValaDataType* vala_class_register_function_real_get_type_declaration (Val
 static char* vala_class_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base)
 {
 	ValaClassRegisterFunction * self;
-	char* __temp1;
-	char* __temp2;
+	char* _tmp0;
+	char* _tmp1;
 	self = ((ValaClassRegisterFunction*) base);
-	__temp1 = NULL;
-	__temp2 = NULL;
-	return (__temp2 = g_strdup_printf ("%sClass", (__temp1 = vala_data_type_get_cname (VALA_DATA_TYPE (vala_class_register_function_get_class_reference (self)), FALSE))), (__temp1 = (g_free (__temp1), NULL)), __temp2);
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_strdup_printf ("%sClass", (_tmp0 = vala_data_type_get_cname (VALA_DATA_TYPE (vala_class_register_function_get_class_reference (self)), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -105,36 +105,36 @@ static char* vala_class_register_function_real_get_base_init_func_name (ValaType
 static char* vala_class_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base)
 {
 	ValaClassRegisterFunction * self;
-	char* __temp5;
-	char* __temp6;
+	char* _tmp0;
+	char* _tmp1;
 	self = ((ValaClassRegisterFunction*) base);
-	__temp5 = NULL;
-	__temp6 = NULL;
-	return (__temp6 = g_strdup_printf ("%s_class_init", (__temp5 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)), NULL))), (__temp5 = (g_free (__temp5), NULL)), __temp6);
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_strdup_printf ("%s_class_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
 static char* vala_class_register_function_real_get_instance_struct_size (ValaTypeRegisterFunction* base)
 {
 	ValaClassRegisterFunction * self;
-	char* __temp8;
-	char* __temp9;
+	char* _tmp0;
+	char* _tmp1;
 	self = ((ValaClassRegisterFunction*) base);
-	__temp8 = NULL;
-	__temp9 = NULL;
-	return (__temp9 = g_strdup_printf ("sizeof (%s)", (__temp8 = vala_data_type_get_cname (VALA_DATA_TYPE (vala_class_register_function_get_class_reference (self)), FALSE))), (__temp8 = (g_free (__temp8), NULL)), __temp9);
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_strdup_printf ("sizeof (%s)", (_tmp0 = vala_data_type_get_cname (VALA_DATA_TYPE (vala_class_register_function_get_class_reference (self)), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
 static char* vala_class_register_function_real_get_instance_init_func_name (ValaTypeRegisterFunction* base)
 {
 	ValaClassRegisterFunction * self;
-	char* __temp11;
-	char* __temp12;
+	char* _tmp0;
+	char* _tmp1;
 	self = ((ValaClassRegisterFunction*) base);
-	__temp11 = NULL;
-	__temp12 = NULL;
-	return (__temp12 = g_strdup_printf ("%s_init", (__temp11 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)), NULL))), (__temp11 = (g_free (__temp11), NULL)), __temp12);
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_strdup_printf ("%s_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -158,6 +158,14 @@ static char* vala_class_register_function_real_get_type_flags (ValaTypeRegisterF
 }
 
 
+static ValaSymbolAccessibility vala_class_register_function_real_get_accessibility (ValaTypeRegisterFunction* base)
+{
+	ValaClassRegisterFunction * self;
+	self = ((ValaClassRegisterFunction*) base);
+	return vala_symbol_get_access (((ValaSymbol*) vala_class_register_function_get_class_reference (self)));
+}
+
+
 static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_init_declaration (ValaTypeRegisterFunction* base)
 {
 	ValaClassRegisterFunction * self;
@@ -173,39 +181,39 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 			ValaTypeReference* base_type;
 			base_type = gee_iterator_get (base_type_it);
 			{
-				ValaInterface* __temp17;
+				ValaInterface* _tmp0;
 				ValaInterface* iface;
-				char* __temp18;
-				char* __temp19;
+				char* _tmp1;
+				char* _tmp2;
 				char* iface_info_name;
 				ValaCCodeDeclaration* ctypedecl;
-				ValaCCodeVariableDeclarator* __temp24;
-				ValaCCodeConstant* __temp23;
-				char* __temp22;
-				char* __temp21;
-				char* __temp20;
+				ValaCCodeVariableDeclarator* _tmp7;
+				ValaCCodeConstant* _tmp6;
+				char* _tmp5;
+				char* _tmp4;
+				char* _tmp3;
 				if (!(VALA_IS_INTERFACE (vala_type_reference_get_data_type (base_type)))) {
 					(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
 					continue;
 				}
-				__temp17 = NULL;
-				iface = (__temp17 = VALA_INTERFACE (vala_type_reference_get_data_type (base_type)), (__temp17 == NULL ? NULL : g_object_ref (__temp17)));
-				__temp18 = NULL;
-				__temp19 = NULL;
-				iface_info_name = (__temp19 = g_strdup_printf ("%s_info", (__temp18 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (iface), NULL))), (__temp18 = (g_free (__temp18), NULL)), __temp19);
+				_tmp0 = NULL;
+				iface = (_tmp0 = VALA_INTERFACE (vala_type_reference_get_data_type (base_type)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+				_tmp1 = NULL;
+				_tmp2 = NULL;
+				iface_info_name = (_tmp2 = g_strdup_printf ("%s_info", (_tmp1 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (iface), NULL))), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
 				ctypedecl = vala_ccode_declaration_new ("const GInterfaceInfo");
 				vala_ccode_declaration_set_modifiers (ctypedecl, VALA_CCODE_MODIFIERS_STATIC);
-				__temp24 = NULL;
-				__temp23 = NULL;
-				__temp22 = NULL;
-				__temp21 = NULL;
-				__temp20 = NULL;
-				vala_ccode_declaration_add_declarator (ctypedecl, VALA_CCODE_DECLARATOR ((__temp24 = vala_ccode_variable_declarator_new_with_initializer (iface_info_name, VALA_CCODE_EXPRESSION ((__temp23 = vala_ccode_constant_new ((__temp22 = g_strdup_printf ("{ (GInterfaceInitFunc) %s_%s_interface_init, (GInterfaceFinalizeFunc) NULL, NULL}", (__temp20 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)), NULL)), (__temp21 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (iface), NULL)))))))))));
-				(__temp24 == NULL ? NULL : (__temp24 = (g_object_unref (__temp24), NULL)));
-				(__temp23 == NULL ? NULL : (__temp23 = (g_object_unref (__temp23), NULL)));
-				(__temp22 = (g_free (__temp22), NULL));
-				(__temp21 = (g_free (__temp21), NULL));
-				(__temp20 = (g_free (__temp20), NULL));
+				_tmp7 = NULL;
+				_tmp6 = NULL;
+				_tmp5 = NULL;
+				_tmp4 = NULL;
+				_tmp3 = NULL;
+				vala_ccode_declaration_add_declarator (ctypedecl, VALA_CCODE_DECLARATOR ((_tmp7 = vala_ccode_variable_declarator_new_with_initializer (iface_info_name, VALA_CCODE_EXPRESSION ((_tmp6 = vala_ccode_constant_new ((_tmp5 = g_strdup_printf ("{ (GInterfaceInitFunc) %s_%s_interface_init, (GInterfaceFinalizeFunc) NULL, NULL}", (_tmp3 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)), NULL)), (_tmp4 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (iface), NULL)))))))))));
+				(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
+				(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
+				(_tmp5 = (g_free (_tmp5), NULL));
+				(_tmp4 = (g_free (_tmp4), NULL));
+				(_tmp3 = (g_free (_tmp3), NULL));
 				vala_ccode_fragment_append (frag, VALA_CCODE_NODE (ctypedecl));
 				(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
 				(iface == NULL ? NULL : (iface = (g_object_unref (iface), NULL)));
@@ -236,54 +244,54 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 			ValaTypeReference* base_type;
 			base_type = gee_iterator_get (base_type_it);
 			{
-				ValaInterface* __temp26;
+				ValaInterface* _tmp0;
 				ValaInterface* iface;
-				char* __temp27;
-				char* __temp28;
+				char* _tmp1;
+				char* _tmp2;
 				char* iface_info_name;
-				ValaCCodeIdentifier* __temp29;
-				ValaCCodeFunctionCall* __temp30;
+				ValaCCodeIdentifier* _tmp3;
+				ValaCCodeFunctionCall* _tmp4;
 				ValaCCodeFunctionCall* reg_call;
-				ValaCCodeIdentifier* __temp33;
-				char* __temp32;
-				char* __temp31;
-				ValaCCodeIdentifier* __temp35;
-				char* __temp34;
-				ValaCCodeIdentifier* __temp37;
-				char* __temp36;
-				ValaCCodeExpressionStatement* __temp38;
+				ValaCCodeIdentifier* _tmp7;
+				char* _tmp6;
+				char* _tmp5;
+				ValaCCodeIdentifier* _tmp9;
+				char* _tmp8;
+				ValaCCodeIdentifier* _tmp11;
+				char* _tmp10;
+				ValaCCodeExpressionStatement* _tmp12;
 				if (!(VALA_IS_INTERFACE (vala_type_reference_get_data_type (base_type)))) {
 					(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
 					continue;
 				}
-				__temp26 = NULL;
-				iface = (__temp26 = VALA_INTERFACE (vala_type_reference_get_data_type (base_type)), (__temp26 == NULL ? NULL : g_object_ref (__temp26)));
-				__temp27 = NULL;
-				__temp28 = NULL;
-				iface_info_name = (__temp28 = g_strdup_printf ("%s_info", (__temp27 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (iface), NULL))), (__temp27 = (g_free (__temp27), NULL)), __temp28);
-				__temp29 = NULL;
-				__temp30 = NULL;
-				reg_call = (__temp30 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((__temp29 = vala_ccode_identifier_new ("g_type_add_interface_static")))), (__temp29 == NULL ? NULL : (__temp29 = (g_object_unref (__temp29), NULL))), __temp30);
-				__temp33 = NULL;
-				__temp32 = NULL;
-				__temp31 = NULL;
-				vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((__temp33 = vala_ccode_identifier_new ((__temp32 = g_strdup_printf ("%s_type_id", (__temp31 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)), NULL))))))));
-				(__temp33 == NULL ? NULL : (__temp33 = (g_object_unref (__temp33), NULL)));
-				(__temp32 = (g_free (__temp32), NULL));
-				(__temp31 = (g_free (__temp31), NULL));
-				__temp35 = NULL;
-				__temp34 = NULL;
-				vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((__temp35 = vala_ccode_identifier_new ((__temp34 = vala_data_type_get_upper_case_cname (VALA_DATA_TYPE (iface), "TYPE_"))))));
-				(__temp35 == NULL ? NULL : (__temp35 = (g_object_unref (__temp35), NULL)));
-				(__temp34 = (g_free (__temp34), NULL));
-				__temp37 = NULL;
-				__temp36 = NULL;
-				vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((__temp37 = vala_ccode_identifier_new ((__temp36 = g_strdup_printf ("&%s", iface_info_name))))));
-				(__temp37 == NULL ? NULL : (__temp37 = (g_object_unref (__temp37), NULL)));
-				(__temp36 = (g_free (__temp36), NULL));
-				__temp38 = NULL;
-				vala_ccode_fragment_append (frag, VALA_CCODE_NODE ((__temp38 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (reg_call)))));
-				(__temp38 == NULL ? NULL : (__temp38 = (g_object_unref (__temp38), NULL)));
+				_tmp0 = NULL;
+				iface = (_tmp0 = VALA_INTERFACE (vala_type_reference_get_data_type (base_type)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+				_tmp1 = NULL;
+				_tmp2 = NULL;
+				iface_info_name = (_tmp2 = g_strdup_printf ("%s_info", (_tmp1 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (iface), NULL))), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
+				_tmp3 = NULL;
+				_tmp4 = NULL;
+				reg_call = (_tmp4 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp3 = vala_ccode_identifier_new ("g_type_add_interface_static")))), (_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL))), _tmp4);
+				_tmp7 = NULL;
+				_tmp6 = NULL;
+				_tmp5 = NULL;
+				vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp7 = vala_ccode_identifier_new ((_tmp6 = g_strdup_printf ("%s_type_id", (_tmp5 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)), NULL))))))));
+				(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
+				(_tmp6 = (g_free (_tmp6), NULL));
+				(_tmp5 = (g_free (_tmp5), NULL));
+				_tmp9 = NULL;
+				_tmp8 = NULL;
+				vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp9 = vala_ccode_identifier_new ((_tmp8 = vala_data_type_get_upper_case_cname (VALA_DATA_TYPE (iface), "TYPE_"))))));
+				(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
+				(_tmp8 = (g_free (_tmp8), NULL));
+				_tmp11 = NULL;
+				_tmp10 = NULL;
+				vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp11 = vala_ccode_identifier_new ((_tmp10 = g_strdup_printf ("&%s", iface_info_name))))));
+				(_tmp11 == NULL ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL)));
+				(_tmp10 = (g_free (_tmp10), NULL));
+				_tmp12 = NULL;
+				vala_ccode_fragment_append (frag, VALA_CCODE_NODE ((_tmp12 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (reg_call)))));
+				(_tmp12 == NULL ? NULL : (_tmp12 = (g_object_unref (_tmp12), NULL)));
 				(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
 				(iface == NULL ? NULL : (iface = (g_object_unref (iface), NULL)));
 				(iface_info_name = (g_free (iface_info_name), NULL));
@@ -320,6 +328,9 @@ static void vala_class_register_function_get_property (GObject * object, guint p
 		case VALA_CLASS_REGISTER_FUNCTION_CLASS_REFERENCE:
 		g_value_set_object (value, vala_class_register_function_get_class_reference (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -332,6 +343,9 @@ static void vala_class_register_function_set_property (GObject * object, guint p
 		case VALA_CLASS_REGISTER_FUNCTION_CLASS_REFERENCE:
 		vala_class_register_function_set_class_reference (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -351,6 +365,7 @@ static void vala_class_register_function_class_init (ValaClassRegisterFunctionCl
 	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_instance_init_func_name = vala_class_register_function_real_get_instance_init_func_name;
 	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_parent_type_name = vala_class_register_function_real_get_parent_type_name;
 	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_flags = vala_class_register_function_real_get_type_flags;
+	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_accessibility = vala_class_register_function_real_get_accessibility;
 	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_declaration = vala_class_register_function_real_get_type_interface_init_declaration;
 	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_statements = vala_class_register_function_real_get_type_interface_init_statements;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_REGISTER_FUNCTION_CLASS_REFERENCE, g_param_spec_object ("class-reference", "foo", "bar", VALA_TYPE_CLASS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
