@@ -28,14 +28,13 @@
 #include <vala/valaarraymovemethod.h>
 #include <vala/valasourcereference.h>
 #include <vala/valaarray.h>
-#include <vala/valafield.h>
-#include <vala/valamemberaccessibility.h>
 #include <vala/valasourcefile.h>
 #include <vala/valacodecontext.h>
-#include <vala/valanamespace.h>
-#include <vala/valatypereference.h>
 #include <vala/valasymbol.h>
 #include <vala/valascope.h>
+#include <vala/valanamespace.h>
+#include <vala/valafield.h>
+#include <vala/valatypereference.h>
 #include <vala/valamethod.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valareport.h>
@@ -65,6 +64,7 @@ static GeeCollection* vala_array_real_get_cheader_filenames (ValaSymbol* base);
 static char* vala_array_real_get_marshaller_type_name (ValaDataType* base);
 static char* vala_array_real_get_get_value_function (ValaDataType* base);
 static char* vala_array_real_get_set_value_function (ValaDataType* base);
+static char* vala_array_real_get_type_id (ValaDataType* base);
 static GObject * vala_array_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_array_parent_class = NULL;
 static void vala_array_dispose (GObject * obj);
@@ -117,30 +117,30 @@ ValaArray* vala_array_new_with_type_parameter (ValaTypeParameter* _element_type_
 static char* vala_array_real_get_cname (ValaDataType* base, gboolean const_type)
 {
 	ValaArray * self;
-	const char* __temp4;
+	const char* _tmp4;
 	self = ((ValaArray*) base);
 	if (self->priv->cname == NULL) {
 		if (vala_array_get_element_type (self) != NULL) {
 			if (vala_data_type_is_reference_type (vala_array_get_element_type (self))) {
-				char* __temp1;
-				char* __temp0;
-				__temp1 = NULL;
-				__temp0 = NULL;
-				self->priv->cname = (__temp1 = g_strdup_printf ("%s*", (__temp0 = vala_data_type_get_cname (vala_array_get_element_type (self), FALSE))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp1);
-				(__temp0 = (g_free (__temp0), NULL));
+				char* _tmp1;
+				char* _tmp0;
+				_tmp1 = NULL;
+				_tmp0 = NULL;
+				self->priv->cname = (_tmp1 = g_strdup_printf ("%s*", (_tmp0 = vala_data_type_get_cname (vala_array_get_element_type (self), FALSE))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
+				(_tmp0 = (g_free (_tmp0), NULL));
 			} else {
-				char* __temp2;
-				__temp2 = NULL;
-				self->priv->cname = (__temp2 = vala_data_type_get_cname (vala_array_get_element_type (self), FALSE), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp2);
+				char* _tmp2;
+				_tmp2 = NULL;
+				self->priv->cname = (_tmp2 = vala_data_type_get_cname (vala_array_get_element_type (self), FALSE), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp2);
 			}
 		} else {
-			char* __temp3;
-			__temp3 = NULL;
-			self->priv->cname = (__temp3 = g_strdup ("gpointer"), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp3);
+			char* _tmp3;
+			_tmp3 = NULL;
+			self->priv->cname = (_tmp3 = g_strdup ("gpointer"), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp3);
 		}
 	}
-	__temp4 = NULL;
-	return (__temp4 = self->priv->cname, (__temp4 == NULL ? NULL : g_strdup (__temp4)));
+	_tmp4 = NULL;
+	return (_tmp4 = self->priv->cname, (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
 }
 
 
@@ -212,106 +212,121 @@ static char* vala_array_real_get_set_value_function (ValaDataType* base)
 }
 
 
+static char* vala_array_real_get_type_id (ValaDataType* base)
+{
+	ValaArray * self;
+	ValaSymbol* _tmp0;
+	gboolean _tmp1;
+	self = ((ValaArray*) base);
+	_tmp0 = NULL;
+	if ((_tmp1 = VALA_SYMBOL (vala_array_get_element_type (self)) == (_tmp0 = vala_scope_lookup (vala_symbol_get_scope (((ValaSymbol*) vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))))), "string")), (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+		return g_strdup ("G_TYPE_STRV");
+	} else {
+		return NULL;
+	}
+}
+
+
 ValaArrayLengthField* vala_array_get_length_field (ValaArray* self)
 {
-	ValaArrayLengthField* __temp18;
+	ValaArrayLengthField* _tmp3;
 	g_return_val_if_fail (VALA_IS_ARRAY (self), NULL);
 	if (self->priv->length_field == NULL) {
-		ValaArrayLengthField* __temp15;
+		ValaArrayLengthField* _tmp0;
 		ValaNamespace* root_symbol;
-		ValaTypeReference* __temp16;
-		ValaDataType* __temp17;
-		__temp15 = NULL;
-		self->priv->length_field = (__temp15 = vala_array_length_field_new (vala_code_node_get_source_reference (((ValaCodeNode*) self))), (self->priv->length_field == NULL ? NULL : (self->priv->length_field = (g_object_unref (self->priv->length_field), NULL))), __temp15);
-		((ValaField*) self->priv->length_field)->access = VALA_MEMBER_ACCESSIBILITY_PUBLIC;
+		ValaTypeReference* _tmp1;
+		ValaDataType* _tmp2;
+		_tmp0 = NULL;
+		self->priv->length_field = (_tmp0 = vala_array_length_field_new (vala_code_node_get_source_reference (((ValaCodeNode*) self))), (self->priv->length_field == NULL ? NULL : (self->priv->length_field = (g_object_unref (self->priv->length_field), NULL))), _tmp0);
+		vala_symbol_set_access (VALA_SYMBOL (self->priv->length_field), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 		root_symbol = g_object_ref (vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))));
-		__temp16 = NULL;
-		vala_field_set_type_reference (VALA_FIELD (self->priv->length_field), (__temp16 = vala_type_reference_new ()));
-		(__temp16 == NULL ? NULL : (__temp16 = (g_object_unref (__temp16), NULL)));
-		__temp17 = NULL;
-		vala_type_reference_set_data_type (vala_field_get_type_reference (((ValaField*) self->priv->length_field)), (__temp17 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (((ValaSymbol*) root_symbol)), "int"))));
-		(__temp17 == NULL ? NULL : (__temp17 = (g_object_unref (__temp17), NULL)));
+		_tmp1 = NULL;
+		vala_field_set_type_reference (VALA_FIELD (self->priv->length_field), (_tmp1 = vala_type_reference_new ()));
+		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
+		_tmp2 = NULL;
+		vala_type_reference_set_data_type (vala_field_get_type_reference (((ValaField*) self->priv->length_field)), (_tmp2 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (((ValaSymbol*) root_symbol)), "int"))));
+		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
 		(root_symbol = (g_object_unref (root_symbol), NULL));
 	}
-	__temp18 = NULL;
-	return (__temp18 = self->priv->length_field, (__temp18 == NULL ? NULL : g_object_ref (__temp18)));
+	_tmp3 = NULL;
+	return (_tmp3 = self->priv->length_field, (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
 }
 
 
 ValaArrayResizeMethod* vala_array_get_resize_method (ValaArray* self)
 {
-	ValaArrayResizeMethod* __temp24;
+	ValaArrayResizeMethod* _tmp4;
 	g_return_val_if_fail (VALA_IS_ARRAY (self), NULL);
 	if (self->priv->resize_method == NULL) {
-		ValaArrayResizeMethod* __temp20;
-		ValaTypeReference* __temp21;
+		ValaArrayResizeMethod* _tmp0;
+		ValaTypeReference* _tmp1;
 		ValaNamespace* root_symbol;
 		ValaTypeReference* int_type;
-		ValaDataType* __temp22;
-		ValaFormalParameter* __temp23;
-		__temp20 = NULL;
-		self->priv->resize_method = (__temp20 = vala_array_resize_method_new (vala_code_node_get_source_reference (((ValaCodeNode*) self))), (self->priv->resize_method == NULL ? NULL : (self->priv->resize_method = (g_object_unref (self->priv->resize_method), NULL))), __temp20);
-		__temp21 = NULL;
-		vala_method_set_return_type (VALA_METHOD (self->priv->resize_method), (__temp21 = vala_type_reference_new ()));
-		(__temp21 == NULL ? NULL : (__temp21 = (g_object_unref (__temp21), NULL)));
-		((ValaMethod*) self->priv->resize_method)->access = VALA_MEMBER_ACCESSIBILITY_PUBLIC;
+		ValaDataType* _tmp2;
+		ValaFormalParameter* _tmp3;
+		_tmp0 = NULL;
+		self->priv->resize_method = (_tmp0 = vala_array_resize_method_new (vala_code_node_get_source_reference (((ValaCodeNode*) self))), (self->priv->resize_method == NULL ? NULL : (self->priv->resize_method = (g_object_unref (self->priv->resize_method), NULL))), _tmp0);
+		_tmp1 = NULL;
+		vala_method_set_return_type (VALA_METHOD (self->priv->resize_method), (_tmp1 = vala_type_reference_new ()));
+		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
+		vala_symbol_set_access (VALA_SYMBOL (self->priv->resize_method), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 		vala_method_set_cname (VALA_METHOD (self->priv->resize_method), "g_renew");
 		root_symbol = g_object_ref (vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))));
 		int_type = vala_type_reference_new ();
-		__temp22 = NULL;
-		vala_type_reference_set_data_type (int_type, (__temp22 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (((ValaSymbol*) root_symbol)), "int"))));
-		(__temp22 == NULL ? NULL : (__temp22 = (g_object_unref (__temp22), NULL)));
-		__temp23 = NULL;
-		vala_method_add_parameter (VALA_METHOD (self->priv->resize_method), (__temp23 = vala_formal_parameter_new ("length", int_type, NULL)));
-		(__temp23 == NULL ? NULL : (__temp23 = (g_object_unref (__temp23), NULL)));
+		_tmp2 = NULL;
+		vala_type_reference_set_data_type (int_type, (_tmp2 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (((ValaSymbol*) root_symbol)), "int"))));
+		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
+		_tmp3 = NULL;
+		vala_method_add_parameter (VALA_METHOD (self->priv->resize_method), (_tmp3 = vala_formal_parameter_new ("length", int_type, NULL)));
+		(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
 		vala_method_set_returns_modified_pointer (VALA_METHOD (self->priv->resize_method), TRUE);
 		(root_symbol = (g_object_unref (root_symbol), NULL));
 		(int_type == NULL ? NULL : (int_type = (g_object_unref (int_type), NULL)));
 	}
-	__temp24 = NULL;
-	return (__temp24 = self->priv->resize_method, (__temp24 == NULL ? NULL : g_object_ref (__temp24)));
+	_tmp4 = NULL;
+	return (_tmp4 = self->priv->resize_method, (_tmp4 == NULL ? NULL : g_object_ref (_tmp4)));
 }
 
 
 ValaArrayMoveMethod* vala_array_get_move_method (ValaArray* self)
 {
-	ValaArrayMoveMethod* __temp32;
+	ValaArrayMoveMethod* _tmp6;
 	g_return_val_if_fail (VALA_IS_ARRAY (self), NULL);
 	if (self->priv->move_method == NULL) {
-		ValaArrayMoveMethod* __temp26;
-		ValaTypeReference* __temp27;
+		ValaArrayMoveMethod* _tmp0;
+		ValaTypeReference* _tmp1;
 		ValaNamespace* root_symbol;
 		ValaTypeReference* int_type;
-		ValaDataType* __temp28;
-		ValaFormalParameter* __temp29;
-		ValaFormalParameter* __temp30;
-		ValaFormalParameter* __temp31;
-		__temp26 = NULL;
-		self->priv->move_method = (__temp26 = vala_array_move_method_new (vala_code_node_get_source_reference (((ValaCodeNode*) self))), (self->priv->move_method == NULL ? NULL : (self->priv->move_method = (g_object_unref (self->priv->move_method), NULL))), __temp26);
-		__temp27 = NULL;
-		vala_method_set_return_type (VALA_METHOD (self->priv->move_method), (__temp27 = vala_type_reference_new ()));
-		(__temp27 == NULL ? NULL : (__temp27 = (g_object_unref (__temp27), NULL)));
-		((ValaMethod*) self->priv->move_method)->access = VALA_MEMBER_ACCESSIBILITY_PUBLIC;
+		ValaDataType* _tmp2;
+		ValaFormalParameter* _tmp3;
+		ValaFormalParameter* _tmp4;
+		ValaFormalParameter* _tmp5;
+		_tmp0 = NULL;
+		self->priv->move_method = (_tmp0 = vala_array_move_method_new (vala_code_node_get_source_reference (((ValaCodeNode*) self))), (self->priv->move_method == NULL ? NULL : (self->priv->move_method = (g_object_unref (self->priv->move_method), NULL))), _tmp0);
+		_tmp1 = NULL;
+		vala_method_set_return_type (VALA_METHOD (self->priv->move_method), (_tmp1 = vala_type_reference_new ()));
+		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
+		vala_symbol_set_access (VALA_SYMBOL (self->priv->move_method), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 		vala_method_set_cname (VALA_METHOD (self->priv->move_method), "_vala_array_move");
 		root_symbol = g_object_ref (vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))));
 		int_type = vala_type_reference_new ();
-		__temp28 = NULL;
-		vala_type_reference_set_data_type (int_type, (__temp28 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (((ValaSymbol*) root_symbol)), "int"))));
-		(__temp28 == NULL ? NULL : (__temp28 = (g_object_unref (__temp28), NULL)));
-		__temp29 = NULL;
-		vala_method_add_parameter (VALA_METHOD (self->priv->move_method), (__temp29 = vala_formal_parameter_new ("src", int_type, NULL)));
-		(__temp29 == NULL ? NULL : (__temp29 = (g_object_unref (__temp29), NULL)));
-		__temp30 = NULL;
-		vala_method_add_parameter (VALA_METHOD (self->priv->move_method), (__temp30 = vala_formal_parameter_new ("dest", int_type, NULL)));
-		(__temp30 == NULL ? NULL : (__temp30 = (g_object_unref (__temp30), NULL)));
-		__temp31 = NULL;
-		vala_method_add_parameter (VALA_METHOD (self->priv->move_method), (__temp31 = vala_formal_parameter_new ("length", int_type, NULL)));
-		(__temp31 == NULL ? NULL : (__temp31 = (g_object_unref (__temp31), NULL)));
+		_tmp2 = NULL;
+		vala_type_reference_set_data_type (int_type, (_tmp2 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (((ValaSymbol*) root_symbol)), "int"))));
+		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
+		_tmp3 = NULL;
+		vala_method_add_parameter (VALA_METHOD (self->priv->move_method), (_tmp3 = vala_formal_parameter_new ("src", int_type, NULL)));
+		(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
+		_tmp4 = NULL;
+		vala_method_add_parameter (VALA_METHOD (self->priv->move_method), (_tmp4 = vala_formal_parameter_new ("dest", int_type, NULL)));
+		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+		_tmp5 = NULL;
+		vala_method_add_parameter (VALA_METHOD (self->priv->move_method), (_tmp5 = vala_formal_parameter_new ("length", int_type, NULL)));
+		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
 		(root_symbol = (g_object_unref (root_symbol), NULL));
 		(int_type == NULL ? NULL : (int_type = (g_object_unref (int_type), NULL)));
 	}
-	__temp32 = NULL;
-	return (__temp32 = self->priv->move_method, (__temp32 == NULL ? NULL : g_object_ref (__temp32)));
+	_tmp6 = NULL;
+	return (_tmp6 = self->priv->move_method, (_tmp6 == NULL ? NULL : g_object_ref (_tmp6)));
 }
 
 
@@ -369,7 +384,7 @@ static GObject * vala_array_constructor (GType type, guint n_construct_propertie
 	self = VALA_ARRAY (obj);
 	{
 		gint i;
-		char* __temp40;
+		char* _tmp3;
 		/* FIXME: this implementation reveals compiler bugs 
 		string commas = "";
 		int i = rank - 1;
@@ -385,26 +400,26 @@ static GObject * vala_array_constructor (GType type, guint n_construct_propertie
 		}
 		i = vala_array_get_rank (self) - 1;
 		if (vala_array_get_element_type (self) != NULL) {
-			char* __temp37;
-			__temp37 = NULL;
-			vala_symbol_set_name (VALA_SYMBOL (self), (__temp37 = g_strdup_printf ("%s[", vala_symbol_get_name (((ValaSymbol*) vala_array_get_element_type (self))))));
-			(__temp37 = (g_free (__temp37), NULL));
+			char* _tmp0;
+			_tmp0 = NULL;
+			vala_symbol_set_name (VALA_SYMBOL (self), (_tmp0 = g_strdup_printf ("%s[", vala_symbol_get_name (((ValaSymbol*) vala_array_get_element_type (self))))));
+			(_tmp0 = (g_free (_tmp0), NULL));
 		} else {
-			char* __temp38;
-			__temp38 = NULL;
-			vala_symbol_set_name (VALA_SYMBOL (self), (__temp38 = g_strdup_printf ("%s[", vala_symbol_get_name (((ValaSymbol*) vala_array_get_element_type_parameter (self))))));
-			(__temp38 = (g_free (__temp38), NULL));
+			char* _tmp1;
+			_tmp1 = NULL;
+			vala_symbol_set_name (VALA_SYMBOL (self), (_tmp1 = g_strdup_printf ("%s[", vala_symbol_get_name (((ValaSymbol*) vala_array_get_element_type_parameter (self))))));
+			(_tmp1 = (g_free (_tmp1), NULL));
 		}
 		while (i > 0) {
-			char* __temp39;
-			__temp39 = NULL;
-			vala_symbol_set_name (VALA_SYMBOL (self), (__temp39 = g_strdup_printf ("%s,", vala_symbol_get_name (((ValaSymbol*) self)))));
-			(__temp39 = (g_free (__temp39), NULL));
+			char* _tmp2;
+			_tmp2 = NULL;
+			vala_symbol_set_name (VALA_SYMBOL (self), (_tmp2 = g_strdup_printf ("%s,", vala_symbol_get_name (((ValaSymbol*) self)))));
+			(_tmp2 = (g_free (_tmp2), NULL));
 			i--;
 		}
-		__temp40 = NULL;
-		vala_symbol_set_name (VALA_SYMBOL (self), (__temp40 = g_strdup_printf ("%s]", vala_symbol_get_name (((ValaSymbol*) self)))));
-		(__temp40 = (g_free (__temp40), NULL));
+		_tmp3 = NULL;
+		vala_symbol_set_name (VALA_SYMBOL (self), (_tmp3 = g_strdup_printf ("%s]", vala_symbol_get_name (((ValaSymbol*) self)))));
+		(_tmp3 = (g_free (_tmp3), NULL));
 	}
 	return obj;
 }
@@ -424,6 +439,9 @@ static void vala_array_get_property (GObject * object, guint property_id, GValue
 		case VALA_ARRAY_RANK:
 		g_value_set_int (value, vala_array_get_rank (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -442,6 +460,9 @@ static void vala_array_set_property (GObject * object, guint property_id, const
 		case VALA_ARRAY_RANK:
 		vala_array_set_rank (self, g_value_get_int (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -463,6 +484,7 @@ static void vala_array_class_init (ValaArrayClass * klass)
 	VALA_DATA_TYPE_CLASS (klass)->get_marshaller_type_name = vala_array_real_get_marshaller_type_name;
 	VALA_DATA_TYPE_CLASS (klass)->get_get_value_function = vala_array_real_get_get_value_function;
 	VALA_DATA_TYPE_CLASS (klass)->get_set_value_function = vala_array_real_get_set_value_function;
+	VALA_DATA_TYPE_CLASS (klass)->get_type_id = vala_array_real_get_type_id;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_ELEMENT_TYPE, g_param_spec_object ("element-type", "foo", "bar", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_ELEMENT_TYPE_PARAMETER, g_param_spec_object ("element-type-parameter", "foo", "bar", VALA_TYPE_TYPE_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_RANK, g_param_spec_int ("rank", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
