@@ -54,7 +54,9 @@ struct _ValaCodeContextClass {
 };
 
 GeeCollection* vala_code_context_get_source_files (ValaCodeContext* self);
+GeeCollection* vala_code_context_get_c_source_files (ValaCodeContext* self);
 void vala_code_context_add_source_file (ValaCodeContext* self, ValaSourceFile* file);
+void vala_code_context_add_c_source_file (ValaCodeContext* self, const char* file);
 GeeCollection* vala_code_context_get_packages (ValaCodeContext* self);
 gboolean vala_code_context_has_package (ValaCodeContext* self, const char* pkg);
 void vala_code_context_add_package (ValaCodeContext* self, const char* pkg);
@@ -74,6 +76,8 @@ gboolean vala_code_context_get_compile_only (ValaCodeContext* self);
 void vala_code_context_set_compile_only (ValaCodeContext* self, gboolean value);
 char* vala_code_context_get_output (ValaCodeContext* self);
 void vala_code_context_set_output (ValaCodeContext* self, const char* value);
+char* vala_code_context_get_directory (ValaCodeContext* self);
+void vala_code_context_set_directory (ValaCodeContext* self, const char* value);
 gboolean vala_code_context_get_debug (ValaCodeContext* self);
 void vala_code_context_set_debug (ValaCodeContext* self, gboolean value);
 gint vala_code_context_get_optlevel (ValaCodeContext* self);
@@ -82,6 +86,10 @@ gboolean vala_code_context_get_thread (ValaCodeContext* self);
 void vala_code_context_set_thread (ValaCodeContext* self, gboolean value);
 ValaMethod* vala_code_context_get_module_init_method (ValaCodeContext* self);
 void vala_code_context_set_module_init_method (ValaCodeContext* self, ValaMethod* value);
+gboolean vala_code_context_get_save_temps (ValaCodeContext* self);
+void vala_code_context_set_save_temps (ValaCodeContext* self, gboolean value);
+gboolean vala_code_context_get_save_csources (ValaCodeContext* self);
+gboolean vala_code_context_get_save_cheaders (ValaCodeContext* self);
 ValaNamespace* vala_code_context_get_root (ValaCodeContext* self);
 GType vala_code_context_get_type (void);
 
