@@ -43,12 +43,14 @@ typedef struct _ValaSourceFile ValaSourceFile;
 typedef struct _ValaSourceFileClass ValaSourceFileClass;
 typedef struct _ValaCodeContext ValaCodeContext;
 typedef struct _ValaCodeContextClass ValaCodeContextClass;
-typedef struct _ValaSymbol ValaSymbol;
-typedef struct _ValaSymbolClass ValaSymbolClass;
 typedef struct _ValaMethod ValaMethod;
 typedef struct _ValaMethodClass ValaMethodClass;
 typedef struct _ValaMember ValaMember;
 typedef struct _ValaMemberClass ValaMemberClass;
+typedef struct _ValaSymbol ValaSymbol;
+typedef struct _ValaSymbolClass ValaSymbolClass;
+typedef struct _ValaScope ValaScope;
+typedef struct _ValaScopeClass ValaScopeClass;
 typedef struct _ValaInvokable ValaInvokable;
 typedef struct _ValaInvokableIface ValaInvokableIface;
 typedef struct _ValaTypeReference ValaTypeReference;
@@ -57,66 +59,62 @@ typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 typedef struct _ValaDataType ValaDataType;
 typedef struct _ValaDataTypeClass ValaDataTypeClass;
-typedef struct _ValaNamespace ValaNamespace;
-typedef struct _ValaNamespaceClass ValaNamespaceClass;
-typedef struct _ValaClass ValaClass;
-typedef struct _ValaClassClass ValaClassClass;
-typedef struct _ValaTypeParameter ValaTypeParameter;
-typedef struct _ValaTypeParameterClass ValaTypeParameterClass;
+typedef struct _ValaPointer ValaPointer;
+typedef struct _ValaPointerClass ValaPointerClass;
 typedef struct _ValaArray ValaArray;
 typedef struct _ValaArrayClass ValaArrayClass;
+typedef struct _ValaTypeParameter ValaTypeParameter;
+typedef struct _ValaTypeParameterClass ValaTypeParameterClass;
 typedef struct _ValaArrayLengthField ValaArrayLengthField;
 typedef struct _ValaArrayLengthFieldClass ValaArrayLengthFieldClass;
 typedef struct _ValaField ValaField;
 typedef struct _ValaFieldClass ValaFieldClass;
-typedef struct _ValaAttribute ValaAttribute;
-typedef struct _ValaAttributeClass ValaAttributeClass;
-typedef struct _ValaNamedArgument ValaNamedArgument;
-typedef struct _ValaNamedArgumentClass ValaNamedArgumentClass;
 typedef struct _ValaArrayResizeMethod ValaArrayResizeMethod;
 typedef struct _ValaArrayResizeMethodClass ValaArrayResizeMethodClass;
+typedef struct _ValaArrayMoveMethod ValaArrayMoveMethod;
+typedef struct _ValaArrayMoveMethodClass ValaArrayMoveMethodClass;
+typedef struct _ValaFormalParameter ValaFormalParameter;
+typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
+typedef struct _ValaBlock ValaBlock;
+typedef struct _ValaBlockClass ValaBlockClass;
+typedef struct _ValaStatement ValaStatement;
+typedef struct _ValaStatementIface ValaStatementIface;
+typedef struct _ValaVariableDeclarator ValaVariableDeclarator;
+typedef struct _ValaVariableDeclaratorClass ValaVariableDeclaratorClass;
+typedef struct _ValaNamespace ValaNamespace;
+typedef struct _ValaNamespaceClass ValaNamespaceClass;
+typedef struct _ValaClass ValaClass;
+typedef struct _ValaClassClass ValaClassClass;
 typedef struct _ValaConstant ValaConstant;
 typedef struct _ValaConstantClass ValaConstantClass;
 typedef struct _ValaProperty ValaProperty;
 typedef struct _ValaPropertyClass ValaPropertyClass;
 typedef struct _ValaPropertyAccessor ValaPropertyAccessor;
 typedef struct _ValaPropertyAccessorClass ValaPropertyAccessorClass;
-typedef struct _ValaStatement ValaStatement;
-typedef struct _ValaStatementClass ValaStatementClass;
-typedef struct _ValaFormalParameter ValaFormalParameter;
-typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
 typedef struct _ValaSignal ValaSignal;
 typedef struct _ValaSignalClass ValaSignalClass;
 typedef struct _ValaCallback ValaCallback;
 typedef struct _ValaCallbackClass ValaCallbackClass;
+typedef struct _ValaStruct ValaStruct;
+typedef struct _ValaStructClass ValaStructClass;
 typedef struct _ValaConstructor ValaConstructor;
 typedef struct _ValaConstructorClass ValaConstructorClass;
 typedef struct _ValaDestructor ValaDestructor;
 typedef struct _ValaDestructorClass ValaDestructorClass;
 typedef struct _ValaInterface ValaInterface;
 typedef struct _ValaInterfaceClass ValaInterfaceClass;
-typedef struct _ValaStruct ValaStruct;
-typedef struct _ValaStructClass ValaStructClass;
 typedef struct _ValaEnum ValaEnum;
 typedef struct _ValaEnumClass ValaEnumClass;
 typedef struct _ValaEnumValue ValaEnumValue;
 typedef struct _ValaEnumValueClass ValaEnumValueClass;
-typedef struct _ValaFlags ValaFlags;
-typedef struct _ValaFlagsClass ValaFlagsClass;
-typedef struct _ValaFlagsValue ValaFlagsValue;
-typedef struct _ValaFlagsValueClass ValaFlagsValueClass;
-typedef struct _ValaPointer ValaPointer;
-typedef struct _ValaPointerClass ValaPointerClass;
-typedef struct _ValaBlock ValaBlock;
-typedef struct _ValaBlockClass ValaBlockClass;
-typedef struct _ValaVariableDeclarator ValaVariableDeclarator;
-typedef struct _ValaVariableDeclaratorClass ValaVariableDeclaratorClass;
 typedef struct _ValaNamespaceReference ValaNamespaceReference;
 typedef struct _ValaNamespaceReferenceClass ValaNamespaceReferenceClass;
 typedef struct _ValaSourceFileCycle ValaSourceFileCycle;
 typedef struct _ValaSourceFileCycleClass ValaSourceFileCycleClass;
 typedef struct _ValaCreationMethod ValaCreationMethod;
 typedef struct _ValaCreationMethodClass ValaCreationMethodClass;
+typedef struct _ValaNamedArgument ValaNamedArgument;
+typedef struct _ValaNamedArgumentClass ValaNamedArgumentClass;
 typedef struct _ValaEmptyStatement ValaEmptyStatement;
 typedef struct _ValaEmptyStatementClass ValaEmptyStatementClass;
 typedef struct _ValaDeclarationStatement ValaDeclarationStatement;
@@ -211,6 +209,8 @@ typedef struct _ValaLambdaExpression ValaLambdaExpression;
 typedef struct _ValaLambdaExpressionClass ValaLambdaExpressionClass;
 typedef struct _ValaAssignment ValaAssignment;
 typedef struct _ValaAssignmentClass ValaAssignmentClass;
+typedef struct _ValaAttribute ValaAttribute;
+typedef struct _ValaAttributeClass ValaAttributeClass;
 
 #define VALA_TYPE_CODE_NODE (vala_code_node_get_type ())
 #define VALA_CODE_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CODE_NODE, ValaCodeNode))
@@ -247,8 +247,6 @@ ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* nam
 char* vala_code_node_to_string (ValaCodeNode* self);
 ValaCodeNode* vala_code_node_get_parent_node (ValaCodeNode* self);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
-ValaSymbol* vala_code_node_get_symbol (ValaCodeNode* self);
-void vala_code_node_set_symbol (ValaCodeNode* self, ValaSymbol* value);
 ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaCCodeNode* vala_code_node_get_ccodenode (ValaCodeNode* self);
@@ -257,7 +255,7 @@ gboolean vala_code_node_get_error (ValaCodeNode* self);
 void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
 gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self);
 void vala_code_node_set_tree_can_fail (ValaCodeNode* self, gboolean value);
-GType vala_code_node_get_type ();
+GType vala_code_node_get_type (void);
 
 G_END_DECLS
 
