@@ -24,8 +24,8 @@
 #include <vala/valatypereference.h>
 #include <vala/valaexpression.h>
 #include <vala/valasourcereference.h>
-#include <vala/valasymbol.h>
 #include <vala/valaconstant.h>
+#include <vala/valasymbol.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaConstantPrivate {
@@ -103,30 +103,30 @@ static void vala_constant_real_accept_children (ValaCodeNode* base, ValaCodeVisi
  */
 char* vala_constant_get_cname (ValaConstant* self)
 {
-	const char* __temp5;
+	const char* _tmp5;
 	g_return_val_if_fail (VALA_IS_CONSTANT (self), NULL);
 	if (self->priv->cname == NULL) {
 		if (vala_symbol_get_parent_symbol (((ValaSymbol*) self)) == NULL) {
-			char* __temp1;
-			const char* __temp0;
+			char* _tmp1;
+			const char* _tmp0;
 			/* global constant*/
-			__temp1 = NULL;
-			__temp0 = NULL;
-			self->priv->cname = (__temp1 = (__temp0 = vala_symbol_get_name (((ValaSymbol*) self)), (__temp0 == NULL ? NULL : g_strdup (__temp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp1);
+			_tmp1 = NULL;
+			_tmp0 = NULL;
+			self->priv->cname = (_tmp1 = (_tmp0 = vala_symbol_get_name (((ValaSymbol*) self)), (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
 		} else {
-			char* __temp4;
-			char* __temp3;
-			char* __temp2;
-			__temp4 = NULL;
-			__temp3 = NULL;
-			__temp2 = NULL;
-			self->priv->cname = (__temp4 = g_strdup_printf ("%s%s", (__temp3 = g_utf8_strup ((__temp2 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), -1)), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp4);
-			(__temp3 = (g_free (__temp3), NULL));
-			(__temp2 = (g_free (__temp2), NULL));
+			char* _tmp4;
+			char* _tmp3;
+			char* _tmp2;
+			_tmp4 = NULL;
+			_tmp3 = NULL;
+			_tmp2 = NULL;
+			self->priv->cname = (_tmp4 = g_strdup_printf ("%s%s", (_tmp3 = g_utf8_strup ((_tmp2 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), -1)), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp4);
+			(_tmp3 = (g_free (_tmp3), NULL));
+			(_tmp2 = (g_free (_tmp2), NULL));
 		}
 	}
-	__temp5 = NULL;
-	return (__temp5 = self->priv->cname, (__temp5 == NULL ? NULL : g_strdup (__temp5)));
+	_tmp5 = NULL;
+	return (_tmp5 = self->priv->cname, (_tmp5 == NULL ? NULL : g_strdup (_tmp5)));
 }
 
 
@@ -155,10 +155,10 @@ ValaTypeReference* vala_constant_get_type_reference (ValaConstant* self)
 
 void vala_constant_set_type_reference (ValaConstant* self, ValaTypeReference* value)
 {
-	ValaTypeReference* __temp9;
+	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_CONSTANT (self));
-	__temp9 = NULL;
-	self->priv->_type_reference = (__temp9 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp9);
+	_tmp1 = NULL;
+	self->priv->_type_reference = (_tmp1 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp1);
 }
 
 
@@ -171,12 +171,12 @@ ValaExpression* vala_constant_get_initializer (ValaConstant* self)
 
 void vala_constant_set_initializer (ValaConstant* self, ValaExpression* value)
 {
-	ValaExpression* __temp12;
-	ValaExpression* __temp11;
+	ValaExpression* _tmp2;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CONSTANT (self));
-	__temp12 = NULL;
-	__temp11 = NULL;
-	self->priv->_initializer = (__temp12 = (__temp11 = value, (__temp11 == NULL ? NULL : g_object_ref (__temp11))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL))), __temp12);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL))), _tmp2);
 }
 
 
@@ -191,6 +191,9 @@ static void vala_constant_get_property (GObject * object, guint property_id, GVa
 		case VALA_CONSTANT_INITIALIZER:
 		g_value_set_object (value, vala_constant_get_initializer (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -206,6 +209,9 @@ static void vala_constant_set_property (GObject * object, guint property_id, con
 		case VALA_CONSTANT_INITIALIZER:
 		vala_constant_set_initializer (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
