@@ -1,6 +1,6 @@
 /* valacreationmethod.vala
  *
- * Copyright (C) 2007  Raffaele Sandrini
+ * Copyright (C) 2007  Raffaele Sandrini, Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,15 +17,17 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  *
  * Author:
- * 	Raffaele Sandrini <j@bitron.ch>
+ *	Raffaele Sandrini <rasa@gmx.ch>
+ * 	Jürg Billeter <j@bitron.ch>
  */
 
 #include "valacreationmethod.h"
 #include <vala/valasourcereference.h>
+#include <vala/valacreationmethod.h>
 #include <vala/valasymbol.h>
 #include <vala/valacodevisitor.h>
-#include <vala/valacreationmethod.h>
 #include <vala/valaformalparameter.h>
+#include <vala/valatypereference.h>
 #include <vala/valablock.h>
 #include <vala/valadatatype.h>
 
@@ -92,6 +94,22 @@ static void vala_creation_method_real_accept_children (ValaCodeNode* base, ValaC
 		(param_collection == NULL ? NULL : (param_collection = (g_object_unref (param_collection), NULL)));
 		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
+	{
+		GeeCollection* error_domain_collection;
+		GeeIterator* error_domain_it;
+		error_domain_collection = vala_method_get_error_domains (VALA_METHOD (self));
+		error_domain_it = gee_iterable_iterator (GEE_ITERABLE (error_domain_collection));
+		while (gee_iterator_next (error_domain_it)) {
+			ValaTypeReference* error_domain;
+			error_domain = gee_iterator_get (error_domain_it);
+			{
+				vala_code_node_accept (VALA_CODE_NODE (error_domain), visitor);
+				(error_domain == NULL ? NULL : (error_domain = (g_object_unref (error_domain), NULL)));
+			}
+		}
+		(error_domain_collection == NULL ? NULL : (error_domain_collection = (g_object_unref (error_domain_collection), NULL)));
+		(error_domain_it == NULL ? NULL : (error_domain_it = (g_object_unref (error_domain_it), NULL)));
+	}
 	if (vala_method_get_body (((ValaMethod*) self)) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_method_get_body (((ValaMethod*) self))), visitor);
 	}
@@ -101,28 +119,28 @@ static void vala_creation_method_real_accept_children (ValaCodeNode* base, ValaC
 static char* vala_creation_method_real_get_default_cname (ValaMethod* base)
 {
 	ValaCreationMethod * self;
-	ValaSymbol* __temp0;
+	ValaSymbol* _tmp0;
 	ValaSymbol* parent;
 	self = ((ValaCreationMethod*) base);
-	__temp0 = NULL;
-	parent = (__temp0 = vala_symbol_get_parent_symbol (((ValaSymbol*) self)), (__temp0 == NULL ? NULL : g_object_ref (__temp0)));
+	_tmp0 = NULL;
+	parent = (_tmp0 = vala_symbol_get_parent_symbol (((ValaSymbol*) self)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 	g_assert (VALA_IS_DATA_TYPE (parent));
 	if (vala_symbol_get_name (((ValaSymbol*) self)) == NULL) {
-		char* __temp1;
-		char* __temp2;
-		char* __temp3;
-		__temp1 = NULL;
-		__temp2 = NULL;
-		__temp3 = NULL;
-		return (__temp3 = (__temp2 = g_strdup_printf ("%snew", (__temp1 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL ((VALA_DATA_TYPE (parent)))))), (__temp1 = (g_free (__temp1), NULL)), __temp2), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), __temp3);
+		char* _tmp1;
+		char* _tmp2;
+		char* _tmp3;
+		_tmp1 = NULL;
+		_tmp2 = NULL;
+		_tmp3 = NULL;
+		return (_tmp3 = (_tmp2 = g_strdup_printf ("%snew", (_tmp1 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL ((VALA_DATA_TYPE (parent)))))), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), _tmp3);
 	} else {
-		char* __temp4;
-		char* __temp5;
-		char* __temp6;
-		__temp4 = NULL;
-		__temp5 = NULL;
-		__temp6 = NULL;
-		return (__temp6 = (__temp5 = g_strdup_printf ("%snew_%s", (__temp4 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL ((VALA_DATA_TYPE (parent))))), vala_symbol_get_name (((ValaSymbol*) self))), (__temp4 = (g_free (__temp4), NULL)), __temp5), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), __temp6);
+		char* _tmp4;
+		char* _tmp5;
+		char* _tmp6;
+		_tmp4 = NULL;
+		_tmp5 = NULL;
+		_tmp6 = NULL;
+		return (_tmp6 = (_tmp5 = g_strdup_printf ("%snew_%s", (_tmp4 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL ((VALA_DATA_TYPE (parent))))), vala_symbol_get_name (((ValaSymbol*) self))), (_tmp4 = (g_free (_tmp4), NULL)), _tmp5), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), _tmp6);
 	}
 	(parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL)));
 }
@@ -150,6 +168,9 @@ static void vala_creation_method_get_property (GObject * object, guint property_
 		case VALA_CREATION_METHOD_N_CONSTRUCTION_PARAMS:
 		g_value_set_int (value, vala_creation_method_get_n_construction_params (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -162,6 +183,9 @@ static void vala_creation_method_set_property (GObject * object, guint property_
 		case VALA_CREATION_METHOD_N_CONSTRUCTION_PARAMS:
 		vala_creation_method_set_n_construction_params (self, g_value_get_int (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
