@@ -1,6 +1,6 @@
 /* valacreationmethod.vala
  *
- * Copyright (C) 2007  Raffaele Sandrini
+ * Copyright (C) 2007  Raffaele Sandrini, Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,12 +17,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  *
  * Author:
- * 	Raffaele Sandrini <j@bitron.ch>
+ *	Raffaele Sandrini <rasa@gmx.ch>
+ * 	Jürg Billeter <j@bitron.ch>
  */
 
 #ifndef __VALACREATIONMETHOD_H__
 #define __VALACREATIONMETHOD_H__
-typedef struct _ValaCreationMethodPrivate ValaCreationMethodPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -41,6 +41,7 @@ G_BEGIN_DECLS
 #define VALA_IS_CREATION_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CREATION_METHOD))
 #define VALA_CREATION_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CREATION_METHOD, ValaCreationMethodClass))
 
+typedef struct _ValaCreationMethodPrivate ValaCreationMethodPrivate;
 
 /**
  * Represents a type creation method.
@@ -56,7 +57,7 @@ struct _ValaCreationMethodClass {
 ValaCreationMethod* vala_creation_method_new (const char* name, ValaSourceReference* source_reference);
 gint vala_creation_method_get_n_construction_params (ValaCreationMethod* self);
 void vala_creation_method_set_n_construction_params (ValaCreationMethod* self, gint value);
-GType vala_creation_method_get_type ();
+GType vala_creation_method_get_type (void);
 
 G_END_DECLS
 
