@@ -28,8 +28,9 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/collection.h>
+#include <vala/valasymbol.h>
 #include <vala/valacodenode.h>
-#include <vala/valamemberaccessibility.h>
 
 G_BEGIN_DECLS
 
@@ -48,13 +49,11 @@ typedef struct _ValaDataTypePrivate ValaDataTypePrivate;
  * code or imported from an external library with a Vala API file.
  */
 struct _ValaDataType {
-	ValaCodeNode parent;
+	ValaSymbol parent;
 	ValaDataTypePrivate * priv;
-	ValaMemberAccessibility access;
-	ValaNamespace* namespace;
 };
 struct _ValaDataTypeClass {
-	ValaCodeNodeClass parent;
+	ValaSymbolClass parent;
 	char* (*get_cname) (ValaDataType* self, gboolean const_type);
 	gboolean (*is_reference_type) (ValaDataType* self);
 	char* (*get_dup_function) (ValaDataType* self);
@@ -67,10 +66,7 @@ struct _ValaDataTypeClass {
 	char* (*get_get_value_function) (ValaDataType* self);
 	char* (*get_set_value_function) (ValaDataType* self);
 	char* (*get_upper_case_cname) (ValaDataType* self, const char* infix);
-	char* (*get_lower_case_cname) (ValaDataType* self, const char* infix);
-	char* (*get_lower_case_cprefix) (ValaDataType* self);
 	char* (*get_default_value) (ValaDataType* self);
-	GList* (*get_cheader_filenames) (ValaDataType* self);
 	gboolean (*is_subtype_of) (ValaDataType* self, ValaDataType* t);
 	gint (*get_type_parameter_index) (ValaDataType* self, const char* name);
 };
@@ -87,18 +83,13 @@ char* vala_data_type_get_marshaller_type_name (ValaDataType* self);
 char* vala_data_type_get_get_value_function (ValaDataType* self);
 char* vala_data_type_get_set_value_function (ValaDataType* self);
 char* vala_data_type_get_upper_case_cname (ValaDataType* self, const char* infix);
-char* vala_data_type_get_lower_case_cname (ValaDataType* self, const char* infix);
-char* vala_data_type_get_lower_case_cprefix (ValaDataType* self);
 char* vala_data_type_get_default_value (ValaDataType* self);
-GList* vala_data_type_get_cheader_filenames (ValaDataType* self);
 void vala_data_type_add_cheader_filename (ValaDataType* self, const char* filename);
 ValaPointer* vala_data_type_get_pointer (ValaDataType* self);
 ValaArray* vala_data_type_get_array (ValaDataType* self, gint rank);
 gboolean vala_data_type_is_subtype_of (ValaDataType* self, ValaDataType* t);
 gint vala_data_type_get_type_parameter_index (ValaDataType* self, const char* name);
-char* vala_data_type_get_name (ValaDataType* self);
-void vala_data_type_set_name (ValaDataType* self, const char* value);
-GType vala_data_type_get_type ();
+GType vala_data_type_get_type (void);
 
 G_END_DECLS
 
