@@ -23,8 +23,8 @@
 #include "valadestructor.h"
 #include <vala/valablock.h>
 #include <vala/valasourcereference.h>
-#include <vala/valacodevisitor.h>
 #include <vala/valadestructor.h>
+#include <vala/valacodevisitor.h>
 
 struct _ValaDestructorPrivate {
 	ValaBlock* _body;
@@ -87,12 +87,12 @@ ValaBlock* vala_destructor_get_body (ValaDestructor* self)
 
 void vala_destructor_set_body (ValaDestructor* self, ValaBlock* value)
 {
-	ValaBlock* __temp2;
-	ValaBlock* __temp1;
+	ValaBlock* _tmp2;
+	ValaBlock* _tmp1;
 	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
-	__temp2 = NULL;
-	__temp1 = NULL;
-	self->priv->_body = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp2);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
 }
 
 
@@ -121,6 +121,9 @@ static void vala_destructor_get_property (GObject * object, guint property_id, G
 		case VALA_DESTRUCTOR_INSTANCE:
 		g_value_set_boolean (value, vala_destructor_get_instance (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -136,6 +139,9 @@ static void vala_destructor_set_property (GObject * object, guint property_id, c
 		case VALA_DESTRUCTOR_INSTANCE:
 		vala_destructor_set_instance (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
