@@ -25,9 +25,9 @@
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
 #include <vala/valasourcereference.h>
+#include <vala/valaenum.h>
 #include <vala/valasymbol.h>
 #include <vala/valaenumvalue.h>
-#include <vala/valaenum.h>
 #include <vala/valascope.h>
 #include <vala/valamethod.h>
 #include <vala/valacreationmethod.h>
@@ -68,6 +68,7 @@ static char* vala_enum_real_get_set_value_function (ValaDataType* base);
 static char* vala_enum_real_get_default_value (ValaDataType* base);
 static gpointer vala_enum_parent_class = NULL;
 static void vala_enum_dispose (GObject * obj);
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
 /**
@@ -118,13 +119,13 @@ void vala_enum_add_method (ValaEnum* self, ValaMethod* m)
 		return;
 	}
 	if (vala_method_get_instance (m)) {
-		ValaFormalParameter* __temp1;
-		ValaTypeReference* __temp0;
-		__temp1 = NULL;
-		__temp0 = NULL;
-		vala_method_set_this_parameter (m, (__temp1 = vala_formal_parameter_new ("this", (__temp0 = vala_type_reference_new ()), NULL)));
-		(__temp1 == NULL ? NULL : (__temp1 = (g_object_unref (__temp1), NULL)));
-		(__temp0 == NULL ? NULL : (__temp0 = (g_object_unref (__temp0), NULL)));
+		ValaFormalParameter* _tmp1;
+		ValaTypeReference* _tmp0;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		vala_method_set_this_parameter (m, (_tmp1 = vala_formal_parameter_new ("this", (_tmp0 = vala_type_reference_new ()), NULL)));
+		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
+		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 		vala_type_reference_set_data_type (vala_formal_parameter_get_type_reference (vala_method_get_this_parameter (m)), VALA_DATA_TYPE (self));
 		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) m)), vala_symbol_get_name (((ValaSymbol*) vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
 	}
@@ -195,83 +196,79 @@ static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor*
 static char* vala_enum_real_get_cname (ValaDataType* base, gboolean const_type)
 {
 	ValaEnum * self;
-	const char* __temp5;
+	const char* _tmp2;
 	self = ((ValaEnum*) base);
 	if (self->priv->cname == NULL) {
-		char* __temp4;
-		char* __temp3;
-		__temp4 = NULL;
-		__temp3 = NULL;
-		self->priv->cname = (__temp4 = g_strdup_printf ("%s%s", (__temp3 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp4);
-		(__temp3 = (g_free (__temp3), NULL));
+		char* _tmp1;
+		char* _tmp0;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		self->priv->cname = (_tmp1 = g_strdup_printf ("%s%s", (_tmp0 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
+		(_tmp0 = (g_free (_tmp0), NULL));
 	}
-	__temp5 = NULL;
-	return (__temp5 = self->priv->cname, (__temp5 == NULL ? NULL : g_strdup (__temp5)));
+	_tmp2 = NULL;
+	return (_tmp2 = self->priv->cname, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
 }
 
 
 static char* vala_enum_real_get_lower_case_cprefix (ValaSymbol* base)
 {
 	ValaEnum * self;
-	const char* __temp9;
+	const char* _tmp2;
 	self = ((ValaEnum*) base);
 	if (self->priv->lower_case_cprefix == NULL) {
-		char* __temp8;
-		char* __temp7;
-		__temp8 = NULL;
-		__temp7 = NULL;
-		self->priv->lower_case_cprefix = (__temp8 = g_strdup_printf ("%s_", (__temp7 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self), NULL))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), __temp8);
-		(__temp7 = (g_free (__temp7), NULL));
+		char* _tmp1;
+		char* _tmp0;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		self->priv->lower_case_cprefix = (_tmp1 = g_strdup_printf ("%s_", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self), NULL))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp1);
+		(_tmp0 = (g_free (_tmp0), NULL));
 	}
-	__temp9 = NULL;
-	return (__temp9 = self->priv->lower_case_cprefix, (__temp9 == NULL ? NULL : g_strdup (__temp9)));
+	_tmp2 = NULL;
+	return (_tmp2 = self->priv->lower_case_cprefix, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
 }
 
 
 static char* vala_enum_get_lower_case_csuffix (ValaEnum* self)
 {
-	const char* __temp12;
+	const char* _tmp1;
 	g_return_val_if_fail (VALA_IS_ENUM (self), NULL);
 	if (self->priv->lower_case_csuffix == NULL) {
-		char* __temp11;
-		__temp11 = NULL;
-		self->priv->lower_case_csuffix = (__temp11 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), __temp11);
+		char* _tmp0;
+		_tmp0 = NULL;
+		self->priv->lower_case_csuffix = (_tmp0 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), _tmp0);
 	}
-	__temp12 = NULL;
-	return (__temp12 = self->priv->lower_case_csuffix, (__temp12 == NULL ? NULL : g_strdup (__temp12)));
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->lower_case_csuffix, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 }
 
 
 static char* vala_enum_real_get_lower_case_cname (ValaSymbol* base, const char* infix)
 {
 	ValaEnum * self;
-	char* __temp15;
-	char* __temp14;
-	char* __temp16;
+	char* _tmp1;
+	char* _tmp0;
+	char* _tmp2;
 	self = ((ValaEnum*) base);
 	if (infix == NULL) {
 		infix = "";
 	}
-	__temp15 = NULL;
-	__temp14 = NULL;
-	__temp16 = NULL;
-	return (__temp16 = g_strdup_printf ("%s%s%s", (__temp14 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), infix, (__temp15 = vala_enum_get_lower_case_csuffix (self))), (__temp15 = (g_free (__temp15), NULL)), (__temp14 = (g_free (__temp14), NULL)), __temp16);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	_tmp2 = NULL;
+	return (_tmp2 = g_strdup_printf ("%s%s%s", (_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), infix, (_tmp1 = vala_enum_get_lower_case_csuffix (self))), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
 }
 
 
 static char* vala_enum_real_get_upper_case_cname (ValaDataType* base, const char* infix)
 {
 	ValaEnum * self;
-	char* __temp20;
-	char* __temp19;
-	char* __temp18;
-	char* __temp21;
+	char* _tmp0;
+	char* _tmp1;
 	self = ((ValaEnum*) base);
-	__temp20 = NULL;
-	__temp19 = NULL;
-	__temp18 = NULL;
-	__temp21 = NULL;
-	return (__temp21 = g_utf8_strup ((__temp20 = g_strdup_printf ("%s%s", (__temp18 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), (__temp19 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self)))))), -1), (__temp20 = (g_free (__temp20), NULL)), (__temp19 = (g_free (__temp19), NULL)), (__temp18 = (g_free (__temp18), NULL)), __temp21);
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_utf8_strup ((_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self), NULL)), -1), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -285,11 +282,11 @@ static gboolean vala_enum_real_is_reference_type (ValaDataType* base)
 
 static void vala_enum_set_cname (ValaEnum* self, const char* cname)
 {
-	char* __temp24;
+	char* _tmp0;
 	g_return_if_fail (VALA_IS_ENUM (self));
 	g_return_if_fail (cname != NULL);
-	__temp24 = NULL;
-	self->priv->cname = (__temp24 = g_strdup (cname), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp24);
+	_tmp0 = NULL;
+	self->priv->cname = (_tmp0 = g_strdup (cname), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp0);
 }
 
 
@@ -301,18 +298,18 @@ static void vala_enum_set_cname (ValaEnum* self, const char* cname)
  */
 char* vala_enum_get_cprefix (ValaEnum* self)
 {
-	const char* __temp27;
+	const char* _tmp2;
 	g_return_val_if_fail (VALA_IS_ENUM (self), NULL);
 	if (self->priv->cprefix == NULL) {
-		char* __temp26;
-		char* __temp25;
-		__temp26 = NULL;
-		__temp25 = NULL;
-		self->priv->cprefix = (__temp26 = g_strdup_printf ("%s_", (__temp25 = vala_data_type_get_upper_case_cname (VALA_DATA_TYPE (self), NULL))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), __temp26);
-		(__temp25 = (g_free (__temp25), NULL));
+		char* _tmp1;
+		char* _tmp0;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		self->priv->cprefix = (_tmp1 = g_strdup_printf ("%s_", (_tmp0 = vala_data_type_get_upper_case_cname (VALA_DATA_TYPE (self), NULL))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp1);
+		(_tmp0 = (g_free (_tmp0), NULL));
 	}
-	__temp27 = NULL;
-	return (__temp27 = self->priv->cprefix, (__temp27 == NULL ? NULL : g_strdup (__temp27)));
+	_tmp2 = NULL;
+	return (_tmp2 = self->priv->cprefix, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
 }
 
 
@@ -324,11 +321,11 @@ char* vala_enum_get_cprefix (ValaEnum* self)
  */
 void vala_enum_set_cprefix (ValaEnum* self, const char* cprefix)
 {
-	char* __temp29;
+	char* _tmp0;
 	g_return_if_fail (VALA_IS_ENUM (self));
 	g_return_if_fail (cprefix != NULL);
-	__temp29 = NULL;
-	self->priv->cprefix = (__temp29 = g_strdup (cprefix), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), __temp29);
+	_tmp0 = NULL;
+	self->priv->cprefix = (_tmp0 = g_strdup (cprefix), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp0);
 }
 
 
@@ -337,16 +334,21 @@ static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a)
 	g_return_if_fail (VALA_IS_ENUM (self));
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
-		char* __temp30;
-		__temp30 = NULL;
-		vala_enum_set_cname (self, (__temp30 = vala_attribute_get_string (a, "cname")));
-		(__temp30 = (g_free (__temp30), NULL));
+		char* _tmp0;
+		_tmp0 = NULL;
+		vala_enum_set_cname (self, (_tmp0 = vala_attribute_get_string (a, "cname")));
+		(_tmp0 = (g_free (_tmp0), NULL));
 	}
 	if (vala_attribute_has_argument (a, "cprefix")) {
-		char* __temp31;
-		__temp31 = NULL;
-		vala_enum_set_cprefix (self, (__temp31 = vala_attribute_get_string (a, "cprefix")));
-		(__temp31 = (g_free (__temp31), NULL));
+		char* _tmp1;
+		_tmp1 = NULL;
+		vala_enum_set_cprefix (self, (_tmp1 = vala_attribute_get_string (a, "cprefix")));
+		(_tmp1 = (g_free (_tmp1), NULL));
+	}
+	if (vala_attribute_has_argument (a, "lower_case_csuffix")) {
+		char* _tmp2;
+		_tmp2 = NULL;
+		self->priv->lower_case_csuffix = (_tmp2 = vala_attribute_get_string (a, "lower_case_csuffix"), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), _tmp2);
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
 		char* val;
@@ -354,18 +356,20 @@ static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a)
 		{
 			char** filename_collection;
 			char** filename_it;
+			int filename_collection_length1;
 			filename_collection = g_strsplit (val, ",", 0);
+			filename_collection_length1 = -1;
 			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
-				const char* __temp32;
+				const char* _tmp3;
 				char* filename;
-				__temp32 = NULL;
-				filename = (__temp32 = *filename_it, (__temp32 == NULL ? NULL : g_strdup (__temp32)));
+				_tmp3 = NULL;
+				filename = (_tmp3 = *filename_it, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
 				{
 					vala_data_type_add_cheader_filename (VALA_DATA_TYPE (self), filename);
 					(filename = (g_free (filename), NULL));
 				}
 			}
-			(filename_collection = (g_strfreev (filename_collection), NULL));
+			(filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL));
 		}
 		(val = (g_free (val), NULL));
 	}
@@ -383,10 +387,10 @@ void vala_enum_process_attributes (ValaEnum* self)
 		GList* a_it;
 		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* __temp33;
+			ValaAttribute* _tmp0;
 			ValaAttribute* a;
-			__temp33 = NULL;
-			a = (__temp33 = a_it->data, (__temp33 == NULL ? NULL : g_object_ref (__temp33)));
+			_tmp0 = NULL;
+			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_enum_process_ccode_attribute (self, a);
@@ -415,26 +419,29 @@ static char* vala_enum_real_get_marshaller_type_name (ValaDataType* base)
 {
 	ValaEnum * self;
 	self = ((ValaEnum*) base);
-	return g_strdup ("ENUM");
+	return g_strdup ("INT");
 }
 
 
+/* FIXME: use GType-registered enums*/
 static char* vala_enum_real_get_get_value_function (ValaDataType* base)
 {
 	ValaEnum * self;
 	self = ((ValaEnum*) base);
-	return g_strdup ("g_value_get_enum");
+	return g_strdup ("g_value_get_int");
 }
 
 
+/* FIXME: use GType-registered enums*/
 static char* vala_enum_real_get_set_value_function (ValaDataType* base)
 {
 	ValaEnum * self;
 	self = ((ValaEnum*) base);
-	return g_strdup ("g_value_set_enum");
+	return g_strdup ("g_value_set_int");
 }
 
 
+/* FIXME: use GType-registered enums*/
 static char* vala_enum_real_get_default_value (ValaDataType* base)
 {
 	ValaEnum * self;
@@ -465,6 +472,9 @@ static void vala_enum_get_property (GObject * object, guint property_id, GValue
 		case VALA_ENUM_ERROR_DOMAIN:
 		g_value_set_boolean (value, vala_enum_get_error_domain (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -477,6 +487,9 @@ static void vala_enum_set_property (GObject * object, guint property_id, const G
 		case VALA_ENUM_ERROR_DOMAIN:
 		vala_enum_set_error_domain (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -541,5 +554,23 @@ GType vala_enum_get_type (void)
 }
 
 
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func)
+{
+	if (array != NULL && destroy_func != NULL) {
+		int i;
+		if (array_length >= 0)
+		for (i = 0; i < array_length; i = i + 1) {
+			if (((gpointer*) array)[i] != NULL)
+			destroy_func (((gpointer*) array)[i]);
+		}
+		else
+		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) array)[i]);
+		}
+	}
+	g_free (array);
+}
+
+
 
 
