@@ -19,22 +19,18 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valafield.h"
 #include <vala/valatypereference.h>
 #include <vala/valaexpression.h>
 #include <vala/valasourcereference.h>
 #include <vala/valafield.h>
-#include <vala/valacodevisitor.h>
 #include <vala/valasymbol.h>
-#include <vala/valadatatype.h>
+#include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 #include <vala/valacallback.h>
 
 struct _ValaFieldPrivate {
-	char* _name;
 	ValaTypeReference* _type_reference;
 	ValaExpression* _initializer;
 	gboolean _no_array_length;
@@ -45,7 +41,6 @@ struct _ValaFieldPrivate {
 #define VALA_FIELD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FIELD, ValaFieldPrivate))
 enum  {
 	VALA_FIELD_DUMMY_PROPERTY,
-	VALA_FIELD_NAME,
 	VALA_FIELD_TYPE_REFERENCE,
 	VALA_FIELD_INITIALIZER,
 	VALA_FIELD_INSTANCE,
@@ -55,7 +50,7 @@ static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor
 static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_field_set_cname (ValaField* self, const char* cname);
 static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute* a);
-static GList* vala_field_real_get_parameters (ValaInvokable* base);
+static GeeCollection* vala_field_real_get_parameters (ValaInvokable* base);
 static ValaTypeReference* vala_field_real_get_return_type (ValaInvokable* base);
 static gboolean vala_field_real_is_invokable (ValaInvokable* base);
 static gboolean vala_field_real_get_lock_used (ValaLockable* base);
@@ -64,6 +59,7 @@ static gpointer vala_field_parent_class = NULL;
 static ValaInvokableIface* vala_field_vala_invokable_parent_iface = NULL;
 static ValaLockableIface* vala_field_vala_lockable_parent_iface = NULL;
 static void vala_field_dispose (GObject * obj);
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
 /**
@@ -75,22 +71,18 @@ static void vala_field_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created field
  */
-ValaField* vala_field_new (const char* _name, ValaTypeReference* type, ValaExpression* init, ValaSourceReference* source)
+ValaField* vala_field_new (const char* name, ValaTypeReference* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaField * self;
-	g_return_val_if_fail (_name != NULL, NULL);
-	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (type), NULL);
-	g_return_val_if_fail (init == NULL || VALA_IS_EXPRESSION (init), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 4);
-	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
-	(__params_it->name = "type-reference", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, type), __params_it++);
-	(__params_it->name = "initializer", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, init), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_FIELD, __params_it - __params, __params);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (type_reference), NULL);
+	g_return_val_if_fail (initializer == NULL || VALA_IS_EXPRESSION (initializer), NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	self = g_object_newv (VALA_TYPE_FIELD, 0, NULL);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	vala_field_set_type_reference (self, type_reference);
+	vala_field_set_initializer (self, initializer);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -98,7 +90,7 @@ ValaField* vala_field_new (const char* _name, ValaTypeReference* type, ValaExpre
 static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaField * self;
-	self = VALA_FIELD (base);
+	self = ((ValaField*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, VALA_MEMBER (self));
 	vala_code_visitor_visit_field (visitor, self);
@@ -108,7 +100,7 @@ static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor
 static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaField * self;
-	self = VALA_FIELD (base);
+	self = ((ValaField*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_field_get_type_reference (self)), visitor);
 	if (vala_field_get_initializer (self) != NULL) {
@@ -124,39 +116,47 @@ static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor
  */
 char* vala_field_get_cname (ValaField* self)
 {
-	const char* __temp4;
+	const char* _tmp1;
 	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
 	if (self->priv->cname == NULL) {
-		if (!vala_field_get_instance (self) && VALA_IS_DATA_TYPE (vala_symbol_get_node (vala_symbol_get_parent_symbol (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))) {
-			ValaDataType* __temp0;
-			ValaDataType* t;
-			char* __temp2;
-			char* __temp1;
-			__temp0 = NULL;
-			t = (__temp0 = VALA_DATA_TYPE (vala_symbol_get_node (vala_symbol_get_parent_symbol (vala_code_node_get_symbol (VALA_CODE_NODE (self))))), (__temp0 == NULL ? NULL : g_object_ref (__temp0)));
-			__temp2 = NULL;
-			__temp1 = NULL;
-			self->priv->cname = (__temp2 = g_strdup_printf ("%s_%s", (__temp1 = vala_data_type_get_lower_case_cname (t, NULL)), vala_field_get_name (self)), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp2);
-			(__temp1 = (g_free (__temp1), NULL));
-			(t == NULL ? NULL : (t = (g_object_unref (t), NULL)));
-		} else {
-			char* __temp3;
-			__temp3 = NULL;
-			self->priv->cname = (__temp3 = g_strdup (vala_field_get_name (self)), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp3);
-		}
+		char* _tmp0;
+		_tmp0 = NULL;
+		self->priv->cname = (_tmp0 = vala_field_get_default_cname (self), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp0);
 	}
-	__temp4 = NULL;
-	return (__temp4 = self->priv->cname, (__temp4 == NULL ? NULL : g_strdup (__temp4)));
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->cname, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 }
 
 
 static void vala_field_set_cname (ValaField* self, const char* cname)
 {
-	char* __temp6;
+	char* _tmp0;
 	g_return_if_fail (VALA_IS_FIELD (self));
 	g_return_if_fail (cname != NULL);
-	__temp6 = NULL;
-	self->priv->cname = (__temp6 = g_strdup (cname), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp6);
+	_tmp0 = NULL;
+	self->priv->cname = (_tmp0 = g_strdup (cname), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp0);
+}
+
+
+/**
+ * Returns the default name of this field as it is used in C code.
+ *
+ * @return the name to be used in C code by default
+ */
+char* vala_field_get_default_cname (ValaField* self)
+{
+	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
+	if (!vala_field_get_instance (self)) {
+		char* _tmp0;
+		char* _tmp1;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		return (_tmp1 = g_strconcat ((_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self)), NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	} else {
+		const char* _tmp3;
+		_tmp3 = NULL;
+		return (_tmp3 = vala_symbol_get_name (((ValaSymbol*) self)), (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
+	}
 }
 
 
@@ -165,10 +165,33 @@ static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute*
 	g_return_if_fail (VALA_IS_FIELD (self));
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
-		char* __temp7;
-		__temp7 = NULL;
-		vala_field_set_cname (self, (__temp7 = vala_attribute_get_string (a, "cname")));
-		(__temp7 = (g_free (__temp7), NULL));
+		char* _tmp0;
+		_tmp0 = NULL;
+		vala_field_set_cname (self, (_tmp0 = vala_attribute_get_string (a, "cname")));
+		(_tmp0 = (g_free (_tmp0), NULL));
+	}
+	if (vala_attribute_has_argument (a, "cheader_filename")) {
+		char* val;
+		val = vala_attribute_get_string (a, "cheader_filename");
+		{
+			char** filename_collection;
+			char** filename_it;
+			int filename_collection_length1;
+			filename_collection = g_strsplit (val, ",", 0);
+			filename_collection_length1 = -1;
+			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
+				const char* _tmp1;
+				char* filename;
+				_tmp1 = NULL;
+				filename = (_tmp1 = *filename_it, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+				{
+					vala_member_add_cheader_filename (VALA_MEMBER (self), filename);
+					(filename = (g_free (filename), NULL));
+				}
+			}
+			(filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL));
+		}
+		(val = (g_free (val), NULL));
 	}
 }
 
@@ -180,41 +203,43 @@ void vala_field_process_attributes (ValaField* self)
 {
 	g_return_if_fail (VALA_IS_FIELD (self));
 	{
-		GList* __temp8;
+		GList* a_collection;
 		GList* a_it;
-		__temp8 = NULL;
-		__temp8 = VALA_CODE_NODE (self)->attributes;
-		for (a_it = __temp8; a_it != NULL; a_it = a_it->next) {
+		a_collection = ((ValaCodeNode*) self)->attributes;
+		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
+			ValaAttribute* _tmp0;
 			ValaAttribute* a;
-			a = a_it->data;
+			_tmp0 = NULL;
+			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_field_process_ccode_attribute (self, a);
 				} else {
 					if (g_utf8_collate (vala_attribute_get_name (a), "NoArrayLength") == 0) {
-						(vala_field_set_no_array_length (self, TRUE), vala_field_get_no_array_length (self));
+						vala_field_set_no_array_length (self, TRUE);
 					}
 				}
+				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
 			}
 		}
 	}
 }
 
 
-static GList* vala_field_real_get_parameters (ValaInvokable* base)
+static GeeCollection* vala_field_real_get_parameters (ValaInvokable* base)
 {
 	ValaField * self;
-	ValaCallback* __temp10;
+	ValaCallback* _tmp1;
 	ValaCallback* cb;
-	GList* __temp11;
-	self = VALA_FIELD (base);
+	GeeCollection* _tmp2;
+	self = ((ValaField*) base);
 	if (!vala_invokable_is_invokable (VALA_INVOKABLE (self))) {
-		return NULL;
+		return GEE_COLLECTION (NULL);
 	}
-	__temp10 = NULL;
-	cb = (__temp10 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_field_get_type_reference (self))), (__temp10 == NULL ? NULL : g_object_ref (__temp10)));
-	__temp11 = NULL;
-	return (__temp11 = vala_callback_get_parameters (cb), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), __temp11);
+	_tmp1 = NULL;
+	cb = (_tmp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_field_get_type_reference (self))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	_tmp2 = NULL;
+	return (_tmp2 = vala_callback_get_parameters (cb), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), _tmp2);
 	(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
 }
 
@@ -222,19 +247,19 @@ static GList* vala_field_real_get_parameters (ValaInvokable* base)
 static ValaTypeReference* vala_field_real_get_return_type (ValaInvokable* base)
 {
 	ValaField * self;
-	ValaCallback* __temp13;
+	ValaCallback* _tmp1;
 	ValaCallback* cb;
-	ValaTypeReference* __temp14;
-	ValaTypeReference* __temp15;
-	self = VALA_FIELD (base);
+	ValaTypeReference* _tmp2;
+	ValaTypeReference* _tmp3;
+	self = ((ValaField*) base);
 	if (!vala_invokable_is_invokable (VALA_INVOKABLE (self))) {
 		return VALA_TYPE_REFERENCE (NULL);
 	}
-	__temp13 = NULL;
-	cb = (__temp13 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_field_get_type_reference (self))), (__temp13 == NULL ? NULL : g_object_ref (__temp13)));
-	__temp14 = NULL;
-	__temp15 = NULL;
-	return (__temp15 = (__temp14 = vala_callback_get_return_type (cb), (__temp14 == NULL ? NULL : g_object_ref (__temp14))), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), __temp15);
+	_tmp1 = NULL;
+	cb = (_tmp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_field_get_type_reference (self))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	_tmp2 = NULL;
+	_tmp3 = NULL;
+	return (_tmp3 = (_tmp2 = vala_callback_get_return_type (cb), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), _tmp3);
 	(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
 }
 
@@ -242,7 +267,7 @@ static ValaTypeReference* vala_field_real_get_return_type (ValaInvokable* base)
 static gboolean vala_field_real_is_invokable (ValaInvokable* base)
 {
 	ValaField * self;
-	self = VALA_FIELD (base);
+	self = ((ValaField*) base);
 	return (VALA_IS_CALLBACK (vala_type_reference_get_data_type (vala_field_get_type_reference (self))));
 }
 
@@ -250,7 +275,7 @@ static gboolean vala_field_real_is_invokable (ValaInvokable* base)
 static gboolean vala_field_real_get_lock_used (ValaLockable* base)
 {
 	ValaField * self;
-	self = VALA_FIELD (base);
+	self = ((ValaField*) base);
 	return self->priv->lock_used;
 }
 
@@ -258,27 +283,11 @@ static gboolean vala_field_real_get_lock_used (ValaLockable* base)
 static void vala_field_real_set_lock_used (ValaLockable* base, gboolean used)
 {
 	ValaField * self;
-	self = VALA_FIELD (base);
+	self = ((ValaField*) base);
 	self->priv->lock_used = used;
 }
 
 
-char* vala_field_get_name (ValaField* self)
-{
-	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
-	return self->priv->_name;
-}
-
-
-void vala_field_set_name (ValaField* self, const char* value)
-{
-	char* __temp19;
-	g_return_if_fail (VALA_IS_FIELD (self));
-	__temp19 = NULL;
-	self->priv->_name = (__temp19 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp19);
-}
-
-
 ValaTypeReference* vala_field_get_type_reference (ValaField* self)
 {
 	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
@@ -288,10 +297,10 @@ ValaTypeReference* vala_field_get_type_reference (ValaField* self)
 
 void vala_field_set_type_reference (ValaField* self, ValaTypeReference* value)
 {
-	ValaTypeReference* __temp21;
+	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_FIELD (self));
-	__temp21 = NULL;
-	self->priv->_type_reference = (__temp21 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp21);
+	_tmp1 = NULL;
+	self->priv->_type_reference = (_tmp1 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp1);
 }
 
 
@@ -304,12 +313,12 @@ ValaExpression* vala_field_get_initializer (ValaField* self)
 
 void vala_field_set_initializer (ValaField* self, ValaExpression* value)
 {
-	ValaExpression* __temp24;
-	ValaExpression* __temp23;
+	ValaExpression* _tmp2;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_FIELD (self));
-	__temp24 = NULL;
-	__temp23 = NULL;
-	self->priv->_initializer = (__temp24 = (__temp23 = value, (__temp23 == NULL ? NULL : g_object_ref (__temp23))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL))), __temp24);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL))), _tmp2);
 }
 
 
@@ -346,9 +355,6 @@ static void vala_field_get_property (GObject * object, guint property_id, GValue
 	ValaField * self;
 	self = VALA_FIELD (object);
 	switch (property_id) {
-		case VALA_FIELD_NAME:
-		g_value_set_string (value, vala_field_get_name (self));
-		break;
 		case VALA_FIELD_TYPE_REFERENCE:
 		g_value_set_object (value, vala_field_get_type_reference (self));
 		break;
@@ -361,6 +367,9 @@ static void vala_field_get_property (GObject * object, guint property_id, GValue
 		case VALA_FIELD_NO_ARRAY_LENGTH:
 		g_value_set_boolean (value, vala_field_get_no_array_length (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -370,9 +379,6 @@ static void vala_field_set_property (GObject * object, guint property_id, const
 	ValaField * self;
 	self = VALA_FIELD (object);
 	switch (property_id) {
-		case VALA_FIELD_NAME:
-		vala_field_set_name (self, g_value_get_string (value));
-		break;
 		case VALA_FIELD_TYPE_REFERENCE:
 		vala_field_set_type_reference (self, g_value_get_object (value));
 		break;
@@ -385,6 +391,9 @@ static void vala_field_set_property (GObject * object, guint property_id, const
 		case VALA_FIELD_NO_ARRAY_LENGTH:
 		vala_field_set_no_array_length (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -398,8 +407,7 @@ static void vala_field_class_init (ValaFieldClass * klass)
 	G_OBJECT_CLASS (klass)->dispose = vala_field_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_field_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_field_real_accept_children;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_TYPE_REFERENCE, g_param_spec_object ("type-reference", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_TYPE_REFERENCE, g_param_spec_object ("type-reference", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INITIALIZER, g_param_spec_object ("initializer", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INSTANCE, g_param_spec_boolean ("instance", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -437,7 +445,6 @@ static void vala_field_dispose (GObject * obj)
 	ValaFieldClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_FIELD (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
 	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
 	(self->priv->cname = (g_free (self->priv->cname), NULL));
@@ -447,7 +454,7 @@ static void vala_field_dispose (GObject * obj)
 }
 
 
-GType vala_field_get_type ()
+GType vala_field_get_type (void)
 {
 	static GType vala_field_type_id = 0;
 	if (G_UNLIKELY (vala_field_type_id == 0)) {
@@ -462,5 +469,23 @@ GType vala_field_get_type ()
 }
 
 
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func)
+{
+	if (array != NULL && destroy_func != NULL) {
+		int i;
+		if (array_length >= 0)
+		for (i = 0; i < array_length; i = i + 1) {
+			if (((gpointer*) array)[i] != NULL)
+			destroy_func (((gpointer*) array)[i]);
+		}
+		else
+		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) array)[i]);
+		}
+	}
+	g_free (array);
+}
+
+
 
 
