@@ -22,16 +22,15 @@
 
 #ifndef __VALAFIELD_H__
 #define __VALAFIELD_H__
-typedef struct _ValaFieldPrivate ValaFieldPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/collection.h>
 #include <vala/valamember.h>
 #include <vala/valainvokable.h>
 #include <vala/valalockable.h>
-#include <vala/valamemberaccessibility.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -44,6 +43,7 @@ G_BEGIN_DECLS
 #define VALA_IS_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_FIELD))
 #define VALA_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_FIELD, ValaFieldClass))
 
+typedef struct _ValaFieldPrivate ValaFieldPrivate;
 
 /**
  * Represents a type or namespace field.
@@ -51,17 +51,15 @@ G_BEGIN_DECLS
 struct _ValaField {
 	ValaMember parent;
 	ValaFieldPrivate * priv;
-	ValaMemberAccessibility access;
 };
 struct _ValaFieldClass {
 	ValaMemberClass parent;
 };
 
-ValaField* vala_field_new (const char* _name, ValaTypeReference* type, ValaExpression* init, ValaSourceReference* source);
+ValaField* vala_field_new (const char* name, ValaTypeReference* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference);
 char* vala_field_get_cname (ValaField* self);
+char* vala_field_get_default_cname (ValaField* self);
 void vala_field_process_attributes (ValaField* self);
-char* vala_field_get_name (ValaField* self);
-void vala_field_set_name (ValaField* self, const char* value);
 ValaTypeReference* vala_field_get_type_reference (ValaField* self);
 void vala_field_set_type_reference (ValaField* self, ValaTypeReference* value);
 ValaExpression* vala_field_get_initializer (ValaField* self);
@@ -70,7 +68,7 @@ gboolean vala_field_get_instance (ValaField* self);
 void vala_field_set_instance (ValaField* self, gboolean value);
 gboolean vala_field_get_no_array_length (ValaField* self);
 void vala_field_set_no_array_length (ValaField* self, gboolean value);
-GType vala_field_get_type ();
+GType vala_field_get_type (void);
 
 G_END_DECLS
 
