@@ -90,17 +90,17 @@ char* vala_integer_literal_get_type_name (ValaIntegerLiteral* self)
 	number = g_strdup (vala_integer_literal_get_value (self));
 	l = 0;
 	while (g_str_has_suffix (number, "L")) {
-		char* __temp1;
+		char* _tmp0;
 		l++;
-		__temp1 = NULL;
-		number = (__temp1 = g_strndup (number, strlen (number) - 1), (number = (g_free (number), NULL)), __temp1);
+		_tmp0 = NULL;
+		number = (_tmp0 = g_strndup (number, strlen (number) - 1), (number = (g_free (number), NULL)), _tmp0);
 	}
 	u = FALSE;
 	if (g_str_has_suffix (number, "U")) {
-		char* __temp2;
+		char* _tmp1;
 		u = TRUE;
-		__temp2 = NULL;
-		number = (__temp2 = g_strndup (number, strlen (number) - 1), (number = (g_free (number), NULL)), __temp2);
+		_tmp1 = NULL;
+		number = (_tmp1 = g_strndup (number, strlen (number) - 1), (number = (g_free (number), NULL)), _tmp1);
 	}
 	n = g_ascii_strtoll (number, NULL, 0);
 	if (!u && n > 0x7fffffff) {
@@ -114,34 +114,34 @@ char* vala_integer_literal_get_type_name (ValaIntegerLiteral* self)
 	}
 	if (l == 0) {
 		if (u) {
-			char* __temp3;
-			__temp3 = NULL;
-			return (__temp3 = g_strdup ("uint"), (number = (g_free (number), NULL)), __temp3);
+			char* _tmp2;
+			_tmp2 = NULL;
+			return (_tmp2 = g_strdup ("uint"), (number = (g_free (number), NULL)), _tmp2);
 		} else {
-			char* __temp4;
-			__temp4 = NULL;
-			return (__temp4 = g_strdup ("int"), (number = (g_free (number), NULL)), __temp4);
+			char* _tmp3;
+			_tmp3 = NULL;
+			return (_tmp3 = g_strdup ("int"), (number = (g_free (number), NULL)), _tmp3);
 		}
 	} else {
 		if (l == 1) {
 			if (u) {
-				char* __temp5;
-				__temp5 = NULL;
-				return (__temp5 = g_strdup ("ulong"), (number = (g_free (number), NULL)), __temp5);
+				char* _tmp4;
+				_tmp4 = NULL;
+				return (_tmp4 = g_strdup ("ulong"), (number = (g_free (number), NULL)), _tmp4);
 			} else {
-				char* __temp6;
-				__temp6 = NULL;
-				return (__temp6 = g_strdup ("long"), (number = (g_free (number), NULL)), __temp6);
+				char* _tmp5;
+				_tmp5 = NULL;
+				return (_tmp5 = g_strdup ("long"), (number = (g_free (number), NULL)), _tmp5);
 			}
 		} else {
 			if (u) {
-				char* __temp7;
-				__temp7 = NULL;
-				return (__temp7 = g_strdup ("uint64"), (number = (g_free (number), NULL)), __temp7);
+				char* _tmp6;
+				_tmp6 = NULL;
+				return (_tmp6 = g_strdup ("uint64"), (number = (g_free (number), NULL)), _tmp6);
 			} else {
-				char* __temp8;
-				__temp8 = NULL;
-				return (__temp8 = g_strdup ("int64"), (number = (g_free (number), NULL)), __temp8);
+				char* _tmp7;
+				_tmp7 = NULL;
+				return (_tmp7 = g_strdup ("int64"), (number = (g_free (number), NULL)), _tmp7);
 			}
 		}
 	}
@@ -158,10 +158,10 @@ char* vala_integer_literal_get_value (ValaIntegerLiteral* self)
 
 void vala_integer_literal_set_value (ValaIntegerLiteral* self, const char* value)
 {
-	char* __temp10;
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_INTEGER_LITERAL (self));
-	__temp10 = NULL;
-	self->priv->_value = (__temp10 = g_strdup (value), (self->priv->_value = (g_free (self->priv->_value), NULL)), __temp10);
+	_tmp1 = NULL;
+	self->priv->_value = (_tmp1 = g_strdup (value), (self->priv->_value = (g_free (self->priv->_value), NULL)), _tmp1);
 }
 
 
@@ -173,6 +173,9 @@ static void vala_integer_literal_get_property (GObject * object, guint property_
 		case VALA_INTEGER_LITERAL_VALUE:
 		g_value_set_string (value, vala_integer_literal_get_value (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -185,6 +188,9 @@ static void vala_integer_literal_set_property (GObject * object, guint property_
 		case VALA_INTEGER_LITERAL_VALUE:
 		vala_integer_literal_set_value (self, g_value_get_string (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
