@@ -25,9 +25,9 @@
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
 #include <vala/valasourcereference.h>
+#include <vala/valainterface.h>
 #include <vala/valasymbol.h>
 #include <vala/valatypeparameter.h>
-#include <vala/valainterface.h>
 #include <vala/valascope.h>
 #include <vala/valatypereference.h>
 #include <vala/valamethod.h>
@@ -42,6 +42,7 @@
 
 struct _ValaInterfacePrivate {
 	gboolean _is_static;
+	gboolean _declaration_only;
 	GeeList* type_parameters;
 	GeeList* prerequisites;
 	GeeList* methods;
@@ -56,7 +57,8 @@ struct _ValaInterfacePrivate {
 #define VALA_INTERFACE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INTERFACE, ValaInterfacePrivate))
 enum  {
 	VALA_INTERFACE_DUMMY_PROPERTY,
-	VALA_INTERFACE_IS_STATIC
+	VALA_INTERFACE_IS_STATIC,
+	VALA_INTERFACE_DECLARATION_ONLY
 };
 static char* vala_interface_real_get_cname (ValaDataType* base, gboolean const_type);
 static char* vala_interface_real_get_lower_case_cname (ValaSymbol* base, const char* infix);
@@ -70,6 +72,7 @@ static char* vala_interface_real_get_ref_function (ValaDataType* base);
 static char* vala_interface_real_get_unref_function (ValaDataType* base);
 static gboolean vala_interface_real_is_subtype_of (ValaDataType* base, ValaDataType* t);
 static void vala_interface_process_ccode_attribute (ValaInterface* self, ValaAttribute* a);
+static void vala_interface_process_dbus_interface_attribute (ValaInterface* self, ValaAttribute* a);
 static char* vala_interface_real_get_marshaller_type_name (ValaDataType* base);
 static char* vala_interface_real_get_get_value_function (ValaDataType* base);
 static char* vala_interface_real_get_set_value_function (ValaDataType* base);
@@ -77,6 +80,7 @@ static char* vala_interface_real_get_type_id (ValaDataType* base);
 static gint vala_interface_real_get_type_parameter_index (ValaDataType* base, const char* name);
 static gpointer vala_interface_parent_class = NULL;
 static void vala_interface_dispose (GObject * obj);
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
 /**
@@ -180,13 +184,13 @@ void vala_interface_add_method (ValaInterface* self, ValaMethod* m)
 		return;
 	}
 	if (vala_method_get_instance (m)) {
-		ValaFormalParameter* __temp3;
-		ValaTypeReference* __temp2;
-		__temp3 = NULL;
-		__temp2 = NULL;
-		vala_method_set_this_parameter (m, (__temp3 = vala_formal_parameter_new ("this", (__temp2 = vala_type_reference_new ()), NULL)));
-		(__temp3 == NULL ? NULL : (__temp3 = (g_object_unref (__temp3), NULL)));
-		(__temp2 == NULL ? NULL : (__temp2 = (g_object_unref (__temp2), NULL)));
+		ValaFormalParameter* _tmp1;
+		ValaTypeReference* _tmp0;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		vala_method_set_this_parameter (m, (_tmp1 = vala_formal_parameter_new ("this", (_tmp0 = vala_type_reference_new ()), NULL)));
+		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
+		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 		vala_type_reference_set_data_type (vala_formal_parameter_get_type_reference (vala_method_get_this_parameter (m)), VALA_DATA_TYPE (self));
 		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) m)), vala_symbol_get_name (((ValaSymbol*) vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
 	}
@@ -291,18 +295,18 @@ GeeCollection* vala_interface_get_signals (ValaInterface* self)
 static char* vala_interface_real_get_cname (ValaDataType* base, gboolean const_type)
 {
 	ValaInterface * self;
-	const char* __temp10;
+	const char* _tmp2;
 	self = ((ValaInterface*) base);
 	if (self->priv->cname == NULL) {
-		char* __temp9;
-		char* __temp8;
-		__temp9 = NULL;
-		__temp8 = NULL;
-		self->priv->cname = (__temp9 = g_strdup_printf ("%s%s", (__temp8 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp9);
-		(__temp8 = (g_free (__temp8), NULL));
+		char* _tmp1;
+		char* _tmp0;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		self->priv->cname = (_tmp1 = g_strdup_printf ("%s%s", (_tmp0 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
+		(_tmp0 = (g_free (_tmp0), NULL));
 	}
-	__temp10 = NULL;
-	return (__temp10 = self->priv->cname, (__temp10 == NULL ? NULL : g_strdup (__temp10)));
+	_tmp2 = NULL;
+	return (_tmp2 = self->priv->cname, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
 }
 
 
@@ -314,15 +318,15 @@ static char* vala_interface_real_get_cname (ValaDataType* base, gboolean const_t
  */
 char* vala_interface_get_lower_case_csuffix (ValaInterface* self)
 {
-	const char* __temp13;
+	const char* _tmp1;
 	g_return_val_if_fail (VALA_IS_INTERFACE (self), NULL);
 	if (self->priv->lower_case_csuffix == NULL) {
-		char* __temp12;
-		__temp12 = NULL;
-		self->priv->lower_case_csuffix = (__temp12 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), __temp12);
+		char* _tmp0;
+		_tmp0 = NULL;
+		self->priv->lower_case_csuffix = (_tmp0 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), _tmp0);
 	}
-	__temp13 = NULL;
-	return (__temp13 = self->priv->lower_case_csuffix, (__temp13 == NULL ? NULL : g_strdup (__temp13)));
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->lower_case_csuffix, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 }
 
 
@@ -334,52 +338,52 @@ char* vala_interface_get_lower_case_csuffix (ValaInterface* self)
  */
 void vala_interface_set_lower_case_csuffix (ValaInterface* self, const char* csuffix)
 {
-	char* __temp15;
+	char* _tmp0;
 	g_return_if_fail (VALA_IS_INTERFACE (self));
 	g_return_if_fail (csuffix != NULL);
-	__temp15 = NULL;
-	self->priv->lower_case_csuffix = (__temp15 = g_strdup (csuffix), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), __temp15);
+	_tmp0 = NULL;
+	self->priv->lower_case_csuffix = (_tmp0 = g_strdup (csuffix), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), _tmp0);
 }
 
 
 static char* vala_interface_real_get_lower_case_cname (ValaSymbol* base, const char* infix)
 {
 	ValaInterface * self;
-	char* __temp17;
-	char* __temp16;
-	char* __temp18;
+	char* _tmp1;
+	char* _tmp0;
+	char* _tmp2;
 	self = ((ValaInterface*) base);
 	if (infix == NULL) {
 		infix = "";
 	}
-	__temp17 = NULL;
-	__temp16 = NULL;
-	__temp18 = NULL;
-	return (__temp18 = g_strdup_printf ("%s%s%s", (__temp16 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), infix, (__temp17 = vala_interface_get_lower_case_csuffix (self))), (__temp17 = (g_free (__temp17), NULL)), (__temp16 = (g_free (__temp16), NULL)), __temp18);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	_tmp2 = NULL;
+	return (_tmp2 = g_strdup_printf ("%s%s%s", (_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), infix, (_tmp1 = vala_interface_get_lower_case_csuffix (self))), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
 }
 
 
 static char* vala_interface_real_get_lower_case_cprefix (ValaSymbol* base)
 {
 	ValaInterface * self;
-	char* __temp20;
-	char* __temp21;
+	char* _tmp0;
+	char* _tmp1;
 	self = ((ValaInterface*) base);
-	__temp20 = NULL;
-	__temp21 = NULL;
-	return (__temp21 = g_strdup_printf ("%s_", (__temp20 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self), NULL))), (__temp20 = (g_free (__temp20), NULL)), __temp21);
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_strdup_printf ("%s_", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
 static char* vala_interface_real_get_upper_case_cname (ValaDataType* base, const char* infix)
 {
 	ValaInterface * self;
-	char* __temp23;
-	char* __temp24;
+	char* _tmp0;
+	char* _tmp1;
 	self = ((ValaInterface*) base);
-	__temp23 = NULL;
-	__temp24 = NULL;
-	return (__temp24 = g_utf8_strup ((__temp23 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self), infix)), -1), (__temp23 = (g_free (__temp23), NULL)), __temp24);
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_utf8_strup ((_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self), infix)), -1), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -537,8 +541,8 @@ static gboolean vala_interface_real_is_subtype_of (ValaDataType* base, ValaDataT
 			prerequisite = gee_iterator_get (prerequisite_it);
 			{
 				if (vala_type_reference_get_data_type (prerequisite) == t || vala_data_type_is_subtype_of (vala_type_reference_get_data_type (prerequisite), t)) {
-					gboolean __temp30;
-					return (__temp30 = TRUE, (prerequisite == NULL ? NULL : (prerequisite = (g_object_unref (prerequisite), NULL))), (prerequisite_it == NULL ? NULL : (prerequisite_it = (g_object_unref (prerequisite_it), NULL))), __temp30);
+					gboolean _tmp0;
+					return (_tmp0 = TRUE, (prerequisite == NULL ? NULL : (prerequisite = (g_object_unref (prerequisite), NULL))), (prerequisite_it == NULL ? NULL : (prerequisite_it = (g_object_unref (prerequisite_it), NULL))), _tmp0);
 				}
 				(prerequisite == NULL ? NULL : (prerequisite = (g_object_unref (prerequisite), NULL)));
 			}
@@ -554,10 +558,10 @@ static void vala_interface_process_ccode_attribute (ValaInterface* self, ValaAtt
 	g_return_if_fail (VALA_IS_INTERFACE (self));
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "type_cname")) {
-		char* __temp32;
-		__temp32 = NULL;
-		vala_interface_set_type_cname (self, (__temp32 = vala_attribute_get_string (a, "type_cname")));
-		(__temp32 = (g_free (__temp32), NULL));
+		char* _tmp0;
+		_tmp0 = NULL;
+		vala_interface_set_type_cname (self, (_tmp0 = vala_attribute_get_string (a, "type_cname")));
+		(_tmp0 = (g_free (_tmp0), NULL));
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
 		char* val;
@@ -565,24 +569,38 @@ static void vala_interface_process_ccode_attribute (ValaInterface* self, ValaAtt
 		{
 			char** filename_collection;
 			char** filename_it;
+			int filename_collection_length1;
 			filename_collection = g_strsplit (val, ",", 0);
+			filename_collection_length1 = -1;
 			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
-				const char* __temp33;
+				const char* _tmp1;
 				char* filename;
-				__temp33 = NULL;
-				filename = (__temp33 = *filename_it, (__temp33 == NULL ? NULL : g_strdup (__temp33)));
+				_tmp1 = NULL;
+				filename = (_tmp1 = *filename_it, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 				{
 					vala_data_type_add_cheader_filename (VALA_DATA_TYPE (self), filename);
 					(filename = (g_free (filename), NULL));
 				}
 			}
-			(filename_collection = (g_strfreev (filename_collection), NULL));
+			(filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL));
 		}
 		(val = (g_free (val), NULL));
 	}
 }
 
 
+static void vala_interface_process_dbus_interface_attribute (ValaInterface* self, ValaAttribute* a)
+{
+	g_return_if_fail (VALA_IS_INTERFACE (self));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
+	if (vala_interface_get_declaration_only (self)) {
+		char* _tmp0;
+		_tmp0 = NULL;
+		self->priv->cname = (_tmp0 = g_strdup ("DBusGProxy"), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp0);
+	}
+}
+
+
 /**
  * Process all associated attributes.
  */
@@ -594,13 +612,17 @@ void vala_interface_process_attributes (ValaInterface* self)
 		GList* a_it;
 		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* __temp34;
+			ValaAttribute* _tmp0;
 			ValaAttribute* a;
-			__temp34 = NULL;
-			a = (__temp34 = a_it->data, (__temp34 == NULL ? NULL : g_object_ref (__temp34)));
+			_tmp0 = NULL;
+			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_interface_process_ccode_attribute (self, a);
+				} else {
+					if (g_utf8_collate (vala_attribute_get_name (a), "DBusInterface") == 0) {
+						vala_interface_process_dbus_interface_attribute (self, a);
+					}
 				}
 				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
 			}
@@ -616,18 +638,18 @@ void vala_interface_process_attributes (ValaInterface* self)
  */
 char* vala_interface_get_type_cname (ValaInterface* self)
 {
-	const char* __temp37;
+	const char* _tmp2;
 	g_return_val_if_fail (VALA_IS_INTERFACE (self), NULL);
 	if (self->priv->type_cname == NULL) {
-		char* __temp36;
-		char* __temp35;
-		__temp36 = NULL;
-		__temp35 = NULL;
-		self->priv->type_cname = (__temp36 = g_strdup_printf ("%sIface", (__temp35 = vala_data_type_get_cname (VALA_DATA_TYPE (self), FALSE))), (self->priv->type_cname = (g_free (self->priv->type_cname), NULL)), __temp36);
-		(__temp35 = (g_free (__temp35), NULL));
+		char* _tmp1;
+		char* _tmp0;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		self->priv->type_cname = (_tmp1 = g_strdup_printf ("%sIface", (_tmp0 = vala_data_type_get_cname (VALA_DATA_TYPE (self), FALSE))), (self->priv->type_cname = (g_free (self->priv->type_cname), NULL)), _tmp1);
+		(_tmp0 = (g_free (_tmp0), NULL));
 	}
-	__temp37 = NULL;
-	return (__temp37 = self->priv->type_cname, (__temp37 == NULL ? NULL : g_strdup (__temp37)));
+	_tmp2 = NULL;
+	return (_tmp2 = self->priv->type_cname, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
 }
 
 
@@ -638,11 +660,11 @@ char* vala_interface_get_type_cname (ValaInterface* self)
  */
 void vala_interface_set_type_cname (ValaInterface* self, const char* type_cname)
 {
-	char* __temp39;
+	char* _tmp0;
 	g_return_if_fail (VALA_IS_INTERFACE (self));
 	g_return_if_fail (type_cname != NULL);
-	__temp39 = NULL;
-	self->priv->type_cname = (__temp39 = g_strdup (type_cname), (self->priv->type_cname = (g_free (self->priv->type_cname), NULL)), __temp39);
+	_tmp0 = NULL;
+	self->priv->type_cname = (_tmp0 = g_strdup (type_cname), (self->priv->type_cname = (g_free (self->priv->type_cname), NULL)), _tmp0);
 }
 
 
@@ -673,15 +695,15 @@ static char* vala_interface_real_get_set_value_function (ValaDataType* base)
 static char* vala_interface_real_get_type_id (ValaDataType* base)
 {
 	ValaInterface * self;
-	const char* __temp44;
+	const char* _tmp1;
 	self = ((ValaInterface*) base);
 	if (self->priv->type_id == NULL) {
-		char* __temp43;
-		__temp43 = NULL;
-		self->priv->type_id = (__temp43 = vala_data_type_get_upper_case_cname (VALA_DATA_TYPE (self), "TYPE_"), (self->priv->type_id = (g_free (self->priv->type_id), NULL)), __temp43);
+		char* _tmp0;
+		_tmp0 = NULL;
+		self->priv->type_id = (_tmp0 = vala_data_type_get_upper_case_cname (VALA_DATA_TYPE (self), "TYPE_"), (self->priv->type_id = (g_free (self->priv->type_id), NULL)), _tmp0);
 	}
-	__temp44 = NULL;
-	return (__temp44 = self->priv->type_id, (__temp44 == NULL ? NULL : g_strdup (__temp44)));
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->type_id, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 }
 
 
@@ -702,8 +724,8 @@ static gint vala_interface_real_get_type_parameter_index (ValaDataType* base, co
 			parameter = gee_iterator_get (parameter_it);
 			{
 				if (g_utf8_collate (vala_symbol_get_name (((ValaSymbol*) parameter)), name) == 0) {
-					gint __temp46;
-					return (__temp46 = i, (parameter == NULL ? NULL : (parameter = (g_object_unref (parameter), NULL))), (parameter_it == NULL ? NULL : (parameter_it = (g_object_unref (parameter_it), NULL))), __temp46);
+					gint _tmp0;
+					return (_tmp0 = i, (parameter == NULL ? NULL : (parameter = (g_object_unref (parameter), NULL))), (parameter_it == NULL ? NULL : (parameter_it = (g_object_unref (parameter_it), NULL))), _tmp0);
 				}
 				i++;
 				(parameter == NULL ? NULL : (parameter = (g_object_unref (parameter), NULL)));
@@ -729,6 +751,20 @@ void vala_interface_set_is_static (ValaInterface* self, gboolean value)
 }
 
 
+gboolean vala_interface_get_declaration_only (ValaInterface* self)
+{
+	g_return_val_if_fail (VALA_IS_INTERFACE (self), FALSE);
+	return self->priv->_declaration_only;
+}
+
+
+void vala_interface_set_declaration_only (ValaInterface* self, gboolean value)
+{
+	g_return_if_fail (VALA_IS_INTERFACE (self));
+	self->priv->_declaration_only = value;
+}
+
+
 static void vala_interface_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
 	ValaInterface * self;
@@ -737,6 +773,12 @@ static void vala_interface_get_property (GObject * object, guint property_id, GV
 		case VALA_INTERFACE_IS_STATIC:
 		g_value_set_boolean (value, vala_interface_get_is_static (self));
 		break;
+		case VALA_INTERFACE_DECLARATION_ONLY:
+		g_value_set_boolean (value, vala_interface_get_declaration_only (self));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -749,6 +791,12 @@ static void vala_interface_set_property (GObject * object, guint property_id, co
 		case VALA_INTERFACE_IS_STATIC:
 		vala_interface_set_is_static (self, g_value_get_boolean (value));
 		break;
+		case VALA_INTERFACE_DECLARATION_ONLY:
+		vala_interface_set_declaration_only (self, g_value_get_boolean (value));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -777,6 +825,7 @@ static void vala_interface_class_init (ValaInterfaceClass * klass)
 	VALA_DATA_TYPE_CLASS (klass)->get_type_id = vala_interface_real_get_type_id;
 	VALA_DATA_TYPE_CLASS (klass)->get_type_parameter_index = vala_interface_real_get_type_parameter_index;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INTERFACE_IS_STATIC, g_param_spec_boolean ("is-static", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INTERFACE_DECLARATION_ONLY, g_param_spec_boolean ("declaration-only", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -825,5 +874,23 @@ GType vala_interface_get_type (void)
 }
 
 
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func)
+{
+	if (array != NULL && destroy_func != NULL) {
+		int i;
+		if (array_length >= 0)
+		for (i = 0; i < array_length; i = i + 1) {
+			if (((gpointer*) array)[i] != NULL)
+			destroy_func (((gpointer*) array)[i]);
+		}
+		else
+		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) array)[i]);
+		}
+	}
+	g_free (array);
+}
+
+
 
 
