@@ -23,6 +23,7 @@
 
 #include "valainterfacewriter.h"
 #include <stdio.h>
+#include <gee/collection.h>
 #include <gee/list.h>
 #include <vala/valainterfacewriter.h>
 #include <vala/valasymbol.h>
@@ -30,8 +31,8 @@
 #include <vala/valasourcereference.h>
 #include <vala/valasourcefile.h>
 #include <vala/valadatatype.h>
-#include <vala/valamemberaccessibility.h>
 #include <vala/valatypeparameter.h>
+#include <vala/valatypereference.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valaarray.h>
 #include <vala/valapropertyaccessor.h>
@@ -55,6 +56,7 @@ static void vala_interface_writer_real_visit_enum (ValaCodeVisitor* base, ValaEn
 static void vala_interface_writer_real_visit_enum_value (ValaCodeVisitor* base, ValaEnumValue* ev);
 static void vala_interface_writer_real_visit_constant (ValaCodeVisitor* base, ValaConstant* c);
 static void vala_interface_writer_real_visit_field (ValaCodeVisitor* base, ValaField* f);
+static void vala_interface_writer_write_error_domains (ValaInterfaceWriter* self, GeeCollection* error_domains);
 static void vala_interface_writer_write_params (ValaInterfaceWriter* self, GeeCollection* params);
 static void vala_interface_writer_real_visit_callback (ValaCodeVisitor* base, ValaCallback* cb);
 static void vala_interface_writer_real_visit_method (ValaCodeVisitor* base, ValaMethod* m);
@@ -81,28 +83,37 @@ static void vala_interface_writer_dispose (GObject * obj);
  */
 void vala_interface_writer_write_file (ValaInterfaceWriter* self, ValaCodeContext* context, const char* filename)
 {
-	ValaCodeContext* __temp0;
-	FILE* __temp1;
-	FILE* __temp2;
+	ValaCodeContext* _tmp0;
+	FILE* _tmp1;
+	char* _tmp3;
+	char* _tmp2;
+	FILE* _tmp4;
 	g_return_if_fail (VALA_IS_INTERFACE_WRITER (self));
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (context));
 	g_return_if_fail (filename != NULL);
-	__temp0 = NULL;
-	self->priv->context = (__temp0 = g_object_ref (context), (self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL))), __temp0);
-	__temp1 = NULL;
-	self->priv->stream = (__temp1 = fopen (filename, "w"), (self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL))), __temp1);
+	_tmp0 = NULL;
+	self->priv->context = (_tmp0 = g_object_ref (context), (self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL))), _tmp0);
+	_tmp1 = NULL;
+	self->priv->stream = (_tmp1 = fopen (filename, "w"), (self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL))), _tmp1);
+	_tmp3 = NULL;
+	_tmp2 = NULL;
+	vala_interface_writer_write_string (self, (_tmp3 = g_strdup_printf ("/* %s generated by %s, do not modify. */", (_tmp2 = g_path_get_basename (filename)), g_get_prgname ())));
+	(_tmp3 = (g_free (_tmp3), NULL));
+	(_tmp2 = (g_free (_tmp2), NULL));
+	vala_interface_writer_write_newline (self);
+	vala_interface_writer_write_newline (self);
 	vala_code_context_accept (context, VALA_CODE_VISITOR (self));
-	__temp2 = NULL;
-	self->priv->stream = (__temp2 = NULL, (self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL))), __temp2);
+	_tmp4 = NULL;
+	self->priv->stream = (_tmp4 = NULL, (self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL))), _tmp4);
 }
 
 
 static void vala_interface_writer_real_visit_namespace (ValaCodeVisitor* base, ValaNamespace* ns)
 {
 	ValaInterfaceWriter * self;
-	char* __temp5;
-	char* __temp4;
-	char* __temp3;
+	char* _tmp2;
+	char* _tmp1;
+	char* _tmp0;
 	self = ((ValaInterfaceWriter*) base);
 	g_return_if_fail (VALA_IS_NAMESPACE (ns));
 	if (vala_namespace_get_pkg (ns)) {
@@ -113,13 +124,13 @@ static void vala_interface_writer_real_visit_namespace (ValaCodeVisitor* base, V
 		return;
 	}
 	vala_interface_writer_write_indent (self);
-	__temp5 = NULL;
-	__temp4 = NULL;
-	__temp3 = NULL;
-	vala_interface_writer_write_string (self, (__temp5 = g_strdup_printf ("[CCode (cprefix = \"%s\", lower_case_cprefix = \"%s\")]", (__temp3 = vala_symbol_get_cprefix (VALA_SYMBOL (ns))), (__temp4 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL (ns))))));
-	(__temp5 = (g_free (__temp5), NULL));
-	(__temp4 = (g_free (__temp4), NULL));
-	(__temp3 = (g_free (__temp3), NULL));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	vala_interface_writer_write_string (self, (_tmp2 = g_strdup_printf ("[CCode (cprefix = \"%s\", lower_case_cprefix = \"%s\")]", (_tmp0 = vala_symbol_get_cprefix (VALA_SYMBOL (ns))), (_tmp1 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL (ns))))));
+	(_tmp2 = (g_free (_tmp2), NULL));
+	(_tmp1 = (g_free (_tmp1), NULL));
+	(_tmp0 = (g_free (_tmp0), NULL));
 	vala_interface_writer_write_newline (self);
 	vala_interface_writer_write_indent (self);
 	vala_interface_writer_write_string (self, "namespace ");
@@ -136,7 +147,7 @@ static void vala_interface_writer_real_visit_class (ValaCodeVisitor* base, ValaC
 	ValaInterfaceWriter * self;
 	gboolean first;
 	char* cheaders;
-	char* __temp9;
+	char* _tmp24;
 	GeeCollection* type_params;
 	GeeCollection* base_types;
 	self = ((ValaInterfaceWriter*) base);
@@ -144,7 +155,7 @@ static void vala_interface_writer_real_visit_class (ValaCodeVisitor* base, ValaC
 	if (vala_code_node_get_source_reference (((ValaCodeNode*) cl)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) cl))))) {
 		return;
 	}
-	if (((ValaDataType*) cl)->access == VALA_MEMBER_ACCESSIBILITY_PRIVATE) {
+	if (vala_symbol_get_access (((ValaSymbol*) cl)) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 		return;
 	}
 	vala_interface_writer_write_indent (self);
@@ -160,16 +171,16 @@ static void vala_interface_writer_real_visit_class (ValaCodeVisitor* base, ValaC
 			cheader = gee_iterator_get (cheader_it);
 			{
 				if (first) {
-					char* __temp7;
-					const char* __temp6;
-					__temp7 = NULL;
-					__temp6 = NULL;
-					cheaders = (__temp7 = (__temp6 = cheader, (__temp6 == NULL ? NULL : g_strdup (__temp6))), (cheaders = (g_free (cheaders), NULL)), __temp7);
+					char* _tmp1;
+					const char* _tmp0;
+					_tmp1 = NULL;
+					_tmp0 = NULL;
+					cheaders = (_tmp1 = (_tmp0 = cheader, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (cheaders = (g_free (cheaders), NULL)), _tmp1);
 					first = FALSE;
 				} else {
-					char* __temp8;
-					__temp8 = NULL;
-					cheaders = (__temp8 = g_strdup_printf ("%s,%s", cheaders, cheader), (cheaders = (g_free (cheaders), NULL)), __temp8);
+					char* _tmp2;
+					_tmp2 = NULL;
+					cheaders = (_tmp2 = g_strdup_printf ("%s,%s", cheaders, cheader), (cheaders = (g_free (cheaders), NULL)), _tmp2);
 				}
 				(cheader = (g_free (cheader), NULL));
 			}
@@ -177,9 +188,71 @@ static void vala_interface_writer_real_visit_class (ValaCodeVisitor* base, ValaC
 		(cheader_collection == NULL ? NULL : (cheader_collection = (g_object_unref (cheader_collection), NULL)));
 		(cheader_it == NULL ? NULL : (cheader_it = (g_object_unref (cheader_it), NULL)));
 	}
-	__temp9 = NULL;
-	vala_interface_writer_write_string (self, (__temp9 = g_strdup_printf ("[CCode (cheader_filename = \"%s\")]", cheaders)));
-	(__temp9 = (g_free (__temp9), NULL));
+	vala_interface_writer_write_string (self, "[CCode (");
+	if (vala_data_type_is_reference_counting (VALA_DATA_TYPE (cl))) {
+		char* _tmp5;
+		char* _tmp4;
+		char* _tmp3;
+		gboolean _tmp6;
+		char* _tmp11;
+		char* _tmp10;
+		char* _tmp9;
+		gboolean _tmp12;
+		_tmp5 = NULL;
+		_tmp4 = NULL;
+		_tmp3 = NULL;
+		if ((_tmp6 = vala_class_get_base_class (cl) == NULL || (_tmp3 = vala_data_type_get_ref_function (VALA_DATA_TYPE (vala_class_get_base_class (cl)))) == NULL || g_utf8_collate ((_tmp4 = vala_data_type_get_ref_function (VALA_DATA_TYPE (vala_class_get_base_class (cl)))), (_tmp5 = vala_data_type_get_ref_function (VALA_DATA_TYPE (cl)))) != 0, (_tmp5 = (g_free (_tmp5), NULL)), (_tmp4 = (g_free (_tmp4), NULL)), (_tmp3 = (g_free (_tmp3), NULL)), _tmp6)) {
+			char* _tmp8;
+			char* _tmp7;
+			_tmp8 = NULL;
+			_tmp7 = NULL;
+			vala_interface_writer_write_string (self, (_tmp8 = g_strdup_printf ("ref_function = \"%s\", ", (_tmp7 = vala_data_type_get_ref_function (VALA_DATA_TYPE (cl))))));
+			(_tmp8 = (g_free (_tmp8), NULL));
+			(_tmp7 = (g_free (_tmp7), NULL));
+		}
+		_tmp11 = NULL;
+		_tmp10 = NULL;
+		_tmp9 = NULL;
+		if ((_tmp12 = vala_class_get_base_class (cl) == NULL || (_tmp9 = vala_data_type_get_unref_function (VALA_DATA_TYPE (vala_class_get_base_class (cl)))) == NULL || g_utf8_collate ((_tmp10 = vala_data_type_get_unref_function (VALA_DATA_TYPE (vala_class_get_base_class (cl)))), (_tmp11 = vala_data_type_get_unref_function (VALA_DATA_TYPE (cl)))) != 0, (_tmp11 = (g_free (_tmp11), NULL)), (_tmp10 = (g_free (_tmp10), NULL)), (_tmp9 = (g_free (_tmp9), NULL)), _tmp12)) {
+			char* _tmp14;
+			char* _tmp13;
+			_tmp14 = NULL;
+			_tmp13 = NULL;
+			vala_interface_writer_write_string (self, (_tmp14 = g_strdup_printf ("unref_function = \"%s\", ", (_tmp13 = vala_data_type_get_unref_function (VALA_DATA_TYPE (cl))))));
+			(_tmp14 = (g_free (_tmp14), NULL));
+			(_tmp13 = (g_free (_tmp13), NULL));
+		}
+	} else {
+		char* _tmp15;
+		gboolean _tmp16;
+		char* _tmp20;
+		char* _tmp19;
+		gboolean _tmp21;
+		_tmp15 = NULL;
+		if ((_tmp16 = (_tmp15 = vala_data_type_get_dup_function (VALA_DATA_TYPE (cl))) != NULL, (_tmp15 = (g_free (_tmp15), NULL)), _tmp16)) {
+			char* _tmp18;
+			char* _tmp17;
+			_tmp18 = NULL;
+			_tmp17 = NULL;
+			vala_interface_writer_write_string (self, (_tmp18 = g_strdup_printf ("copy_function = \"%s\", ", (_tmp17 = vala_data_type_get_dup_function (VALA_DATA_TYPE (cl))))));
+			(_tmp18 = (g_free (_tmp18), NULL));
+			(_tmp17 = (g_free (_tmp17), NULL));
+		}
+		_tmp20 = NULL;
+		_tmp19 = NULL;
+		if ((_tmp21 = g_utf8_collate ((_tmp19 = vala_data_type_get_free_function (VALA_DATA_TYPE (cl))), (_tmp20 = vala_class_get_default_free_function (cl))) != 0, (_tmp20 = (g_free (_tmp20), NULL)), (_tmp19 = (g_free (_tmp19), NULL)), _tmp21)) {
+			char* _tmp23;
+			char* _tmp22;
+			_tmp23 = NULL;
+			_tmp22 = NULL;
+			vala_interface_writer_write_string (self, (_tmp23 = g_strdup_printf ("free_function = \"%s\", ", (_tmp22 = vala_data_type_get_free_function (VALA_DATA_TYPE (cl))))));
+			(_tmp23 = (g_free (_tmp23), NULL));
+			(_tmp22 = (g_free (_tmp22), NULL));
+		}
+	}
+	_tmp24 = NULL;
+	vala_interface_writer_write_string (self, (_tmp24 = g_strdup_printf ("cheader_filename = \"%s\")]", cheaders)));
+	(_tmp24 = (g_free (_tmp24), NULL));
 	vala_interface_writer_write_newline (self);
 	vala_interface_writer_write_indent (self);
 	vala_interface_writer_write_string (self, "public ");
@@ -256,19 +329,15 @@ static void vala_interface_writer_real_visit_struct (ValaCodeVisitor* base, Vala
 	ValaInterfaceWriter * self;
 	gboolean first;
 	char* cheaders;
-	char* __temp13;
+	char* _tmp3;
 	self = ((ValaInterfaceWriter*) base);
 	g_return_if_fail (VALA_IS_STRUCT (st));
 	if (vala_code_node_get_source_reference (((ValaCodeNode*) st)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) st))))) {
 		return;
 	}
-	if (((ValaDataType*) st)->access == VALA_MEMBER_ACCESSIBILITY_PRIVATE) {
+	if (vala_symbol_get_access (((ValaSymbol*) st)) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 		return;
 	}
-	if (vala_data_type_is_reference_type (VALA_DATA_TYPE (st))) {
-		vala_interface_writer_write_indent (self);
-		vala_interface_writer_write_string (self, "[ReferenceType]");
-	}
 	vala_interface_writer_write_indent (self);
 	first = TRUE;
 	cheaders = NULL;
@@ -282,16 +351,16 @@ static void vala_interface_writer_real_visit_struct (ValaCodeVisitor* base, Vala
 			cheader = gee_iterator_get (cheader_it);
 			{
 				if (first) {
-					char* __temp11;
-					const char* __temp10;
-					__temp11 = NULL;
-					__temp10 = NULL;
-					cheaders = (__temp11 = (__temp10 = cheader, (__temp10 == NULL ? NULL : g_strdup (__temp10))), (cheaders = (g_free (cheaders), NULL)), __temp11);
+					char* _tmp1;
+					const char* _tmp0;
+					_tmp1 = NULL;
+					_tmp0 = NULL;
+					cheaders = (_tmp1 = (_tmp0 = cheader, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (cheaders = (g_free (cheaders), NULL)), _tmp1);
 					first = FALSE;
 				} else {
-					char* __temp12;
-					__temp12 = NULL;
-					cheaders = (__temp12 = g_strdup_printf ("%s,%s", cheaders, cheader), (cheaders = (g_free (cheaders), NULL)), __temp12);
+					char* _tmp2;
+					_tmp2 = NULL;
+					cheaders = (_tmp2 = g_strdup_printf ("%s,%s", cheaders, cheader), (cheaders = (g_free (cheaders), NULL)), _tmp2);
 				}
 				(cheader = (g_free (cheader), NULL));
 			}
@@ -299,9 +368,9 @@ static void vala_interface_writer_real_visit_struct (ValaCodeVisitor* base, Vala
 		(cheader_collection == NULL ? NULL : (cheader_collection = (g_object_unref (cheader_collection), NULL)));
 		(cheader_it == NULL ? NULL : (cheader_it = (g_object_unref (cheader_it), NULL)));
 	}
-	__temp13 = NULL;
-	vala_interface_writer_write_string (self, (__temp13 = g_strdup_printf ("[CCode (cheader_filename = \"%s\")]", cheaders)));
-	(__temp13 = (g_free (__temp13), NULL));
+	_tmp3 = NULL;
+	vala_interface_writer_write_string (self, (_tmp3 = g_strdup_printf ("[CCode (cheader_filename = \"%s\")]", cheaders)));
+	(_tmp3 = (g_free (_tmp3), NULL));
 	vala_interface_writer_write_newline (self);
 	vala_interface_writer_write_indent (self);
 	vala_interface_writer_write_string (self, "public struct ");
@@ -319,7 +388,7 @@ static void vala_interface_writer_real_visit_interface (ValaCodeVisitor* base, V
 	ValaInterfaceWriter * self;
 	gboolean first;
 	char* cheaders;
-	char* __temp17;
+	char* _tmp3;
 	GeeCollection* type_params;
 	GeeCollection* prerequisites;
 	self = ((ValaInterfaceWriter*) base);
@@ -327,7 +396,7 @@ static void vala_interface_writer_real_visit_interface (ValaCodeVisitor* base, V
 	if (vala_code_node_get_source_reference (((ValaCodeNode*) iface)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) iface))))) {
 		return;
 	}
-	if (((ValaDataType*) iface)->access == VALA_MEMBER_ACCESSIBILITY_PRIVATE) {
+	if (vala_symbol_get_access (((ValaSymbol*) iface)) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 		return;
 	}
 	vala_interface_writer_write_indent (self);
@@ -343,16 +412,16 @@ static void vala_interface_writer_real_visit_interface (ValaCodeVisitor* base, V
 			cheader = gee_iterator_get (cheader_it);
 			{
 				if (first) {
-					char* __temp15;
-					const char* __temp14;
-					__temp15 = NULL;
-					__temp14 = NULL;
-					cheaders = (__temp15 = (__temp14 = cheader, (__temp14 == NULL ? NULL : g_strdup (__temp14))), (cheaders = (g_free (cheaders), NULL)), __temp15);
+					char* _tmp1;
+					const char* _tmp0;
+					_tmp1 = NULL;
+					_tmp0 = NULL;
+					cheaders = (_tmp1 = (_tmp0 = cheader, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (cheaders = (g_free (cheaders), NULL)), _tmp1);
 					first = FALSE;
 				} else {
-					char* __temp16;
-					__temp16 = NULL;
-					cheaders = (__temp16 = g_strdup_printf ("%s,%s", cheaders, cheader), (cheaders = (g_free (cheaders), NULL)), __temp16);
+					char* _tmp2;
+					_tmp2 = NULL;
+					cheaders = (_tmp2 = g_strdup_printf ("%s,%s", cheaders, cheader), (cheaders = (g_free (cheaders), NULL)), _tmp2);
 				}
 				(cheader = (g_free (cheader), NULL));
 			}
@@ -360,9 +429,9 @@ static void vala_interface_writer_real_visit_interface (ValaCodeVisitor* base, V
 		(cheader_collection == NULL ? NULL : (cheader_collection = (g_object_unref (cheader_collection), NULL)));
 		(cheader_it == NULL ? NULL : (cheader_it = (g_object_unref (cheader_it), NULL)));
 	}
-	__temp17 = NULL;
-	vala_interface_writer_write_string (self, (__temp17 = g_strdup_printf ("[CCode (cheader_filename = \"%s\")]", cheaders)));
-	(__temp17 = (g_free (__temp17), NULL));
+	_tmp3 = NULL;
+	vala_interface_writer_write_string (self, (_tmp3 = g_strdup_printf ("[CCode (cheader_filename = \"%s\")]", cheaders)));
+	(_tmp3 = (g_free (_tmp3), NULL));
 	vala_interface_writer_write_newline (self);
 	vala_interface_writer_write_indent (self);
 	vala_interface_writer_write_string (self, "public ");
@@ -436,14 +505,14 @@ static void vala_interface_writer_real_visit_enum (ValaCodeVisitor* base, ValaEn
 	ValaInterfaceWriter * self;
 	gboolean first;
 	char* cheaders;
-	char* __temp22;
-	char* __temp21;
+	char* _tmp4;
+	char* _tmp3;
 	self = ((ValaInterfaceWriter*) base);
 	g_return_if_fail (VALA_IS_ENUM (en));
 	if (vala_code_node_get_source_reference (((ValaCodeNode*) en)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) en))))) {
 		return;
 	}
-	if (((ValaDataType*) en)->access == VALA_MEMBER_ACCESSIBILITY_PRIVATE) {
+	if (vala_symbol_get_access (((ValaSymbol*) en)) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 		return;
 	}
 	vala_interface_writer_write_indent (self);
@@ -459,16 +528,16 @@ static void vala_interface_writer_real_visit_enum (ValaCodeVisitor* base, ValaEn
 			cheader = gee_iterator_get (cheader_it);
 			{
 				if (first) {
-					char* __temp19;
-					const char* __temp18;
-					__temp19 = NULL;
-					__temp18 = NULL;
-					cheaders = (__temp19 = (__temp18 = cheader, (__temp18 == NULL ? NULL : g_strdup (__temp18))), (cheaders = (g_free (cheaders), NULL)), __temp19);
+					char* _tmp1;
+					const char* _tmp0;
+					_tmp1 = NULL;
+					_tmp0 = NULL;
+					cheaders = (_tmp1 = (_tmp0 = cheader, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (cheaders = (g_free (cheaders), NULL)), _tmp1);
 					first = FALSE;
 				} else {
-					char* __temp20;
-					__temp20 = NULL;
-					cheaders = (__temp20 = g_strdup_printf ("%s,%s", cheaders, cheader), (cheaders = (g_free (cheaders), NULL)), __temp20);
+					char* _tmp2;
+					_tmp2 = NULL;
+					cheaders = (_tmp2 = g_strdup_printf ("%s,%s", cheaders, cheader), (cheaders = (g_free (cheaders), NULL)), _tmp2);
 				}
 				(cheader = (g_free (cheader), NULL));
 			}
@@ -476,11 +545,11 @@ static void vala_interface_writer_real_visit_enum (ValaCodeVisitor* base, ValaEn
 		(cheader_collection == NULL ? NULL : (cheader_collection = (g_object_unref (cheader_collection), NULL)));
 		(cheader_it == NULL ? NULL : (cheader_it = (g_object_unref (cheader_it), NULL)));
 	}
-	__temp22 = NULL;
-	__temp21 = NULL;
-	vala_interface_writer_write_string (self, (__temp22 = g_strdup_printf ("[CCode (cprefix = \"%s\", cheader_filename = \"%s\")]", (__temp21 = vala_enum_get_cprefix (en)), cheaders)));
-	(__temp22 = (g_free (__temp22), NULL));
-	(__temp21 = (g_free (__temp21), NULL));
+	_tmp4 = NULL;
+	_tmp3 = NULL;
+	vala_interface_writer_write_string (self, (_tmp4 = g_strdup_printf ("[CCode (cprefix = \"%s\", cheader_filename = \"%s\")]", (_tmp3 = vala_enum_get_cprefix (en)), cheaders)));
+	(_tmp4 = (g_free (_tmp4), NULL));
+	(_tmp3 = (g_free (_tmp3), NULL));
 	vala_interface_writer_write_indent (self);
 	vala_interface_writer_write_string (self, "public enum ");
 	vala_interface_writer_write_identifier (self, vala_symbol_get_name (((ValaSymbol*) en)));
@@ -525,14 +594,29 @@ static void vala_interface_writer_real_visit_constant (ValaCodeVisitor* base, Va
 static void vala_interface_writer_real_visit_field (ValaCodeVisitor* base, ValaField* f)
 {
 	ValaInterfaceWriter * self;
+	char* _tmp1;
+	char* _tmp0;
+	gboolean _tmp2;
 	self = ((ValaInterfaceWriter*) base);
 	g_return_if_fail (VALA_IS_FIELD (f));
 	if (vala_code_node_get_source_reference (((ValaCodeNode*) f)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) f))))) {
 		return;
 	}
-	if (f->access == VALA_MEMBER_ACCESSIBILITY_PRIVATE) {
+	if (vala_symbol_get_access (((ValaSymbol*) f)) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 		return;
 	}
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	if ((_tmp2 = g_utf8_collate ((_tmp0 = vala_field_get_cname (f)), (_tmp1 = vala_field_get_default_cname (f))) != 0, (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2)) {
+		char* _tmp4;
+		char* _tmp3;
+		vala_interface_writer_write_indent (self);
+		_tmp4 = NULL;
+		_tmp3 = NULL;
+		vala_interface_writer_write_string (self, (_tmp4 = g_strdup_printf ("[CCode (cname = \"%s\")]", (_tmp3 = vala_field_get_cname (f)))));
+		(_tmp4 = (g_free (_tmp4), NULL));
+		(_tmp3 = (g_free (_tmp3), NULL));
+	}
 	vala_interface_writer_write_indent (self);
 	vala_interface_writer_write_string (self, "public ");
 	if (vala_type_reference_get_data_type (vala_field_get_type_reference (f)) != NULL && vala_data_type_is_reference_type (vala_type_reference_get_data_type (vala_field_get_type_reference (f))) && !vala_type_reference_get_takes_ownership (vala_field_get_type_reference (f))) {
@@ -546,6 +630,38 @@ static void vala_interface_writer_real_visit_field (ValaCodeVisitor* base, ValaF
 }
 
 
+static void vala_interface_writer_write_error_domains (ValaInterfaceWriter* self, GeeCollection* error_domains)
+{
+	g_return_if_fail (VALA_IS_INTERFACE_WRITER (self));
+	g_return_if_fail (error_domains == NULL || GEE_IS_COLLECTION (error_domains));
+	if (gee_collection_get_size (error_domains) > 0) {
+		gboolean first;
+		vala_interface_writer_write_string (self, " throws ");
+		first = TRUE;
+		{
+			GeeCollection* type_collection;
+			GeeIterator* type_it;
+			type_collection = error_domains;
+			type_it = gee_iterable_iterator (GEE_ITERABLE (type_collection));
+			while (gee_iterator_next (type_it)) {
+				ValaTypeReference* type;
+				type = gee_iterator_get (type_it);
+				{
+					if (!first) {
+						vala_interface_writer_write_string (self, ", ");
+					} else {
+						first = FALSE;
+					}
+					vala_interface_writer_write_type (self, type);
+					(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+				}
+			}
+			(type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL)));
+		}
+	}
+}
+
+
 static void vala_interface_writer_write_params (ValaInterfaceWriter* self, GeeCollection* params)
 {
 	gboolean first;
@@ -586,11 +702,11 @@ static void vala_interface_writer_write_params (ValaInterfaceWriter* self, GeeCo
 				vala_interface_writer_write_string (self, " ");
 				vala_interface_writer_write_identifier (self, vala_symbol_get_name (((ValaSymbol*) param)));
 				if (vala_formal_parameter_get_default_expression (param) != NULL) {
-					char* __temp23;
+					char* _tmp0;
 					vala_interface_writer_write_string (self, " = ");
-					__temp23 = NULL;
-					vala_interface_writer_write_string (self, (__temp23 = vala_code_node_to_string (VALA_CODE_NODE (vala_formal_parameter_get_default_expression (param)))));
-					(__temp23 = (g_free (__temp23), NULL));
+					_tmp0 = NULL;
+					vala_interface_writer_write_string (self, (_tmp0 = vala_code_node_to_string (VALA_CODE_NODE (vala_formal_parameter_get_default_expression (param)))));
+					(_tmp0 = (g_free (_tmp0), NULL));
 				}
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
@@ -604,21 +720,21 @@ static void vala_interface_writer_write_params (ValaInterfaceWriter* self, GeeCo
 static void vala_interface_writer_real_visit_callback (ValaCodeVisitor* base, ValaCallback* cb)
 {
 	ValaInterfaceWriter * self;
-	ValaDataType* __temp24;
+	ValaDataType* _tmp0;
 	ValaDataType* type;
-	GeeCollection* __temp25;
+	GeeCollection* _tmp1;
 	self = ((ValaInterfaceWriter*) base);
 	g_return_if_fail (VALA_IS_CALLBACK (cb));
 	if (vala_code_node_get_source_reference (((ValaCodeNode*) cb)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) cb))))) {
 		return;
 	}
-	if (((ValaDataType*) cb)->access == VALA_MEMBER_ACCESSIBILITY_PRIVATE) {
+	if (vala_symbol_get_access (((ValaSymbol*) cb)) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 		return;
 	}
 	vala_interface_writer_write_indent (self);
 	vala_interface_writer_write_string (self, "public static delegate ");
-	__temp24 = NULL;
-	type = (__temp24 = vala_type_reference_get_data_type (vala_callback_get_return_type (cb)), (__temp24 == NULL ? NULL : g_object_ref (__temp24)));
+	_tmp0 = NULL;
+	type = (_tmp0 = vala_type_reference_get_data_type (vala_callback_get_return_type (cb)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 	if (type == NULL) {
 		vala_interface_writer_write_string (self, "void");
 	} else {
@@ -633,9 +749,9 @@ static void vala_interface_writer_real_visit_callback (ValaCodeVisitor* base, Va
 	vala_interface_writer_write_string (self, " ");
 	vala_interface_writer_write_identifier (self, vala_symbol_get_name (((ValaSymbol*) cb)));
 	vala_interface_writer_write_string (self, " ");
-	__temp25 = NULL;
-	vala_interface_writer_write_params (self, (__temp25 = vala_callback_get_parameters (cb)));
-	(__temp25 == NULL ? NULL : (__temp25 = (g_object_unref (__temp25), NULL)));
+	_tmp1 = NULL;
+	vala_interface_writer_write_params (self, (_tmp1 = vala_callback_get_parameters (cb)));
+	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 	vala_interface_writer_write_string (self, ";");
 	vala_interface_writer_write_newline (self);
 	(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
@@ -645,16 +761,19 @@ static void vala_interface_writer_real_visit_callback (ValaCodeVisitor* base, Va
 static void vala_interface_writer_real_visit_method (ValaCodeVisitor* base, ValaMethod* m)
 {
 	ValaInterfaceWriter * self;
-	char* __temp27;
-	char* __temp26;
-	gboolean __temp28;
-	GeeCollection* __temp32;
+	GString* ccode_params;
+	char* separator;
+	char* _tmp1;
+	char* _tmp0;
+	gboolean _tmp2;
+	GeeCollection* _tmp8;
+	GeeCollection* _tmp9;
 	self = ((ValaInterfaceWriter*) base);
 	g_return_if_fail (VALA_IS_METHOD (m));
 	if (vala_code_node_get_source_reference (((ValaCodeNode*) m)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) m))))) {
 		return;
 	}
-	if (m->access == VALA_MEMBER_ACCESSIBILITY_PRIVATE || vala_method_get_overrides (m)) {
+	if (vala_symbol_get_access (((ValaSymbol*) m)) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE || vala_method_get_overrides (m)) {
 		return;
 	}
 	if (vala_method_get_no_array_length (m)) {
@@ -693,26 +812,40 @@ static void vala_interface_writer_real_visit_method (ValaCodeVisitor* base, Vala
 		vala_interface_writer_write_indent (self);
 		vala_interface_writer_write_string (self, "[InstanceByReference]");
 	}
-	__temp27 = NULL;
-	__temp26 = NULL;
-	if ((__temp28 = g_utf8_collate ((__temp26 = vala_method_get_cname (m)), (__temp27 = vala_method_get_default_cname (m))) != 0, (__temp27 = (g_free (__temp27), NULL)), (__temp26 = (g_free (__temp26), NULL)), __temp28)) {
-		char* __temp30;
-		char* __temp29;
+	ccode_params = g_string_new ("");
+	separator = g_strdup ("");
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	if ((_tmp2 = g_utf8_collate ((_tmp0 = vala_method_get_cname (m)), (_tmp1 = vala_method_get_default_cname (m))) != 0, (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2)) {
+		char* _tmp3;
+		char* _tmp4;
+		_tmp3 = NULL;
+		g_string_append_printf (ccode_params, "%scname = \"%s\"", separator, (_tmp3 = vala_method_get_cname (m)), NULL);
+		(_tmp3 = (g_free (_tmp3), NULL));
+		_tmp4 = NULL;
+		separator = (_tmp4 = g_strdup (", "), (separator = (g_free (separator), NULL)), _tmp4);
+	}
+	if (g_utf8_collate (vala_method_get_sentinel (m), VALA_METHOD_DEFAULT_SENTINEL) != 0) {
+		char* _tmp5;
+		g_string_append_printf (ccode_params, "%ssentinel = \"%s\"", separator, vala_method_get_sentinel (m), NULL);
+		_tmp5 = NULL;
+		separator = (_tmp5 = g_strdup (", "), (separator = (g_free (separator), NULL)), _tmp5);
+	}
+	if (ccode_params->len > 0) {
+		char* _tmp6;
 		vala_interface_writer_write_indent (self);
-		__temp30 = NULL;
-		__temp29 = NULL;
-		vala_interface_writer_write_string (self, (__temp30 = g_strdup_printf ("[CCode (cname = \"%s\")]", (__temp29 = vala_method_get_cname (m)))));
-		(__temp30 = (g_free (__temp30), NULL));
-		(__temp29 = (g_free (__temp29), NULL));
+		_tmp6 = NULL;
+		vala_interface_writer_write_string (self, (_tmp6 = g_strdup_printf ("[CCode (%s)]", ccode_params->str)));
+		(_tmp6 = (g_free (_tmp6), NULL));
 	}
 	vala_interface_writer_write_indent (self);
 	vala_interface_writer_write_string (self, "public");
 	if (VALA_IS_CREATION_METHOD (m)) {
-		ValaDataType* __temp31;
+		ValaDataType* _tmp7;
 		ValaDataType* datatype;
 		vala_interface_writer_write_string (self, " ");
-		__temp31 = NULL;
-		datatype = (__temp31 = VALA_DATA_TYPE (vala_symbol_get_parent_symbol (((ValaSymbol*) m))), (__temp31 == NULL ? NULL : g_object_ref (__temp31)));
+		_tmp7 = NULL;
+		datatype = (_tmp7 = VALA_DATA_TYPE (vala_symbol_get_parent_symbol (((ValaSymbol*) m))), (_tmp7 == NULL ? NULL : g_object_ref (_tmp7)));
 		vala_interface_writer_write_identifier (self, vala_symbol_get_name (((ValaSymbol*) datatype)));
 		if (vala_symbol_get_name (((ValaSymbol*) m)) != NULL) {
 			vala_interface_writer_write_string (self, ".");
@@ -749,11 +882,16 @@ static void vala_interface_writer_real_visit_method (ValaCodeVisitor* base, Vala
 		vala_interface_writer_write_identifier (self, vala_symbol_get_name (((ValaSymbol*) m)));
 	}
 	vala_interface_writer_write_string (self, " ");
-	__temp32 = NULL;
-	vala_interface_writer_write_params (self, (__temp32 = vala_invokable_get_parameters (VALA_INVOKABLE (m))));
-	(__temp32 == NULL ? NULL : (__temp32 = (g_object_unref (__temp32), NULL)));
+	_tmp8 = NULL;
+	vala_interface_writer_write_params (self, (_tmp8 = vala_invokable_get_parameters (VALA_INVOKABLE (m))));
+	(_tmp8 == NULL ? NULL : (_tmp8 = (g_object_unref (_tmp8), NULL)));
+	_tmp9 = NULL;
+	vala_interface_writer_write_error_domains (self, (_tmp9 = vala_method_get_error_domains (m)));
+	(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
 	vala_interface_writer_write_string (self, ";");
 	vala_interface_writer_write_newline (self);
+	(ccode_params == NULL ? NULL : (ccode_params = (g_string_free (ccode_params, TRUE), NULL)));
+	(separator = (g_free (separator), NULL));
 }
 
 
@@ -804,12 +942,12 @@ static void vala_interface_writer_real_visit_property (ValaCodeVisitor* base, Va
 static void vala_interface_writer_real_visit_signal (ValaCodeVisitor* base, ValaSignal* sig)
 {
 	ValaInterfaceWriter * self;
-	ValaDataType* __temp33;
+	ValaDataType* _tmp0;
 	ValaDataType* type;
-	GeeCollection* __temp34;
+	GeeCollection* _tmp1;
 	self = ((ValaInterfaceWriter*) base);
 	g_return_if_fail (VALA_IS_SIGNAL (sig));
-	if (vala_signal_get_access (sig) == VALA_MEMBER_ACCESSIBILITY_PRIVATE) {
+	if (vala_symbol_get_access (((ValaSymbol*) sig)) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 		return;
 	}
 	if (vala_signal_get_has_emitter (sig)) {
@@ -818,8 +956,8 @@ static void vala_interface_writer_real_visit_signal (ValaCodeVisitor* base, Vala
 	}
 	vala_interface_writer_write_indent (self);
 	vala_interface_writer_write_string (self, "public signal ");
-	__temp33 = NULL;
-	type = (__temp33 = vala_type_reference_get_data_type (vala_signal_get_return_type (sig)), (__temp33 == NULL ? NULL : g_object_ref (__temp33)));
+	_tmp0 = NULL;
+	type = (_tmp0 = vala_type_reference_get_data_type (vala_signal_get_return_type (sig)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 	if (type == NULL) {
 		vala_interface_writer_write_string (self, "void");
 	} else {
@@ -834,9 +972,9 @@ static void vala_interface_writer_real_visit_signal (ValaCodeVisitor* base, Vala
 	vala_interface_writer_write_string (self, " ");
 	vala_interface_writer_write_identifier (self, vala_symbol_get_name (((ValaSymbol*) sig)));
 	vala_interface_writer_write_string (self, " ");
-	__temp34 = NULL;
-	vala_interface_writer_write_params (self, (__temp34 = vala_invokable_get_parameters (VALA_INVOKABLE (sig))));
-	(__temp34 == NULL ? NULL : (__temp34 = (g_object_unref (__temp34), NULL)));
+	_tmp1 = NULL;
+	vala_interface_writer_write_params (self, (_tmp1 = vala_invokable_get_parameters (VALA_INVOKABLE (sig))));
+	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 	vala_interface_writer_write_string (self, ";");
 	vala_interface_writer_write_newline (self);
 	(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
@@ -862,7 +1000,7 @@ static void vala_interface_writer_write_identifier (ValaInterfaceWriter* self, c
 {
 	g_return_if_fail (VALA_IS_INTERFACE_WRITER (self));
 	g_return_if_fail (s != NULL);
-	if (g_utf8_collate (s, "base") == 0 || g_utf8_collate (s, "class") == 0 || g_utf8_collate (s, "construct") == 0 || g_utf8_collate (s, "delegate") == 0 || g_utf8_collate (s, "foreach") == 0 || g_utf8_collate (s, "in") == 0 || g_utf8_collate (s, "interface") == 0 || g_utf8_collate (s, "lock") == 0 || g_utf8_collate (s, "namespace") == 0 || g_utf8_collate (s, "out") == 0 || g_utf8_collate (s, "ref") == 0) {
+	if (g_utf8_collate (s, "base") == 0 || g_utf8_collate (s, "class") == 0 || g_utf8_collate (s, "construct") == 0 || g_utf8_collate (s, "delegate") == 0 || g_utf8_collate (s, "do") == 0 || g_utf8_collate (s, "foreach") == 0 || g_utf8_collate (s, "in") == 0 || g_utf8_collate (s, "interface") == 0 || g_utf8_collate (s, "lock") == 0 || g_utf8_collate (s, "namespace") == 0 || g_utf8_collate (s, "new") == 0 || g_utf8_collate (s, "out") == 0 || g_utf8_collate (s, "ref") == 0 || g_utf8_collate (s, "signal") == 0) {
 		fputc ('@', self->priv->stream);
 	}
 	vala_interface_writer_write_string (self, s);
@@ -875,10 +1013,10 @@ static void vala_interface_writer_write_type (ValaInterfaceWriter* self, ValaTyp
 	g_return_if_fail (VALA_IS_INTERFACE_WRITER (self));
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (type));
 	if (vala_type_reference_get_data_type (type) != NULL) {
-		char* __temp35;
-		__temp35 = NULL;
-		vala_interface_writer_write_string (self, (__temp35 = vala_symbol_get_full_name (VALA_SYMBOL (vala_type_reference_get_data_type (type)))));
-		(__temp35 = (g_free (__temp35), NULL));
+		char* _tmp0;
+		_tmp0 = NULL;
+		vala_interface_writer_write_string (self, (_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (vala_type_reference_get_data_type (type)))));
+		(_tmp0 = (g_free (_tmp0), NULL));
 	} else {
 		vala_interface_writer_write_string (self, vala_symbol_get_name (((ValaSymbol*) vala_type_reference_get_type_parameter (type))));
 	}
@@ -905,10 +1043,10 @@ static void vala_interface_writer_write_type (ValaInterfaceWriter* self, ValaTyp
 						vala_interface_writer_write_string (self, "weak ");
 					}
 					if (vala_type_reference_get_data_type (type_arg) != NULL) {
-						char* __temp36;
-						__temp36 = NULL;
-						vala_interface_writer_write_string (self, (__temp36 = vala_symbol_get_full_name (VALA_SYMBOL (vala_type_reference_get_data_type (type_arg)))));
-						(__temp36 = (g_free (__temp36), NULL));
+						char* _tmp1;
+						_tmp1 = NULL;
+						vala_interface_writer_write_string (self, (_tmp1 = vala_symbol_get_full_name (VALA_SYMBOL (vala_type_reference_get_data_type (type_arg)))));
+						(_tmp1 = (g_free (_tmp1), NULL));
 					} else {
 						vala_interface_writer_write_string (self, vala_symbol_get_name (((ValaSymbol*) vala_type_reference_get_type_parameter (type_arg))));
 					}
