@@ -143,12 +143,12 @@ ValaExpression* vala_lambda_expression_get_expression_body (ValaLambdaExpression
 
 void vala_lambda_expression_set_expression_body (ValaLambdaExpression* self, ValaExpression* value)
 {
-	ValaExpression* __temp3;
-	ValaExpression* __temp2;
+	ValaExpression* _tmp2;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_LAMBDA_EXPRESSION (self));
-	__temp3 = NULL;
-	__temp2 = NULL;
-	self->priv->_expression_body = (__temp3 = (__temp2 = value, (__temp2 == NULL ? NULL : g_object_ref (__temp2))), (self->priv->_expression_body == NULL ? NULL : (self->priv->_expression_body = (g_object_unref (self->priv->_expression_body), NULL))), __temp3);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_expression_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_expression_body == NULL ? NULL : (self->priv->_expression_body = (g_object_unref (self->priv->_expression_body), NULL))), _tmp2);
 }
 
 
@@ -161,12 +161,12 @@ ValaBlock* vala_lambda_expression_get_statement_body (ValaLambdaExpression* self
 
 void vala_lambda_expression_set_statement_body (ValaLambdaExpression* self, ValaBlock* value)
 {
-	ValaBlock* __temp6;
-	ValaBlock* __temp5;
+	ValaBlock* _tmp2;
+	ValaBlock* _tmp1;
 	g_return_if_fail (VALA_IS_LAMBDA_EXPRESSION (self));
-	__temp6 = NULL;
-	__temp5 = NULL;
-	self->priv->_statement_body = (__temp6 = (__temp5 = value, (__temp5 == NULL ? NULL : g_object_ref (__temp5))), (self->priv->_statement_body == NULL ? NULL : (self->priv->_statement_body = (g_object_unref (self->priv->_statement_body), NULL))), __temp6);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_statement_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_statement_body == NULL ? NULL : (self->priv->_statement_body = (g_object_unref (self->priv->_statement_body), NULL))), _tmp2);
 }
 
 
@@ -179,12 +179,12 @@ ValaMethod* vala_lambda_expression_get_method (ValaLambdaExpression* self)
 
 void vala_lambda_expression_set_method (ValaLambdaExpression* self, ValaMethod* value)
 {
-	ValaMethod* __temp9;
-	ValaMethod* __temp8;
+	ValaMethod* _tmp2;
+	ValaMethod* _tmp1;
 	g_return_if_fail (VALA_IS_LAMBDA_EXPRESSION (self));
-	__temp9 = NULL;
-	__temp8 = NULL;
-	self->priv->_method = (__temp9 = (__temp8 = value, (__temp8 == NULL ? NULL : g_object_ref (__temp8))), (self->priv->_method == NULL ? NULL : (self->priv->_method = (g_object_unref (self->priv->_method), NULL))), __temp9);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_method == NULL ? NULL : (self->priv->_method = (g_object_unref (self->priv->_method), NULL))), _tmp2);
 }
 
 
@@ -202,6 +202,9 @@ static void vala_lambda_expression_get_property (GObject * object, guint propert
 		case VALA_LAMBDA_EXPRESSION_METHOD:
 		g_value_set_object (value, vala_lambda_expression_get_method (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -220,6 +223,9 @@ static void vala_lambda_expression_set_property (GObject * object, guint propert
 		case VALA_LAMBDA_EXPRESSION_METHOD:
 		vala_lambda_expression_set_method (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
