@@ -22,7 +22,6 @@
 
 #ifndef __VALALITERAL_H__
 #define __VALALITERAL_H__
-typedef struct _ValaLiteralPrivate ValaLiteralPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -38,6 +37,7 @@ G_BEGIN_DECLS
 #define VALA_IS_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LITERAL))
 #define VALA_LITERAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LITERAL, ValaLiteralClass))
 
+typedef struct _ValaLiteralPrivate ValaLiteralPrivate;
 
 /**
  * Base class for all literals in the source code.
@@ -52,7 +52,7 @@ struct _ValaLiteralClass {
 
 ValaTypeReference* vala_literal_get_static_type (ValaLiteral* self);
 void vala_literal_set_static_type (ValaLiteral* self, ValaTypeReference* value);
-GType vala_literal_get_type ();
+GType vala_literal_get_type (void);
 
 G_END_DECLS
 
