@@ -27,6 +27,7 @@
 #include <gee/iterator.h>
 #include <vala/valasymbol.h>
 #include <vala/valamemorymanager.h>
+#include <vala/valaexpression.h>
 #include <vala/valatypereference.h>
 #include <vala/valadatatype.h>
 #include <vala/valainvokable.h>
@@ -58,11 +59,13 @@ static void vala_memory_manager_real_visit_constructor (ValaCodeVisitor* base, V
 static void vala_memory_manager_real_visit_destructor (ValaCodeVisitor* base, ValaDestructor* d);
 static void vala_memory_manager_real_visit_named_argument (ValaCodeVisitor* base, ValaNamedArgument* n);
 static void vala_memory_manager_real_visit_variable_declarator (ValaCodeVisitor* base, ValaVariableDeclarator* decl);
+static void vala_memory_manager_real_visit_initializer_list (ValaCodeVisitor* base, ValaInitializerList* list);
 static void vala_memory_manager_real_visit_expression_statement (ValaCodeVisitor* base, ValaExpressionStatement* stmt);
 static void vala_memory_manager_real_visit_end_return_statement (ValaCodeVisitor* base, ValaReturnStatement* stmt);
 static void vala_memory_manager_real_visit_throw_statement (ValaCodeVisitor* base, ValaThrowStatement* stmt);
 static void vala_memory_manager_real_visit_try_statement (ValaCodeVisitor* base, ValaTryStatement* stmt);
 static void vala_memory_manager_real_visit_catch_clause (ValaCodeVisitor* base, ValaCatchClause* clause);
+static void vala_memory_manager_real_visit_array_creation_expression (ValaCodeVisitor* base, ValaArrayCreationExpression* e);
 static void vala_memory_manager_real_visit_member_access (ValaCodeVisitor* base, ValaMemberAccess* expr);
 static void vala_memory_manager_real_visit_end_invocation_expression (ValaCodeVisitor* base, ValaInvocationExpression* expr);
 static void vala_memory_manager_real_visit_end_object_creation_expression (ValaCodeVisitor* base, ValaObjectCreationExpression* expr);
@@ -163,11 +166,11 @@ static void vala_memory_manager_real_visit_field (ValaCodeVisitor* base, ValaFie
 static void vala_memory_manager_real_visit_method (ValaCodeVisitor* base, ValaMethod* m)
 {
 	ValaMemoryManager * self;
-	ValaSymbol* __temp0;
+	ValaSymbol* _tmp0;
 	self = ((ValaMemoryManager*) base);
 	g_return_if_fail (VALA_IS_METHOD (m));
-	__temp0 = NULL;
-	self->priv->current_symbol = (__temp0 = VALA_SYMBOL (g_object_ref (m)), (self->priv->current_symbol == NULL ? NULL : (self->priv->current_symbol = (g_object_unref (self->priv->current_symbol), NULL))), __temp0);
+	_tmp0 = NULL;
+	self->priv->current_symbol = (_tmp0 = VALA_SYMBOL (g_object_ref (m)), (self->priv->current_symbol == NULL ? NULL : (self->priv->current_symbol = (g_object_unref (self->priv->current_symbol), NULL))), _tmp0);
 	vala_code_node_accept_children (VALA_CODE_NODE (m), VALA_CODE_VISITOR (self));
 }
 
@@ -184,11 +187,11 @@ static void vala_memory_manager_real_visit_creation_method (ValaCodeVisitor* bas
 static void vala_memory_manager_real_visit_property (ValaCodeVisitor* base, ValaProperty* prop)
 {
 	ValaMemoryManager * self;
-	ValaSymbol* __temp1;
+	ValaSymbol* _tmp0;
 	self = ((ValaMemoryManager*) base);
 	g_return_if_fail (VALA_IS_PROPERTY (prop));
-	__temp1 = NULL;
-	self->priv->current_symbol = (__temp1 = VALA_SYMBOL (g_object_ref (prop)), (self->priv->current_symbol == NULL ? NULL : (self->priv->current_symbol = (g_object_unref (self->priv->current_symbol), NULL))), __temp1);
+	_tmp0 = NULL;
+	self->priv->current_symbol = (_tmp0 = VALA_SYMBOL (g_object_ref (prop)), (self->priv->current_symbol == NULL ? NULL : (self->priv->current_symbol = (g_object_unref (self->priv->current_symbol), NULL))), _tmp0);
 	vala_code_node_accept_children (VALA_CODE_NODE (prop), VALA_CODE_VISITOR (self));
 }
 
@@ -234,6 +237,7 @@ static void vala_memory_manager_real_visit_variable_declarator (ValaCodeVisitor*
 	ValaMemoryManager * self;
 	self = ((ValaMemoryManager*) base);
 	g_return_if_fail (VALA_IS_VARIABLE_DECLARATOR (decl));
+	vala_code_node_accept_children (VALA_CODE_NODE (decl), VALA_CODE_VISITOR (self));
 	if (vala_variable_declarator_get_initializer (decl) != NULL) {
 		if (vala_type_reference_get_takes_ownership (vala_variable_declarator_get_type_reference (decl))) {
 			vala_memory_manager_visit_possibly_missing_copy_expression (self, vala_variable_declarator_get_initializer (decl));
@@ -244,6 +248,15 @@ static void vala_memory_manager_real_visit_variable_declarator (ValaCodeVisitor*
 }
 
 
+static void vala_memory_manager_real_visit_initializer_list (ValaCodeVisitor* base, ValaInitializerList* list)
+{
+	ValaMemoryManager * self;
+	self = ((ValaMemoryManager*) base);
+	g_return_if_fail (VALA_IS_INITIALIZER_LIST (list));
+	vala_code_node_accept_children (VALA_CODE_NODE (list), VALA_CODE_VISITOR (self));
+}
+
+
 static void vala_memory_manager_real_visit_expression_statement (ValaCodeVisitor* base, ValaExpressionStatement* stmt)
 {
 	ValaMemoryManager * self;
@@ -260,10 +273,10 @@ static void vala_memory_manager_real_visit_end_return_statement (ValaCodeVisitor
 	g_return_if_fail (VALA_IS_RETURN_STATEMENT (stmt));
 	if (vala_return_statement_get_return_expression (stmt) != NULL) {
 		if (VALA_IS_METHOD (self->priv->current_symbol)) {
-			ValaMethod* __temp2;
+			ValaMethod* _tmp0;
 			ValaMethod* m;
-			__temp2 = NULL;
-			m = (__temp2 = VALA_METHOD (self->priv->current_symbol), (__temp2 == NULL ? NULL : g_object_ref (__temp2)));
+			_tmp0 = NULL;
+			m = (_tmp0 = VALA_METHOD (self->priv->current_symbol), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			if (vala_type_reference_get_transfers_ownership (vala_method_get_return_type (m))) {
 				vala_memory_manager_visit_possibly_missing_copy_expression (self, vala_return_statement_get_return_expression (stmt));
 			} else {
@@ -305,6 +318,32 @@ static void vala_memory_manager_real_visit_catch_clause (ValaCodeVisitor* base,
 }
 
 
+static void vala_memory_manager_real_visit_array_creation_expression (ValaCodeVisitor* base, ValaArrayCreationExpression* e)
+{
+	ValaMemoryManager * self;
+	self = ((ValaMemoryManager*) base);
+	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (e));
+	if (vala_array_creation_expression_get_initializer_list (e) != NULL) {
+		{
+			GeeCollection* init_collection;
+			GeeIterator* init_it;
+			init_collection = vala_initializer_list_get_initializers (vala_array_creation_expression_get_initializer_list (e));
+			init_it = gee_iterable_iterator (GEE_ITERABLE (init_collection));
+			while (gee_iterator_next (init_it)) {
+				ValaExpression* init;
+				init = gee_iterator_get (init_it);
+				{
+					vala_memory_manager_visit_possibly_missing_copy_expression (self, init);
+					(init == NULL ? NULL : (init = (g_object_unref (init), NULL)));
+				}
+			}
+			(init_collection == NULL ? NULL : (init_collection = (g_object_unref (init_collection), NULL)));
+			(init_it == NULL ? NULL : (init_it = (g_object_unref (init_it), NULL)));
+		}
+	}
+}
+
+
 static void vala_memory_manager_real_visit_member_access (ValaCodeVisitor* base, ValaMemberAccess* expr)
 {
 	ValaMemoryManager * self;
@@ -319,14 +358,14 @@ static void vala_memory_manager_real_visit_member_access (ValaCodeVisitor* base,
 static void vala_memory_manager_real_visit_end_invocation_expression (ValaCodeVisitor* base, ValaInvocationExpression* expr)
 {
 	ValaMemoryManager * self;
-	ValaInvokable* __temp3;
+	ValaInvokable* _tmp0;
 	ValaInvokable* msym;
 	GeeCollection* params;
 	GeeIterator* params_it;
 	self = ((ValaMemoryManager*) base);
 	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (expr));
-	__temp3 = NULL;
-	msym = (__temp3 = VALA_INVOKABLE (vala_expression_get_symbol_reference (vala_invocation_expression_get_call (expr))), (__temp3 == NULL ? NULL : g_object_ref (__temp3)));
+	_tmp0 = NULL;
+	msym = (_tmp0 = VALA_INVOKABLE (vala_expression_get_symbol_reference (vala_invocation_expression_get_call (expr))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 	params = vala_invokable_get_parameters (msym);
 	params_it = gee_iterable_iterator (GEE_ITERABLE (params));
 	{
@@ -346,11 +385,11 @@ static void vala_memory_manager_real_visit_end_invocation_expression (ValaCodeVi
 						is_ref = vala_type_reference_get_takes_ownership (vala_formal_parameter_get_type_reference (param));
 						if (is_ref && vala_type_reference_get_type_parameter (vala_formal_parameter_get_type_reference (param)) != NULL) {
 							if (VALA_IS_MEMBER_ACCESS (vala_invocation_expression_get_call (expr))) {
-								ValaMemberAccess* __temp4;
+								ValaMemberAccess* _tmp1;
 								ValaMemberAccess* ma;
 								ValaTypeReference* param_type;
-								__temp4 = NULL;
-								ma = (__temp4 = VALA_MEMBER_ACCESS (vala_invocation_expression_get_call (expr)), (__temp4 == NULL ? NULL : g_object_ref (__temp4)));
+								_tmp1 = NULL;
+								ma = (_tmp1 = VALA_MEMBER_ACCESS (vala_invocation_expression_get_call (expr)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 								param_type = vala_semantic_analyzer_get_actual_type (vala_expression_get_static_type (vala_member_access_get_inner (ma)), VALA_SYMBOL (msym), vala_formal_parameter_get_type_reference (param), VALA_CODE_NODE (expr));
 								if (param_type != NULL) {
 									is_ref = vala_type_reference_get_takes_ownership (param_type);
@@ -386,7 +425,7 @@ static void vala_memory_manager_real_visit_end_invocation_expression (ValaCodeVi
 static void vala_memory_manager_real_visit_end_object_creation_expression (ValaCodeVisitor* base, ValaObjectCreationExpression* expr)
 {
 	ValaMemoryManager * self;
-	ValaInvokable* __temp5;
+	ValaInvokable* _tmp0;
 	ValaInvokable* msym;
 	GeeCollection* params;
 	GeeIterator* params_it;
@@ -395,8 +434,8 @@ static void vala_memory_manager_real_visit_end_object_creation_expression (ValaC
 	if (!(VALA_IS_INVOKABLE (vala_expression_get_symbol_reference (((ValaExpression*) expr))))) {
 		return;
 	}
-	__temp5 = NULL;
-	msym = (__temp5 = VALA_INVOKABLE (vala_expression_get_symbol_reference (((ValaExpression*) expr))), (__temp5 == NULL ? NULL : g_object_ref (__temp5)));
+	_tmp0 = NULL;
+	msym = (_tmp0 = VALA_INVOKABLE (vala_expression_get_symbol_reference (((ValaExpression*) expr))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 	params = vala_invokable_get_parameters (msym);
 	params_it = gee_iterable_iterator (GEE_ITERABLE (params));
 	{
@@ -490,11 +529,13 @@ static void vala_memory_manager_class_init (ValaMemoryManagerClass * klass)
 	VALA_CODE_VISITOR_CLASS (klass)->visit_destructor = vala_memory_manager_real_visit_destructor;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_named_argument = vala_memory_manager_real_visit_named_argument;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_variable_declarator = vala_memory_manager_real_visit_variable_declarator;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_initializer_list = vala_memory_manager_real_visit_initializer_list;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_expression_statement = vala_memory_manager_real_visit_expression_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_end_return_statement = vala_memory_manager_real_visit_end_return_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_throw_statement = vala_memory_manager_real_visit_throw_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_try_statement = vala_memory_manager_real_visit_try_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_catch_clause = vala_memory_manager_real_visit_catch_clause;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_array_creation_expression = vala_memory_manager_real_visit_array_creation_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_member_access = vala_memory_manager_real_visit_member_access;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_end_invocation_expression = vala_memory_manager_real_visit_end_invocation_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_end_object_creation_expression = vala_memory_manager_real_visit_end_object_creation_expression;
