@@ -34,7 +34,6 @@ struct _ValaPropertyPrivate {
 	ValaTypeReference* _type_reference;
 	ValaPropertyAccessor* _get_accessor;
 	ValaPropertyAccessor* _set_accessor;
-	ValaMemberAccessibility _access;
 	ValaFormalParameter* _this_parameter;
 	gboolean _no_accessor_method;
 	gboolean _interface_only;
@@ -51,7 +50,6 @@ enum  {
 	VALA_PROPERTY_TYPE_REFERENCE,
 	VALA_PROPERTY_GET_ACCESSOR,
 	VALA_PROPERTY_SET_ACCESSOR,
-	VALA_PROPERTY_ACCESS,
 	VALA_PROPERTY_THIS_PARAMETER,
 	VALA_PROPERTY_NO_ACCESSOR_METHOD,
 	VALA_PROPERTY_INTERFACE_ONLY,
@@ -141,16 +139,16 @@ static void vala_property_real_accept_children (ValaCodeNode* base, ValaCodeVisi
  */
 char* vala_property_get_upper_case_cname (ValaProperty* self)
 {
-	char* __temp2;
-	char* __temp1;
-	char* __temp0;
-	char* __temp3;
+	char* _tmp2;
+	char* _tmp1;
+	char* _tmp0;
+	char* _tmp3;
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
-	__temp2 = NULL;
-	__temp1 = NULL;
-	__temp0 = NULL;
-	__temp3 = NULL;
-	return (__temp3 = g_utf8_strup ((__temp2 = g_strdup_printf ("%s_%s", (__temp0 = vala_symbol_get_lower_case_cname (vala_symbol_get_parent_symbol (((ValaSymbol*) self)), NULL)), (__temp1 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self)))))), -1), (__temp2 = (g_free (__temp2), NULL)), (__temp1 = (g_free (__temp1), NULL)), (__temp0 = (g_free (__temp0), NULL)), __temp3);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	_tmp3 = NULL;
+	return (_tmp3 = g_utf8_strup ((_tmp2 = g_strdup_printf ("%s_%s", (_tmp0 = vala_symbol_get_lower_case_cname (vala_symbol_get_parent_symbol (((ValaSymbol*) self)), NULL)), (_tmp1 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self)))))), -1), (_tmp2 = (g_free (_tmp2), NULL)), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp3);
 }
 
 
@@ -162,30 +160,30 @@ char* vala_property_get_upper_case_cname (ValaProperty* self)
 ValaCCodeConstant* vala_property_get_canonical_cconstant (ValaProperty* self)
 {
 	GString* str;
-	const char* __temp5;
+	const char* _tmp0;
 	char* i;
-	ValaCCodeConstant* __temp8;
+	ValaCCodeConstant* _tmp3;
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
 	str = g_string_new ("\"");
-	__temp5 = NULL;
-	i = (__temp5 = vala_symbol_get_name (((ValaSymbol*) self)), (__temp5 == NULL ? NULL : g_strdup (__temp5)));
+	_tmp0 = NULL;
+	i = (_tmp0 = vala_symbol_get_name (((ValaSymbol*) self)), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	while (g_utf8_strlen (i, -1) > 0) {
 		gunichar c;
-		char* __temp7;
-		const char* __temp6;
+		char* _tmp2;
+		const char* _tmp1;
 		c = g_utf8_get_char (i);
 		if (c == '_') {
 			g_string_append_c (str, '-');
 		} else {
 			g_string_append_unichar (str, c);
 		}
-		__temp7 = NULL;
-		__temp6 = NULL;
-		i = (__temp7 = (__temp6 = g_utf8_next_char (i), (__temp6 == NULL ? NULL : g_strdup (__temp6))), (i = (g_free (i), NULL)), __temp7);
+		_tmp2 = NULL;
+		_tmp1 = NULL;
+		i = (_tmp2 = (_tmp1 = g_utf8_next_char (i), (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (i = (g_free (i), NULL)), _tmp2);
 	}
 	g_string_append_c (str, '"');
-	__temp8 = NULL;
-	return (__temp8 = vala_ccode_constant_new (str->str), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), (i = (g_free (i), NULL)), __temp8);
+	_tmp3 = NULL;
+	return (_tmp3 = vala_ccode_constant_new (str->str), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), (i = (g_free (i), NULL)), _tmp3);
 	(str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL)));
 	(i = (g_free (i), NULL));
 }
@@ -202,10 +200,10 @@ void vala_property_process_attributes (ValaProperty* self)
 		GList* a_it;
 		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* __temp9;
+			ValaAttribute* _tmp0;
 			ValaAttribute* a;
-			__temp9 = NULL;
-			a = (__temp9 = a_it->data, (__temp9 == NULL ? NULL : g_object_ref (__temp9)));
+			_tmp0 = NULL;
+			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "NoAccessorMethod") == 0) {
 					vala_property_set_no_accessor_method (self, TRUE);
@@ -275,10 +273,10 @@ ValaTypeReference* vala_property_get_type_reference (ValaProperty* self)
 
 void vala_property_set_type_reference (ValaProperty* self, ValaTypeReference* value)
 {
-	ValaTypeReference* __temp18;
+	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_PROPERTY (self));
-	__temp18 = NULL;
-	self->priv->_type_reference = (__temp18 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp18);
+	_tmp1 = NULL;
+	self->priv->_type_reference = (_tmp1 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp1);
 }
 
 
@@ -291,12 +289,12 @@ ValaPropertyAccessor* vala_property_get_get_accessor (ValaProperty* self)
 
 void vala_property_set_get_accessor (ValaProperty* self, ValaPropertyAccessor* value)
 {
-	ValaPropertyAccessor* __temp21;
-	ValaPropertyAccessor* __temp20;
+	ValaPropertyAccessor* _tmp2;
+	ValaPropertyAccessor* _tmp1;
 	g_return_if_fail (VALA_IS_PROPERTY (self));
-	__temp21 = NULL;
-	__temp20 = NULL;
-	self->priv->_get_accessor = (__temp21 = (__temp20 = value, (__temp20 == NULL ? NULL : g_object_ref (__temp20))), (self->priv->_get_accessor == NULL ? NULL : (self->priv->_get_accessor = (g_object_unref (self->priv->_get_accessor), NULL))), __temp21);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_get_accessor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_get_accessor == NULL ? NULL : (self->priv->_get_accessor = (g_object_unref (self->priv->_get_accessor), NULL))), _tmp2);
 }
 
 
@@ -309,26 +307,12 @@ ValaPropertyAccessor* vala_property_get_set_accessor (ValaProperty* self)
 
 void vala_property_set_set_accessor (ValaProperty* self, ValaPropertyAccessor* value)
 {
-	ValaPropertyAccessor* __temp24;
-	ValaPropertyAccessor* __temp23;
+	ValaPropertyAccessor* _tmp2;
+	ValaPropertyAccessor* _tmp1;
 	g_return_if_fail (VALA_IS_PROPERTY (self));
-	__temp24 = NULL;
-	__temp23 = NULL;
-	self->priv->_set_accessor = (__temp24 = (__temp23 = value, (__temp23 == NULL ? NULL : g_object_ref (__temp23))), (self->priv->_set_accessor == NULL ? NULL : (self->priv->_set_accessor = (g_object_unref (self->priv->_set_accessor), NULL))), __temp24);
-}
-
-
-ValaMemberAccessibility vala_property_get_access (ValaProperty* self)
-{
-	g_return_val_if_fail (VALA_IS_PROPERTY (self), 0);
-	return self->priv->_access;
-}
-
-
-void vala_property_set_access (ValaProperty* self, ValaMemberAccessibility value)
-{
-	g_return_if_fail (VALA_IS_PROPERTY (self));
-	self->priv->_access = value;
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_set_accessor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_set_accessor == NULL ? NULL : (self->priv->_set_accessor = (g_object_unref (self->priv->_set_accessor), NULL))), _tmp2);
 }
 
 
@@ -341,12 +325,12 @@ ValaFormalParameter* vala_property_get_this_parameter (ValaProperty* self)
 
 void vala_property_set_this_parameter (ValaProperty* self, ValaFormalParameter* value)
 {
-	ValaFormalParameter* __temp28;
-	ValaFormalParameter* __temp27;
+	ValaFormalParameter* _tmp2;
+	ValaFormalParameter* _tmp1;
 	g_return_if_fail (VALA_IS_PROPERTY (self));
-	__temp28 = NULL;
-	__temp27 = NULL;
-	self->priv->_this_parameter = (__temp28 = (__temp27 = value, (__temp27 == NULL ? NULL : g_object_ref (__temp27))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL))), __temp28);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_this_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL))), _tmp2);
 }
 
 
@@ -443,12 +427,12 @@ ValaProperty* vala_property_get_base_interface_property (ValaProperty* self)
 
 void vala_property_set_base_interface_property (ValaProperty* self, ValaProperty* value)
 {
-	ValaProperty* __temp37;
-	ValaProperty* __temp36;
+	ValaProperty* _tmp2;
+	ValaProperty* _tmp1;
 	g_return_if_fail (VALA_IS_PROPERTY (self));
-	__temp37 = NULL;
-	__temp36 = NULL;
-	self->priv->_base_interface_property = (__temp37 = (__temp36 = value, (__temp36 == NULL ? NULL : g_object_ref (__temp36))), (self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (g_object_unref (self->priv->_base_interface_property), NULL))), __temp37);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_base_interface_property = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (g_object_unref (self->priv->_base_interface_property), NULL))), _tmp2);
 }
 
 
@@ -466,9 +450,6 @@ static void vala_property_get_property (GObject * object, guint property_id, GVa
 		case VALA_PROPERTY_SET_ACCESSOR:
 		g_value_set_object (value, vala_property_get_set_accessor (self));
 		break;
-		case VALA_PROPERTY_ACCESS:
-		g_value_set_int (value, vala_property_get_access (self));
-		break;
 		case VALA_PROPERTY_THIS_PARAMETER:
 		g_value_set_object (value, vala_property_get_this_parameter (self));
 		break;
@@ -493,6 +474,9 @@ static void vala_property_get_property (GObject * object, guint property_id, GVa
 		case VALA_PROPERTY_BASE_INTERFACE_PROPERTY:
 		g_value_set_object (value, vala_property_get_base_interface_property (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -511,9 +495,6 @@ static void vala_property_set_property (GObject * object, guint property_id, con
 		case VALA_PROPERTY_SET_ACCESSOR:
 		vala_property_set_set_accessor (self, g_value_get_object (value));
 		break;
-		case VALA_PROPERTY_ACCESS:
-		vala_property_set_access (self, g_value_get_int (value));
-		break;
 		case VALA_PROPERTY_THIS_PARAMETER:
 		vala_property_set_this_parameter (self, g_value_get_object (value));
 		break;
@@ -538,6 +519,9 @@ static void vala_property_set_property (GObject * object, guint property_id, con
 		case VALA_PROPERTY_BASE_INTERFACE_PROPERTY:
 		vala_property_set_base_interface_property (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -554,7 +538,6 @@ static void vala_property_class_init (ValaPropertyClass * klass)
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_TYPE_REFERENCE, g_param_spec_object ("type-reference", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_GET_ACCESSOR, g_param_spec_object ("get-accessor", "foo", "bar", VALA_TYPE_PROPERTY_ACCESSOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_SET_ACCESSOR, g_param_spec_object ("set-accessor", "foo", "bar", VALA_TYPE_PROPERTY_ACCESSOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESS, g_param_spec_int ("access", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_THIS_PARAMETER, g_param_spec_object ("this-parameter", "foo", "bar", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_NO_ACCESSOR_METHOD, g_param_spec_boolean ("no-accessor-method", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_INTERFACE_ONLY, g_param_spec_boolean ("interface-only", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
