@@ -19,26 +19,27 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valapropertyaccessor.h"
-#include <vala/valastatement.h>
+#include <vala/valaproperty.h>
+#include <vala/valablock.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valasourcereference.h>
 #include <vala/valapropertyaccessor.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaPropertyAccessorPrivate {
+	ValaProperty* _prop;
 	gboolean _readable;
 	gboolean _writable;
 	gboolean _construction;
-	ValaStatement* _body;
+	ValaBlock* _body;
 	ValaFormalParameter* _value_parameter;
 };
 #define VALA_PROPERTY_ACCESSOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PROPERTY_ACCESSOR, ValaPropertyAccessorPrivate))
 enum  {
 	VALA_PROPERTY_ACCESSOR_DUMMY_PROPERTY,
+	VALA_PROPERTY_ACCESSOR_PROP,
 	VALA_PROPERTY_ACCESSOR_READABLE,
 	VALA_PROPERTY_ACCESSOR_WRITABLE,
 	VALA_PROPERTY_ACCESSOR_CONSTRUCTION,
@@ -61,21 +62,17 @@ static void vala_property_accessor_dispose (GObject * obj);
  * @param source       reference to source code
  * @return             newly created property accessor
  */
-ValaPropertyAccessor* vala_property_accessor_new (gboolean _readable, gboolean _writable, gboolean _construction, ValaStatement* _body, ValaSourceReference* source)
+ValaPropertyAccessor* vala_property_accessor_new (gboolean readable, gboolean writable, gboolean construction, ValaBlock* body, ValaSourceReference* source_reference)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaPropertyAccessor * self;
-	g_return_val_if_fail (_body == NULL || VALA_IS_STATEMENT (_body), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 5);
-	__params_it = __params;
-	(__params_it->name = "readable", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, _readable), __params_it++);
-	(__params_it->name = "writable", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, _writable), __params_it++);
-	(__params_it->name = "construction", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, _construction), __params_it++);
-	(__params_it->name = "body", g_value_init (&__params_it->value, VALA_TYPE_STATEMENT), g_value_set_object (&__params_it->value, _body), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_PROPERTY_ACCESSOR, __params_it - __params, __params);
+	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	self = g_object_newv (VALA_TYPE_PROPERTY_ACCESSOR, 0, NULL);
+	vala_property_accessor_set_readable (self, readable);
+	vala_property_accessor_set_writable (self, writable);
+	vala_property_accessor_set_construction (self, construction);
+	vala_property_accessor_set_body (self, body);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -83,7 +80,7 @@ ValaPropertyAccessor* vala_property_accessor_new (gboolean _readable, gboolean _
 static void vala_property_accessor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaPropertyAccessor * self;
-	self = VALA_PROPERTY_ACCESSOR (base);
+	self = ((ValaPropertyAccessor*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_property_accessor (visitor, self);
 }
@@ -92,7 +89,7 @@ static void vala_property_accessor_real_accept (ValaCodeNode* base, ValaCodeVisi
 static void vala_property_accessor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaPropertyAccessor * self;
-	self = VALA_PROPERTY_ACCESSOR (base);
+	self = ((ValaPropertyAccessor*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_property_accessor_get_body (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_property_accessor_get_body (self)), visitor);
@@ -100,6 +97,20 @@ static void vala_property_accessor_real_accept_children (ValaCodeNode* base, Val
 }
 
 
+ValaProperty* vala_property_accessor_get_prop (ValaPropertyAccessor* self)
+{
+	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
+	return self->priv->_prop;
+}
+
+
+void vala_property_accessor_set_prop (ValaPropertyAccessor* self, ValaProperty* value)
+{
+	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	self->priv->_prop = value;
+}
+
+
 gboolean vala_property_accessor_get_readable (ValaPropertyAccessor* self)
 {
 	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), FALSE);
@@ -142,21 +153,21 @@ void vala_property_accessor_set_construction (ValaPropertyAccessor* self, gboole
 }
 
 
-ValaStatement* vala_property_accessor_get_body (ValaPropertyAccessor* self)
+ValaBlock* vala_property_accessor_get_body (ValaPropertyAccessor* self)
 {
 	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
 	return self->priv->_body;
 }
 
 
-void vala_property_accessor_set_body (ValaPropertyAccessor* self, ValaStatement* value)
+void vala_property_accessor_set_body (ValaPropertyAccessor* self, ValaBlock* value)
 {
-	ValaStatement* __temp5;
-	ValaStatement* __temp4;
+	ValaBlock* _tmp2;
+	ValaBlock* _tmp1;
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
-	__temp5 = NULL;
-	__temp4 = NULL;
-	self->priv->_body = (__temp5 = (__temp4 = value, (__temp4 == NULL ? NULL : g_object_ref (__temp4))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp5);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
 }
 
 
@@ -169,12 +180,12 @@ ValaFormalParameter* vala_property_accessor_get_value_parameter (ValaPropertyAcc
 
 void vala_property_accessor_set_value_parameter (ValaPropertyAccessor* self, ValaFormalParameter* value)
 {
-	ValaFormalParameter* __temp8;
-	ValaFormalParameter* __temp7;
+	ValaFormalParameter* _tmp2;
+	ValaFormalParameter* _tmp1;
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
-	__temp8 = NULL;
-	__temp7 = NULL;
-	self->priv->_value_parameter = (__temp8 = (__temp7 = value, (__temp7 == NULL ? NULL : g_object_ref (__temp7))), (self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (g_object_unref (self->priv->_value_parameter), NULL))), __temp8);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_value_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (g_object_unref (self->priv->_value_parameter), NULL))), _tmp2);
 }
 
 
@@ -183,6 +194,9 @@ static void vala_property_accessor_get_property (GObject * object, guint propert
 	ValaPropertyAccessor * self;
 	self = VALA_PROPERTY_ACCESSOR (object);
 	switch (property_id) {
+		case VALA_PROPERTY_ACCESSOR_PROP:
+		g_value_set_object (value, vala_property_accessor_get_prop (self));
+		break;
 		case VALA_PROPERTY_ACCESSOR_READABLE:
 		g_value_set_boolean (value, vala_property_accessor_get_readable (self));
 		break;
@@ -198,6 +212,9 @@ static void vala_property_accessor_get_property (GObject * object, guint propert
 		case VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER:
 		g_value_set_object (value, vala_property_accessor_get_value_parameter (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -207,6 +224,9 @@ static void vala_property_accessor_set_property (GObject * object, guint propert
 	ValaPropertyAccessor * self;
 	self = VALA_PROPERTY_ACCESSOR (object);
 	switch (property_id) {
+		case VALA_PROPERTY_ACCESSOR_PROP:
+		vala_property_accessor_set_prop (self, g_value_get_object (value));
+		break;
 		case VALA_PROPERTY_ACCESSOR_READABLE:
 		vala_property_accessor_set_readable (self, g_value_get_boolean (value));
 		break;
@@ -222,6 +242,9 @@ static void vala_property_accessor_set_property (GObject * object, guint propert
 		case VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER:
 		vala_property_accessor_set_value_parameter (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -235,10 +258,11 @@ static void vala_property_accessor_class_init (ValaPropertyAccessorClass * klass
 	G_OBJECT_CLASS (klass)->dispose = vala_property_accessor_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_property_accessor_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_property_accessor_real_accept_children;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_PROP, g_param_spec_object ("prop", "foo", "bar", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_READABLE, g_param_spec_boolean ("readable", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_WRITABLE, g_param_spec_boolean ("writable", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_CONSTRUCTION, g_param_spec_boolean ("construction", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER, g_param_spec_object ("value-parameter", "foo", "bar", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -263,7 +287,7 @@ static void vala_property_accessor_dispose (GObject * obj)
 }
 
 
-GType vala_property_accessor_get_type ()
+GType vala_property_accessor_get_type (void)
 {
 	static GType vala_property_accessor_type_id = 0;
 	if (G_UNLIKELY (vala_property_accessor_type_id == 0)) {
