@@ -24,13 +24,8 @@
 #include <stdio.h>
 #include <vala/valareport.h>
 
-enum  {
-	VALA_REPORT_DUMMY_PROPERTY
-};
 static gint vala_report_warnings;
 static gint vala_report_errors;
-static gpointer vala_report_parent_class = NULL;
-static void vala_report_dispose (GObject * obj);
 
 
 /**
@@ -65,10 +60,10 @@ void vala_report_warning (ValaSourceReference* source, const char* message)
 	if (source == NULL) {
 		fprintf (stderr, "warning: %s\n", message);
 	} else {
-		char* __temp2;
-		__temp2 = NULL;
-		fprintf (stderr, "%s: warning: %s\n", (__temp2 = vala_source_reference_to_string (source)), message);
-		(__temp2 = (g_free (__temp2), NULL));
+		char* _tmp0;
+		_tmp0 = NULL;
+		fprintf (stderr, "%s: warning: %s\n", (_tmp0 = vala_source_reference_to_string (source)), message);
+		(_tmp0 = (g_free (_tmp0), NULL));
 	}
 }
 
@@ -87,48 +82,13 @@ void vala_report_error (ValaSourceReference* source, const char* message)
 	if (source == NULL) {
 		fprintf (stderr, "error: %s\n", message);
 	} else {
-		char* __temp3;
-		__temp3 = NULL;
-		fprintf (stderr, "%s: error: %s\n", (__temp3 = vala_source_reference_to_string (source)), message);
-		(__temp3 = (g_free (__temp3), NULL));
+		char* _tmp0;
+		_tmp0 = NULL;
+		fprintf (stderr, "%s: error: %s\n", (_tmp0 = vala_source_reference_to_string (source)), message);
+		(_tmp0 = (g_free (_tmp0), NULL));
 	}
 }
 
 
-static void vala_report_class_init (ValaReportClass * klass)
-{
-	vala_report_parent_class = g_type_class_peek_parent (klass);
-	G_OBJECT_CLASS (klass)->dispose = vala_report_dispose;
-}
-
-
-static void vala_report_init (ValaReport * self)
-{
-}
-
-
-static void vala_report_dispose (GObject * obj)
-{
-	ValaReport * self;
-	ValaReportClass * klass;
-	GObjectClass * parent_class;
-	self = VALA_REPORT (obj);
-	klass = VALA_REPORT_CLASS (g_type_class_peek (VALA_TYPE_REPORT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
-}
-
-
-GType vala_report_get_type (void)
-{
-	static GType vala_report_type_id = 0;
-	if (G_UNLIKELY (vala_report_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaReportClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_report_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaReport), 0, (GInstanceInitFunc) vala_report_init };
-		vala_report_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaReport", &g_define_type_info, 0);
-	}
-	return vala_report_type_id;
-}
-
-
 
 
