@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valasourcereference.h"
 #include <vala/valasourcefile.h>
@@ -60,18 +58,14 @@ static void vala_source_reference_dispose (GObject * obj);
  */
 ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaSourceReference * self;
 	g_return_val_if_fail (_file == NULL || VALA_IS_SOURCE_FILE (_file), NULL);
-	__params = g_new0 (GParameter, 5);
-	__params_it = __params;
-	(__params_it->name = "file", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE), g_value_set_object (&__params_it->value, _file), __params_it++);
-	(__params_it->name = "first-line", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _first_line), __params_it++);
-	(__params_it->name = "first-column", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _first_column), __params_it++);
-	(__params_it->name = "last-line", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _last_line), __params_it++);
-	(__params_it->name = "last-column", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _last_column), __params_it++);
-	self = g_object_newv (VALA_TYPE_SOURCE_REFERENCE, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_SOURCE_REFERENCE, 0, NULL);
+	vala_source_reference_set_file (self, _file);
+	vala_source_reference_set_first_line (self, _first_line);
+	vala_source_reference_set_first_column (self, _first_column);
+	vala_source_reference_set_last_line (self, _last_line);
+	vala_source_reference_set_last_column (self, _last_column);
 	return self;
 }
 
@@ -89,19 +83,15 @@ ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _fir
  */
 ValaSourceReference* vala_source_reference_new_with_comment (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column, const char* _comment)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaSourceReference * self;
 	g_return_val_if_fail (_file == NULL || VALA_IS_SOURCE_FILE (_file), NULL);
-	__params = g_new0 (GParameter, 6);
-	__params_it = __params;
-	(__params_it->name = "file", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE), g_value_set_object (&__params_it->value, _file), __params_it++);
-	(__params_it->name = "first-line", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _first_line), __params_it++);
-	(__params_it->name = "first-column", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _first_column), __params_it++);
-	(__params_it->name = "last-line", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _last_line), __params_it++);
-	(__params_it->name = "last-column", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _last_column), __params_it++);
-	(__params_it->name = "comment", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _comment), __params_it++);
-	self = g_object_newv (VALA_TYPE_SOURCE_REFERENCE, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_SOURCE_REFERENCE, 0, NULL);
+	vala_source_reference_set_file (self, _file);
+	vala_source_reference_set_first_line (self, _first_line);
+	vala_source_reference_set_first_column (self, _first_column);
+	vala_source_reference_set_last_line (self, _last_line);
+	vala_source_reference_set_last_column (self, _last_column);
+	vala_source_reference_set_comment (self, _comment);
 	return self;
 }
 
@@ -197,12 +187,12 @@ char* vala_source_reference_get_comment (ValaSourceReference* self)
 
 void vala_source_reference_set_comment (ValaSourceReference* self, const char* value)
 {
-	char* __temp8;
-	const char* __temp7;
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_SOURCE_REFERENCE (self));
-	__temp8 = NULL;
-	__temp7 = NULL;
-	self->priv->_comment = (__temp8 = (__temp7 = value, (__temp7 == NULL ? NULL : g_strdup (__temp7))), (self->priv->_comment = (g_free (self->priv->_comment), NULL)), __temp8);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_comment = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_comment = (g_free (self->priv->_comment), NULL)), _tmp2);
 }
 
 
@@ -229,6 +219,9 @@ static void vala_source_reference_get_property (GObject * object, guint property
 		case VALA_SOURCE_REFERENCE_COMMENT:
 		g_value_set_string (value, vala_source_reference_get_comment (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -256,6 +249,9 @@ static void vala_source_reference_set_property (GObject * object, guint property
 		case VALA_SOURCE_REFERENCE_COMMENT:
 		vala_source_reference_set_comment (self, g_value_get_string (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -295,7 +291,7 @@ static void vala_source_reference_dispose (GObject * obj)
 }
 
 
-GType vala_source_reference_get_type ()
+GType vala_source_reference_get_type (void)
 {
 	static GType vala_source_reference_type_id = 0;
 	if (G_UNLIKELY (vala_source_reference_type_id == 0)) {
