@@ -81,51 +81,51 @@ ValaArray* vala_type_parameter_get_array (ValaTypeParameter* self, gint rank)
 	g_return_val_if_fail (VALA_IS_TYPE_PARAMETER (self), NULL);
 	array_type = NULL;
 	if (self->priv->array_types != NULL) {
-		ValaArray* __temp0;
-		__temp0 = NULL;
-		array_type = (__temp0 = gee_map_get (((GeeMap*) self->priv->array_types), GINT_TO_POINTER (rank)), (array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL))), __temp0);
+		ValaArray* _tmp0;
+		_tmp0 = NULL;
+		array_type = (_tmp0 = gee_map_get (((GeeMap*) self->priv->array_types), GINT_TO_POINTER (rank)), (array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL))), _tmp0);
 	}
 	if (array_type == NULL) {
 		ValaArray* new_array_type;
-		ValaArrayLengthField* __temp3;
-		ValaArrayLengthField* __temp2;
-		ValaArrayResizeMethod* __temp5;
-		ValaArrayResizeMethod* __temp4;
-		ValaArrayMoveMethod* __temp7;
-		ValaArrayMoveMethod* __temp6;
-		ValaArray* __temp9;
-		ValaArray* __temp8;
+		ValaArrayLengthField* _tmp3;
+		ValaArrayLengthField* _tmp2;
+		ValaArrayResizeMethod* _tmp5;
+		ValaArrayResizeMethod* _tmp4;
+		ValaArrayMoveMethod* _tmp7;
+		ValaArrayMoveMethod* _tmp6;
+		ValaArray* _tmp9;
+		ValaArray* _tmp8;
 		if (self->priv->array_types == NULL) {
-			GeeMap* __temp1;
-			__temp1 = NULL;
-			self->priv->array_types = (__temp1 = GEE_MAP (gee_hash_map_new (NULL, NULL, g_object_ref, g_object_unref, g_direct_hash, g_direct_equal, g_direct_equal)), (self->priv->array_types == NULL ? NULL : (self->priv->array_types = (g_object_unref (self->priv->array_types), NULL))), __temp1);
+			GeeMap* _tmp1;
+			_tmp1 = NULL;
+			self->priv->array_types = (_tmp1 = GEE_MAP (gee_hash_map_new (NULL, NULL, g_object_ref, g_object_unref, g_direct_hash, g_direct_equal, g_direct_equal)), (self->priv->array_types == NULL ? NULL : (self->priv->array_types = (g_object_unref (self->priv->array_types), NULL))), _tmp1);
 		}
 		new_array_type = vala_array_new_with_type_parameter (self, rank, vala_code_node_get_source_reference (((ValaCodeNode*) self)));
 		vala_scope_add (vala_symbol_get_scope (vala_symbol_get_parent_symbol (((ValaSymbol*) self))), vala_symbol_get_name (((ValaSymbol*) new_array_type)), VALA_SYMBOL (new_array_type));
 		/* add internal length field */
-		__temp3 = NULL;
-		__temp2 = NULL;
-		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) new_array_type)), vala_symbol_get_name (((ValaSymbol*) (__temp2 = vala_array_get_length_field (new_array_type)))), VALA_SYMBOL ((__temp3 = vala_array_get_length_field (new_array_type))));
-		(__temp3 == NULL ? NULL : (__temp3 = (g_object_unref (__temp3), NULL)));
-		(__temp2 == NULL ? NULL : (__temp2 = (g_object_unref (__temp2), NULL)));
+		_tmp3 = NULL;
+		_tmp2 = NULL;
+		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) new_array_type)), vala_symbol_get_name (((ValaSymbol*) (_tmp2 = vala_array_get_length_field (new_array_type)))), VALA_SYMBOL ((_tmp3 = vala_array_get_length_field (new_array_type))));
+		(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
+		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
 		/* add internal resize method */
-		__temp5 = NULL;
-		__temp4 = NULL;
-		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) new_array_type)), vala_symbol_get_name (((ValaSymbol*) (__temp4 = vala_array_get_resize_method (new_array_type)))), VALA_SYMBOL ((__temp5 = vala_array_get_resize_method (new_array_type))));
-		(__temp5 == NULL ? NULL : (__temp5 = (g_object_unref (__temp5), NULL)));
-		(__temp4 == NULL ? NULL : (__temp4 = (g_object_unref (__temp4), NULL)));
+		_tmp5 = NULL;
+		_tmp4 = NULL;
+		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) new_array_type)), vala_symbol_get_name (((ValaSymbol*) (_tmp4 = vala_array_get_resize_method (new_array_type)))), VALA_SYMBOL ((_tmp5 = vala_array_get_resize_method (new_array_type))));
+		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
 		/* add internal move method */
-		__temp7 = NULL;
-		__temp6 = NULL;
-		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) new_array_type)), vala_symbol_get_name (((ValaSymbol*) (__temp6 = vala_array_get_move_method (new_array_type)))), VALA_SYMBOL ((__temp7 = vala_array_get_move_method (new_array_type))));
-		(__temp7 == NULL ? NULL : (__temp7 = (g_object_unref (__temp7), NULL)));
-		(__temp6 == NULL ? NULL : (__temp6 = (g_object_unref (__temp6), NULL)));
+		_tmp7 = NULL;
+		_tmp6 = NULL;
+		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) new_array_type)), vala_symbol_get_name (((ValaSymbol*) (_tmp6 = vala_array_get_move_method (new_array_type)))), VALA_SYMBOL ((_tmp7 = vala_array_get_move_method (new_array_type))));
+		(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
+		(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
 		/* link the array type to the same source as the container type */
 		vala_code_node_set_source_reference (VALA_CODE_NODE (new_array_type), vala_code_node_get_source_reference (((ValaCodeNode*) self)));
 		gee_map_set (((GeeMap*) self->priv->array_types), GINT_TO_POINTER (rank), new_array_type);
-		__temp9 = NULL;
-		__temp8 = NULL;
-		array_type = (__temp9 = (__temp8 = new_array_type, (__temp8 == NULL ? NULL : g_object_ref (__temp8))), (array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL))), __temp9);
+		_tmp9 = NULL;
+		_tmp8 = NULL;
+		array_type = (_tmp9 = (_tmp8 = new_array_type, (_tmp8 == NULL ? NULL : g_object_ref (_tmp8))), (array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL))), _tmp9);
 		(new_array_type == NULL ? NULL : (new_array_type = (g_object_unref (new_array_type), NULL)));
 	}
 	return array_type;
