@@ -120,36 +120,36 @@ ValaTypeReference* vala_type_reference_new_from_expression (ValaExpression* expr
 {
 	char* ns;
 	char* type_name;
-	gpointer __temp5;
+	gpointer _tmp5;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (expr), NULL);
 	ns = NULL;
 	type_name = NULL;
 	if (VALA_IS_MEMBER_ACCESS (expr)) {
 		ValaTypeReference* type_ref;
-		ValaMemberAccess* __temp0;
+		ValaMemberAccess* _tmp0;
 		ValaMemberAccess* ma;
 		type_ref = NULL;
-		__temp0 = NULL;
-		ma = (__temp0 = VALA_MEMBER_ACCESS (expr), (__temp0 == NULL ? NULL : g_object_ref (__temp0)));
+		_tmp0 = NULL;
+		ma = (_tmp0 = VALA_MEMBER_ACCESS (expr), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 		if (vala_member_access_get_inner (ma) != NULL) {
 			if (VALA_IS_MEMBER_ACCESS (vala_member_access_get_inner (ma))) {
-				ValaMemberAccess* __temp1;
+				ValaMemberAccess* _tmp1;
 				ValaMemberAccess* simple;
-				ValaTypeReference* __temp2;
-				__temp1 = NULL;
-				simple = (__temp1 = VALA_MEMBER_ACCESS (vala_member_access_get_inner (ma)), (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
-				__temp2 = NULL;
-				type_ref = (__temp2 = vala_type_reference_new_from_name (vala_member_access_get_member_name (simple), vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (((ValaCodeNode*) ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), __temp2);
+				ValaTypeReference* _tmp2;
+				_tmp1 = NULL;
+				simple = (_tmp1 = VALA_MEMBER_ACCESS (vala_member_access_get_inner (ma)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+				_tmp2 = NULL;
+				type_ref = (_tmp2 = vala_type_reference_new_from_name (vala_member_access_get_member_name (simple), vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (((ValaCodeNode*) ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), _tmp2);
 				(simple == NULL ? NULL : (simple = (g_object_unref (simple), NULL)));
 			}
 		} else {
-			ValaTypeReference* __temp3;
-			__temp3 = NULL;
-			type_ref = (__temp3 = vala_type_reference_new_from_name (NULL, vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (((ValaCodeNode*) ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), __temp3);
+			ValaTypeReference* _tmp3;
+			_tmp3 = NULL;
+			type_ref = (_tmp3 = vala_type_reference_new_from_name (NULL, vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (((ValaCodeNode*) ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), _tmp3);
 		}
 		if (type_ref != NULL) {
 			GeeCollection* type_args;
-			ValaTypeReference* __temp4;
+			ValaTypeReference* _tmp4;
 			type_args = vala_member_access_get_type_arguments (ma);
 			{
 				GeeCollection* arg_collection;
@@ -166,15 +166,15 @@ ValaTypeReference* vala_type_reference_new_from_expression (ValaExpression* expr
 				}
 				(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 			}
-			__temp4 = NULL;
-			return (__temp4 = type_ref, (type_args == NULL ? NULL : (type_args = (g_object_unref (type_args), NULL))), (ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL))), (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), __temp4);
+			_tmp4 = NULL;
+			return (_tmp4 = type_ref, (type_args == NULL ? NULL : (type_args = (g_object_unref (type_args), NULL))), (ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL))), (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), _tmp4);
 			(type_args == NULL ? NULL : (type_args = (g_object_unref (type_args), NULL)));
 		}
 		(type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL)));
 		(ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL)));
 	}
 	vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) expr)), "Type reference must be simple name or member access expression");
-	return VALA_TYPE_REFERENCE ((__temp5 = NULL, (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), __temp5));
+	return VALA_TYPE_REFERENCE ((_tmp5 = NULL, (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), _tmp5));
 	(ns = (g_free (ns), NULL));
 	(type_name = (g_free (type_name), NULL));
 }
@@ -261,38 +261,38 @@ char* vala_type_reference_get_cname (ValaTypeReference* self, gboolean var_type,
 	ptr = NULL;
 	arr = NULL;
 	if (vala_type_reference_get_type_parameter (self) != NULL || (!vala_data_type_is_reference_type (vala_type_reference_get_data_type (self)) && !vala_type_reference_get_is_ref (self) && !vala_type_reference_get_is_out (self))) {
-		char* __temp9;
-		__temp9 = NULL;
-		ptr = (__temp9 = g_strdup (""), (ptr = (g_free (ptr), NULL)), __temp9);
+		char* _tmp2;
+		_tmp2 = NULL;
+		ptr = (_tmp2 = g_strdup (""), (ptr = (g_free (ptr), NULL)), _tmp2);
 	} else {
 		if ((vala_data_type_is_reference_type (vala_type_reference_get_data_type (self)) && !vala_type_reference_get_is_ref (self) && !vala_type_reference_get_is_out (self)) || (!vala_data_type_is_reference_type (vala_type_reference_get_data_type (self)) && (vala_type_reference_get_is_ref (self) || vala_type_reference_get_is_out (self)))) {
-			char* __temp10;
-			__temp10 = NULL;
-			ptr = (__temp10 = g_strdup ("*"), (ptr = (g_free (ptr), NULL)), __temp10);
+			char* _tmp3;
+			_tmp3 = NULL;
+			ptr = (_tmp3 = g_strdup ("*"), (ptr = (g_free (ptr), NULL)), _tmp3);
 		} else {
-			char* __temp11;
-			__temp11 = NULL;
-			ptr = (__temp11 = g_strdup ("**"), (ptr = (g_free (ptr), NULL)), __temp11);
+			char* _tmp4;
+			_tmp4 = NULL;
+			ptr = (_tmp4 = g_strdup ("**"), (ptr = (g_free (ptr), NULL)), _tmp4);
 		}
 	}
 	if (vala_type_reference_get_data_type (self) != NULL) {
-		char* __temp12;
-		char* __temp13;
-		char* __temp14;
-		__temp12 = NULL;
-		__temp13 = NULL;
-		__temp14 = NULL;
-		return (__temp14 = (__temp13 = g_strconcat ((__temp12 = vala_data_type_get_cname (vala_type_reference_get_data_type (self), const_type)), ptr, arr, NULL, NULL), (__temp12 = (g_free (__temp12), NULL)), __temp13), (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), __temp14);
+		char* _tmp5;
+		char* _tmp6;
+		char* _tmp7;
+		_tmp5 = NULL;
+		_tmp6 = NULL;
+		_tmp7 = NULL;
+		return (_tmp7 = (_tmp6 = g_strconcat ((_tmp5 = vala_data_type_get_cname (vala_type_reference_get_data_type (self), const_type)), ptr, arr, NULL, NULL), (_tmp5 = (g_free (_tmp5), NULL)), _tmp6), (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), _tmp7);
 	} else {
 		if (vala_type_reference_get_type_parameter (self) != NULL) {
-			char* __temp15;
-			__temp15 = NULL;
-			return (__temp15 = g_strconcat ("gpointer", ptr, arr, NULL, NULL), (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), __temp15);
+			char* _tmp8;
+			_tmp8 = NULL;
+			return (_tmp8 = g_strconcat ("gpointer", ptr, arr, NULL, NULL), (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), _tmp8);
 		} else {
-			gpointer __temp16;
+			gpointer _tmp9;
 			/* raise error */
 			vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) self)), "unresolved type reference");
-			return (__temp16 = NULL, (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), __temp16);
+			return (_tmp9 = NULL, (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), _tmp9);
 		}
 	}
 	(ptr = (g_free (ptr), NULL));
@@ -310,39 +310,39 @@ char* vala_type_reference_get_const_cname (ValaTypeReference* self)
 {
 	char* ptr;
 	ValaDataType* t;
-	char* __temp23;
-	char* __temp24;
-	char* __temp25;
+	char* _tmp6;
+	char* _tmp7;
+	char* _tmp8;
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
 	ptr = NULL;
 	t = NULL;
 	/* FIXME: dirty hack to make constant arrays possible */
 	if (VALA_IS_ARRAY (vala_type_reference_get_data_type (self))) {
-		ValaDataType* __temp18;
-		ValaDataType* __temp17;
-		__temp18 = NULL;
-		__temp17 = NULL;
-		t = (__temp18 = (__temp17 = vala_array_get_element_type ((VALA_ARRAY (vala_type_reference_get_data_type (self)))), (__temp17 == NULL ? NULL : g_object_ref (__temp17))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp18);
+		ValaDataType* _tmp1;
+		ValaDataType* _tmp0;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		t = (_tmp1 = (_tmp0 = vala_array_get_element_type ((VALA_ARRAY (vala_type_reference_get_data_type (self)))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), _tmp1);
 	} else {
-		ValaDataType* __temp20;
-		ValaDataType* __temp19;
-		__temp20 = NULL;
-		__temp19 = NULL;
-		t = (__temp20 = (__temp19 = vala_type_reference_get_data_type (self), (__temp19 == NULL ? NULL : g_object_ref (__temp19))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp20);
+		ValaDataType* _tmp3;
+		ValaDataType* _tmp2;
+		_tmp3 = NULL;
+		_tmp2 = NULL;
+		t = (_tmp3 = (_tmp2 = vala_type_reference_get_data_type (self), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), _tmp3);
 	}
 	if (!vala_data_type_is_reference_type (t)) {
-		char* __temp21;
-		__temp21 = NULL;
-		ptr = (__temp21 = g_strdup (""), (ptr = (g_free (ptr), NULL)), __temp21);
+		char* _tmp4;
+		_tmp4 = NULL;
+		ptr = (_tmp4 = g_strdup (""), (ptr = (g_free (ptr), NULL)), _tmp4);
 	} else {
-		char* __temp22;
-		__temp22 = NULL;
-		ptr = (__temp22 = g_strdup ("*"), (ptr = (g_free (ptr), NULL)), __temp22);
+		char* _tmp5;
+		_tmp5 = NULL;
+		ptr = (_tmp5 = g_strdup ("*"), (ptr = (g_free (ptr), NULL)), _tmp5);
 	}
-	__temp23 = NULL;
-	__temp24 = NULL;
-	__temp25 = NULL;
-	return (__temp25 = (__temp24 = g_strdup_printf ("const %s%s", (__temp23 = vala_data_type_get_cname (t, FALSE)), ptr), (__temp23 = (g_free (__temp23), NULL)), __temp24), (ptr = (g_free (ptr), NULL)), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp25);
+	_tmp6 = NULL;
+	_tmp7 = NULL;
+	_tmp8 = NULL;
+	return (_tmp8 = (_tmp7 = g_strdup_printf ("const %s%s", (_tmp6 = vala_data_type_get_cname (t, FALSE)), ptr), (_tmp6 = (g_free (_tmp6), NULL)), _tmp7), (ptr = (g_free (ptr), NULL)), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), _tmp8);
 	(ptr = (g_free (ptr), NULL));
 	(t == NULL ? NULL : (t = (g_object_unref (t), NULL)));
 }
@@ -361,9 +361,9 @@ char* vala_type_reference_to_string (ValaTypeReference* self)
 		return vala_symbol_get_full_name (VALA_SYMBOL (vala_type_reference_get_data_type (self)));
 	} else {
 		if (vala_type_reference_get_type_parameter (self) != NULL) {
-			const char* __temp27;
-			__temp27 = NULL;
-			return (__temp27 = vala_symbol_get_name (((ValaSymbol*) vala_type_reference_get_type_parameter (self))), (__temp27 == NULL ? NULL : g_strdup (__temp27)));
+			const char* _tmp1;
+			_tmp1 = NULL;
+			return (_tmp1 = vala_symbol_get_name (((ValaSymbol*) vala_type_reference_get_type_parameter (self))), (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 		} else {
 			return g_strdup ("null");
 		}
@@ -404,10 +404,10 @@ ValaTypeReference* vala_type_reference_copy (ValaTypeReference* self)
 			ValaTypeReference* arg;
 			arg = gee_iterator_get (arg_it);
 			{
-				ValaTypeReference* __temp30;
-				__temp30 = NULL;
-				gee_collection_add (GEE_COLLECTION (result->priv->type_argument_list), (__temp30 = vala_type_reference_copy (arg)));
-				(__temp30 = (g_object_unref (__temp30), NULL));
+				ValaTypeReference* _tmp0;
+				_tmp0 = NULL;
+				gee_collection_add (GEE_COLLECTION (result->priv->type_argument_list), (_tmp0 = vala_type_reference_copy (arg)));
+				(_tmp0 = (g_object_unref (_tmp0), NULL));
 				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
 		}
@@ -597,12 +597,12 @@ ValaTypeParameter* vala_type_reference_get_type_parameter (ValaTypeReference* se
 
 void vala_type_reference_set_type_parameter (ValaTypeReference* self, ValaTypeParameter* value)
 {
-	ValaTypeParameter* __temp59;
-	ValaTypeParameter* __temp58;
+	ValaTypeParameter* _tmp2;
+	ValaTypeParameter* _tmp1;
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
-	__temp59 = NULL;
-	__temp58 = NULL;
-	self->priv->_type_parameter = (__temp59 = (__temp58 = value, (__temp58 == NULL ? NULL : g_object_ref (__temp58))), (self->priv->_type_parameter == NULL ? NULL : (self->priv->_type_parameter = (g_object_unref (self->priv->_type_parameter), NULL))), __temp59);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_type_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_type_parameter == NULL ? NULL : (self->priv->_type_parameter = (g_object_unref (self->priv->_type_parameter), NULL))), _tmp2);
 }
 
 
@@ -629,12 +629,12 @@ char* vala_type_reference_get_namespace_name (ValaTypeReference* self)
 
 void vala_type_reference_set_namespace_name (ValaTypeReference* self, const char* value)
 {
-	char* __temp63;
-	const char* __temp62;
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
-	__temp63 = NULL;
-	__temp62 = NULL;
-	self->priv->_namespace_name = (__temp63 = (__temp62 = value, (__temp62 == NULL ? NULL : g_strdup (__temp62))), (self->priv->_namespace_name = (g_free (self->priv->_namespace_name), NULL)), __temp63);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_namespace_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_namespace_name = (g_free (self->priv->_namespace_name), NULL)), _tmp2);
 }
 
 
@@ -647,12 +647,12 @@ char* vala_type_reference_get_type_name (ValaTypeReference* self)
 
 void vala_type_reference_set_type_name (ValaTypeReference* self, const char* value)
 {
-	char* __temp66;
-	const char* __temp65;
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
-	__temp66 = NULL;
-	__temp65 = NULL;
-	self->priv->_type_name = (__temp66 = (__temp65 = value, (__temp65 == NULL ? NULL : g_strdup (__temp65))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), __temp66);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), _tmp2);
 }
 
 
@@ -759,6 +759,9 @@ static void vala_type_reference_get_property (GObject * object, guint property_i
 		case VALA_TYPE_REFERENCE_IS_WEAK:
 		g_value_set_boolean (value, vala_type_reference_get_is_weak (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -810,6 +813,9 @@ static void vala_type_reference_set_property (GObject * object, guint property_i
 		case VALA_TYPE_REFERENCE_IS_WEAK:
 		vala_type_reference_set_is_weak (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
